/**
 * Interface.js
 * 紫微排盘接口类，对外暴露方法
 *
 * @date 2014-01-12
 * @version 0.1
 */
 
 /**
  * 保存用户基本信息
  */
 function saveUserBasicInfo(args,oldPeople){
	args = args.split(",");

	if(args.length < 6){
		return false;
	}
	
	var language = args[0];
	var username = args[1];
	var gender = args[2];
	var year = args[3];
	var month = args[4];
	var day = args[5];
	var hour = args[6].charAt(0);
	var isLunarDate = false;
	var isRunYue = false;

	if(oldPeople != 1){
		oldPeople = 0;		//0代表是现代人，1代表1901年之前的人
	}

	if(args.indexOf("农历") >= 0 || args.length == 8){
		isLunarDate = args[7];
	}
 
	if(!(username && gender && year && month && day && hour)){
		return false;
	}
	
	if(!(gender == "男" || gender == "女")){
		return false;
	}
	
	if(year < 1901 || year > 2099){
		return false;
	}
	
	if(month < 1 || month > 12){
		return false;
	}
	
	if(day < 1 || day > 31){
		return false;
	}
	
	if(language != 1){
		language = 0;
	}
	
	
	if(isLunarDate){
		if(month.indexOf("闰") >= 0){
			isRunYue = true;
			month = month.replace("闰", "");
		}
		
		month = Util.convertLunarMonthStr2Integer(month);
		day = Util.convertLunarDayStr2Integer(day);
		
	}

	switch(hour){
		case "子" : hour = "DZ_ZI"; break; 
		case "丑" : hour = "DZ_CHOU"; break; 
		case "寅" : hour = "DZ_YIN"; break; 
		case "卯" : hour = "DZ_MAO"; break; 
		case "辰" : hour = "DZ_CHEN"; break; 
		case "巳" : hour = "DZ_SI"; break; 
		case "午" : hour = "DZ_WU"; break; 
		case "未" : hour = "DZ_WEI"; break; 
		case "申" : hour = "DZ_SHEN"; break; 
		case "酉" : hour = "DZ_YOU"; break; 
		case "戌" : hour = "DZ_XU"; break; 
		case "亥" : hour = "DZ_HAI"; break; 
		default : hour = "DZ_ZI"; break;
	}
 
	year = parseInt(year);
	month = parseInt(month);
	day = parseInt(day);
	hour = Util.getHourByLunarStr(hour);
 
	var user = User.newInstance(username, gender, year, month, day, hour, isLunarDate, isRunYue);
	
	window.taxen = new Object();
	
	window.taxen.ziwei = new Object();
	
	window.taxen.ziwei.users = new Array();
	
	window.taxen.ziwei.users.push({
		"oldPeople" : oldPeople,
		"languageConfig" : language,
		"user" : user
	});
	
	return user.getToken();
 }
 
 /**
  * 获取用户信息
  */
 function getUserInfo(args){
 	
 	if(!args){
 		return false;
 	}
 	args = args.split(",");
 	
 	if(args.length < 2){
 		return false;
 	}
 	
 	var userToken = args[0];
 	
    if(!userToken){
		return false;
	}
    
    var year = parseInt(args[1]);
	
	for(var i = 0 ; i < window.taxen.ziwei.users.length; i ++){
		if(userToken == window.taxen.ziwei.users[i].user.getToken()){
			var user = window.taxen.ziwei.users[i].user;
			var language = window.taxen.ziwei.users[i].languageConfig;
			var oldPeople = window.taxen.ziwei.users[i].oldPeople;
			var usrInfo = user.getUserInfo();
			var birthdayYear = parseInt(user.getUserInfo().getBirthday().getYear());
			
			var currentXuSui = year - birthdayYear + 1;
			var xianTianMingPan = user.getXianTianMingPan(currentXuSui);
			var mingZhu = xianTianMingPan.getMingZhu();
			var shenZhu = xianTianMingPan.getShenZhu();
			var mingJu = user.getUserInfo().getMingJu().name;	
			var name = usrInfo.getName();
			var gender = usrInfo.getGender();
			var genderDescriptor = usrInfo.getGenderDescriptor();
			var birthDate = usrInfo.getBirthday();
			var birthday = birthDate.getYear() + "-" + birthDate.getMonth() + "-" + birthDate.getDay() + "-" + Util.getLunarHour(birthDate.getHour());
			var lunarBirthday = birthDate.getLunarYear() + "-" + (birthDate.isLunarRunYue() ? "闰" : "") + birthDate.getLunarMonth().index + "-" + birthDate.getLunarDay().index + "-" + Util.getLunarHour(birthDate.getHour());
			var bazi = usrInfo.getBaZi();
			
			//十神//藏干//纳音
			var shiShenAndCangGanAndNaYIn = false;
			var daYunPeriod = false;
			if(oldPeople != 1){
				shiShenAndCangGanAndNaYIn = Util.calcBaZiShiShenAndNaYin(bazi,language);
				daYunPeriod = Util.qiDaYun(user);
			}else{
				var yearGanZhi = birthDate.getYearOfGanZhi();
				yearGanZhi = Translator.translateTianGanDiZhi(yearGanZhi,language);
				lunarBirthday = yearGanZhi + "-" + (birthDate.isLunarRunYue() ? "闰" : "") + birthDate.getLunarMonth().index + "-" + birthDate.getLunarDay().index + "-" + Util.getLunarHour(birthDate.getHour());
				birthday = "";
			}
			
			/*var daYunPeriod = new Array();
			
			for(var i =1 ;i < 11; i++){
				var daYunObject = new Object();
				var daYunMingPan = user.getDaYunMingPan(i);
				var liuNian	= daYunMingPan.getYear();
				var liuNianGanZhi = daYunMingPan.getYearOfGanZhi();
				
				daYunObject.setDaYunLiuNian = liuNian;
				daYunObject.setLiNianGanZhi = liuNianGanZhi;
				daYunObject = Translator.translateObject(daYunObject, language);
				
				daYunPeriod.push(daYunObject);
			}*/
			
			var result = {
				"name" : name, 
				"gender" : gender, 
				"genderDescriptor" : genderDescriptor, 
				"birthday" : birthday, 
				"lunarBirthday" : lunarBirthday, 
				"mingZhu" : mingZhu,
				"shenZhu" : shenZhu,
				"mingJu" : mingJu,
				"zodiac" : Util.getZodiacByDiZhi(bazi.nianZhu.split("$")[1]),
				"bazi" : bazi.nianZhu + "-" + bazi.yueZhu + "-" + bazi.riZhu + "-" + bazi.shiZhu,
				"siHuaLunarYearGanZhi" : bazi.nianZhu,
				"lunarMonth" : (birthDate.isLunarRunYue() ? "闰" : "") +  Translator.translate(birthDate.getLunarMonth().name),
				"shiShenAndCangGanAndNaYIn" :　shiShenAndCangGanAndNaYIn,
				"daYunPeriod" : daYunPeriod
			};
			
			result = Translator.translateObject(result, language);
			
			return result;
		}
	}
	
	return false;
 }
 
  /**
  * 获取飞星命盘的某一宫位
  */
 function getFeiXingMingPanSection(args){
	if(!args){
		return false;
	}
	
	var parts = args.split(",");
	
	if(parts.length < 3){
		return false;
	}
	
	var userToken = parts[0];
	var year = parseInt(parts[1]);
	var index = parseInt(parts[2]);
	var daYunMingPan = false;
	var currentDaYunIndex = false;


	if(index < 0 || index > 11){
		index = 0;
	}
	
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];
		
		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;
			var oldPeople = userCfg.oldPeople;
			var birthdayYear = parseInt(userCfg.user.getUserInfo().getBirthday().getYear());
			var currentXuSui = year - birthdayYear + 1;
			
			var xianTianMingPan = userCfg.user.getXianTianMingPan(currentXuSui);
			var mingZhu = xianTianMingPan.getMingZhu();
			var shenZhu = xianTianMingPan.getShenZhu();
			var mingJu = userCfg.user.getUserInfo().getMingJu().name;	
			
			daYunMingPan = userCfg.user.getDaYunMingPan(1);     //未来人的大运都默认为1
			
			if(oldPeople != 1){
				for(var j = 0; j < 12; j++){
					if(xianTianMingPan.getItems()[j].getAgePeriod().isCurrent){
						if(currentDaYunIndex = xianTianMingPan.getItems()[j].getAgePeriod().daYunIndex){
							currentDaYunIndex = j + 1;
						}
						daYunMingPan = userCfg.user.getDaYunMingPan(xianTianMingPan.getItems()[j].getAgePeriod().daYunIndex);
					}
				}
			}
			
			var items = daYunMingPan.getItems();
			
			var item = items[index];
			
			var xianTianMingPan = userCfg.user.getXianTianMingPan();
			
			var xtItems = xianTianMingPan.getItems();
			
			var xtItem =  xtItems[index];
			
			var stars = xtItem.getStars();       //获取星星
			
			var isSiHuaPanOfSelf = new Array();
			var siHuaOfDui = new Array();
			var isSiHuaPanOfDui = false;
			if(xtItem.getSiHuaOfDaYunDui()){
				isSiHuaPanOfDui = xtItem.getSiHuaOfDaYunDui().split("-");
			}
			
			if(isSiHuaPanOfDui){
				for(var i = 0;i < isSiHuaPanOfDui.length; i++){
					if(isSiHuaPanOfDui[i] == "" || isSiHuaPanOfDui[i] == null || isSiHuaPanOfDui[i] == undefined){ 						// "",null,undefined
						continue;
					}
					siHuaOfDui.push(Translator.translate(isSiHuaPanOfDui[i], language));  //对宫四化
				}
			}
			
			for(var i = 0 ; i < stars.length; i ++){
				var star = stars[i];
				if(star.getIfSiHuaOfSelf()){
					isSiHuaPanOfSelf.push(Translator.translate(star.getIfSiHuaOfSelf().toString(), language));   //自宫四化
				}
			}
			
			var laiYin = xtItem.getLaiYin();
			var taisui = xtItem.getTaisui();
			
			var laiYinColor = false;
			var laiYinBgColor = false;
			var taiSuiBgColor = false;
			var taiSuiColor = false;
			
			if(laiYin){
				laiYinColor = "#ffffff";
				laiYinBgColor = "#e9523f";
			}
			
			if(taisui){
				taiSuiColor = "#ffffff";
				taiSuiBgColor = "#e9523f";
			}
			
			var index = item.getIndex();
			var tianGan	= item.getTianGan();
			var diZhi = item.getDiZhi();
			var gongWei	= item.getGongWei();
			var siHuaGongWei = item.getSiHuaGongWei();
			var siHuaYunGong = item.getSiHuaYunGong();
			var agePeriod_begin	= item.getDaYunAgePeriod().begin;
			var agePeriod_end = item.getDaYunAgePeriod().end;
			var daYunGongWei = item.getDaYunGongWei();
			var changSheng = item.getChangSheng12Shen();
			var hasYunYao = item.getDaYunStars() ? 'true' : 'false';
			var xuSui = daYunMingPan.getXuSui() + parseInt(parts[2]);
			var liuNian	= daYunMingPan.getYear() + parseInt(parts[2]);
			
			if(parseInt(parts[2]) >= 10){
				xuSui = false.toString();
				liuNian = false.toString();
			}
			var liuNianGanZhi = daYunMingPan.getYearOfGanZhi();
			var liuNianDouJun = daYunMingPan.getLiuNianDouJun().toString();
			
			var result = {
				"index" : index,  
				"tianGan" : tianGan,	
				"diZhi" : diZhi,
				"gongWei" :	gongWei,
				"agePeriod_begin" :	agePeriod_begin,
				"agePeriod_end" : agePeriod_end,	
				"xuSui" : xuSui,	
				"liuNian" : liuNian,	
				"liuNianGanZhi" : liuNianGanZhi,	
				"laiYin" : laiYin,
				"taisui" : taisui,
				"laiYincolor" : laiYinColor,
				"laiYinBgColor" : laiYinBgColor,
				"taisuiColor" : taiSuiColor,
				"taiSuiBgColor" : taiSuiBgColor,
				"currentDaYunIndex" : currentDaYunIndex,
				"isSiHuaPanOfDui" : siHuaOfDui,
				"isSiHuaPanOfSelf" : isSiHuaPanOfSelf
			};

			result = Translator.translateObject(result, language);
			
			return JSON.stringify(result);
		}
	}
	
	return false;
 }
 
 
 function getAgeIndex(args){
 	
 	if(!args){
 		return false;
 	}
 	
 	var currentIndex = -1;
 	args = args.split(",");
 	
 	var userToken = args[0];
 	var year = args[1];
 	
 	if(args.length >= 3){
 		currentIndex = parseInt(args[2]);
 	}
 	
 	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];
		
		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;
			
			var birthdayYear = parseInt(userCfg.user.getUserInfo().getBirthday().getYear());
			var currentXuSui = year - birthdayYear + 1;
			
			var xianTianMingPan = userCfg.user.getXianTianMingPan(currentXuSui);
			
			var daYunMingPan = userCfg.user.getDaYunMingPan(1);     //未来人的大运都默认为1
			
			if(currentIndex < 0){
				for(var j = 0; j < 12; j++){
				if(xianTianMingPan.getItems()[j].getAgePeriod().isCurrent){
					daYunMingPan = userCfg.user.getDaYunMingPan(xianTianMingPan.getItems()[j].getAgePeriod().daYunIndex);
					}
				}
			}else{
				daYunMingPan = userCfg.user.getDaYunMingPan(currentIndex); 
			}
			
			var ageList = new Array();			
			for(var i = 0; i < 10; i++){
				var obj = new Object();
				var xuSui = daYunMingPan.getXuSui() + i;
				var liuNian	= daYunMingPan.getYear() + i;
				var ageIndex = -1;
				
				var ganZhi = PerpetualCalendar.getLunarYearGanZhiStr(liuNian).split("$");
				
				if(ganZhi){
					ageIndex = Util.getIndexByDiZhi(ganZhi[1]);
				}
				
				obj.setXuSui = xuSui;
				obj.setLiuNian = liuNian;
				obj.setAgeIndex = ageIndex + 1;
				ageList.push(obj);
			}
			return ageList;
		}
	}		
 }
  
 //获取飞星盘的星星
 function getFeiXingPanSectionStars(args){
	if(!args){
		return false;
	}
	
	args = args.split(",");
	
	if(args.length < 2){
		return false;
	}
	
	var userToken = args[0];
	var index = parseInt(args[1]);
	
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];
		
		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;
		
			var xtMingPan = userCfg.user.getXianTianMingPan();
			
			var items = xtMingPan.getItems();
			
			var item = items[index];
			
			var stars = item.getStars();
			
			var starArray = new Array();
			
			for(var i = 0 ; i < stars.length; i ++){
				var star = stars[i];
				
				var starArrayItem = new Object();
				starArrayItem.index = i + 1;
				starArrayItem.name = star.getName();
				
				starArrayItem.descriptor = 'false';
				
				var color = ColorConfig.getStarColor(star.getName());
				var xtSiHua = star.getSiXiang();
				
				starArrayItem.color = color.color;
				starArrayItem.bgcolor = color.bgcolor;
				starArrayItem.siHua = xtSiHua.toString();
				starArrayItem.siHuaBgColor = false;     //先天四化的颜色
				starArrayItem.siHuaColor = false;     //先天四化的颜色
				if(ColorConfig.getXTSiHua(xtSiHua)){
					var sihuacolor = ColorConfig.getXTSiHua(xtSiHua).toString().split("-");
					if(sihuacolor){
						starArrayItem.siHuaBgColor = sihuacolor[0];     //先天四化的颜色
						starArrayItem.siHuaColor = sihuacolor[1];     //先天四化的颜色
					}
				}
				
				starArrayItem.mingGongSiHua = star.getMingGongSiHua().toString();
				
				starArrayItem = Translator.translateObject(starArrayItem, language);
				
				starArray.push(starArrayItem);
			}
			
			return JSON.stringify(starArray);
		}
	}
 }
 
 
 
 function getColor(){
	var xtgw_fore = BizEnum.COLORCONFIG.XIANTIANGONGWEI.color, //	先天宫位前景色	
		xtgw_bg = BizEnum.COLORCONFIG.XIANTIANGONGWEI.bgcolor, //	先天宫位背景色	
		dygw_fore = BizEnum.COLORCONFIG.DAYUNGONGWEI.color, //	大运宫位前景色	
		dygw_bg = BizEnum.COLORCONFIG.DAYUNGONGWEI.bgcolor, //	大运宫位背景色	
		lngw_fore = BizEnum.COLORCONFIG.LIUNIANGONGWEI.color, //	流年宫位前景色	
		lngw_bg = BizEnum.COLORCONFIG.LIUNIANGONGWEI.bgcolor, //	流年宫位背景色	
		lygw_fore = BizEnum.COLORCONFIG.LIUYUEGONGWEI.color, //	流月宫位前景色	
		lygw_bg = BizEnum.COLORCONFIG.LIUYUEGONGWEI.bgcolor, //	流月宫位背景色	
		lrgw_fore = BizEnum.COLORCONFIG.LIURIGONGWEI.color, //	流日宫位前景色	
		lrgw_bg = BizEnum.COLORCONFIG.LIURIGONGWEI.bgcolor, //	流日宫位背景色	
		lsgw_fore = BizEnum.COLORCONFIG.LIUSHIGONGWEI.color, //	流时宫位前景色	
		lsgw_bg = BizEnum.COLORCONFIG.LIUSHIGONGWEI.bgcolor, //	流时宫位背景色	
		yunyao_fore = BizEnum.COLORCONFIG.YUNYAO.color, //	运曜前景色	
		yunyao_bg = BizEnum.COLORCONFIG.YUNYAO.bgcolor, //	运曜背景色	
		liuyao_fore = BizEnum.COLORCONFIG.LIUYAO.color, //	流曜前景色	
		liuyao_bg = BizEnum.COLORCONFIG.LIUYAO.bgcolor, //	流曜背景色	
		xtsh_fore = BizEnum.COLORCONFIG.XIANTIANSIHUA.color, //	先天四化前景色	
		xtsh_bg = BizEnum.COLORCONFIG.XIANTIANSIHUA.bgcolor, //	先天四化背景色	
		dysh_fore = BizEnum.COLORCONFIG.DAYUNSIHUA.color, //	大运四化前景色	
		dysh_bg = BizEnum.COLORCONFIG.DAYUNSIHUA.bgcolor, //	大运四化背景色	
		lnsh_fore = BizEnum.COLORCONFIG.LIUNIANSIHUA.color, //	流年四化前景色	
		lnsh_bg = BizEnum.COLORCONFIG.LIUNIANSIHUA.bgcolor, //	流年四化背景色 	
		lysh_fore = BizEnum.COLORCONFIG.LIUYUESIHUA.color, //	流月四化前景色	
		lysh_bg = BizEnum.COLORCONFIG.LIUYUESIHUA.bgcolor, //	流月四化背景色	
		lrsh_fore = BizEnum.COLORCONFIG.LIURISIHUA.color, //	流日四化前景色	
		lrsh_bg = BizEnum.COLORCONFIG.LIURISIHUA.bgcolor, //	流日四化背景色	
		lsss_fore = BizEnum.COLORCONFIG.LIUSHISIHUA.color, //	流时四化前景色	
		lsss_bg = BizEnum.COLORCONFIG.LIUSHISIHUA.bgcolor, //	流时四化背景色	
		shengong_fore = BizEnum.COLORCONFIG.SHENGONG.color, //	身宫前景色	
		shengong_bg = BizEnum.COLORCONFIG.SHENGONG.bgcolor, //	身宫背景色	
		xiaoxian_fore = BizEnum.COLORCONFIG.XIAOXIAN.color, //	小限前景色	
		xiaoxian_bg = BizEnum.COLORCONFIG.XIAOXIAN.bgcolor, //	小限背景色	
		dyage_fore = BizEnum.COLORCONFIG.AGEPERIOD.color, //	大运年龄前景色	
		dyage_bg = BizEnum.COLORCONFIG.AGEPERIOD.bgcolor, //	大运年龄背景色	
		month_fore = BizEnum.COLORCONFIG.LIUNIANYUE.color, //	月份前景色	
		month_bg = BizEnum.COLORCONFIG.LIUNIANYUE.bgcolor, //	月份背景色	
		tiangan_fore = BizEnum.COLORCONFIG.TIANGAN.color, //	天干前景色	
		tiangan_bg = BizEnum.COLORCONFIG.TIANGAN.bgcolor, //	天干背景色	
		dizhi_fore = BizEnum.COLORCONFIG.DIZHI.color, //	地支前景色	
		dizhi_bg = BizEnum.COLORCONFIG.DIZHI.bgcolor, //	地支背景色
		miaowang_fore = BizEnum.COLORCONFIG.MIAOWANG.color,
		miaowang_bg = BizEnum.COLORCONFIG.MIAOWANG.bgcolor,
		changsheng_fore = BizEnum.COLORCONFIG.CHANGSHENG.color,
		changsheng_bg = BizEnum.COLORCONFIG.CHANGSHENG.bgcolor,
		tssl_fore = BizEnum.COLORCONFIG.TAISUISHALU.color,
		tssl_bg = BizEnum.COLORCONFIG.TAISUISHALU.bgcolor,
		lnsq_fore = BizEnum.COLORCONFIG.LIUNIANSUIQIAN.color,
		lnsq_bg = BizEnum.COLORCONFIG.LIUNIANSUIQIAN.bgcolor,
		lnjq_fore = BizEnum.COLORCONFIG.LIUNIANJIANGQIAN.color,
		lnjq_bg = BizEnum.COLORCONFIG.LIUNIANJIANGQIAN.bgcolor;
		
		
		return {
			"tssl_fore" : tssl_fore,
			"tssl_bg" : tssl_bg,
            "lnsq_fore" : lnsq_fore,
            "lnsq_bg" : lnsq_bg,
            "lnjq_fore" :  lnjq_fore,
            "lnjq_bg" :  lnjq_bg,
			"miaowang_fore" : miaowang_fore,
			"miaowang_bg" : miaowang_bg,
            "xtgw_fore" : xtgw_fore,
            "xtgw_bg" : xtgw_bg,
            "dygw_fore" :  dygw_fore,
            "dygw_bg" :  dygw_bg,
            "lngw_fore" : lngw_fore, 
            "lngw_bg" :  lngw_bg,
            "lygw_fore" :  lygw_fore,
            "lygw_bg" :  lygw_bg,
            "lrgw_fore"  :  lrgw_fore, 
            "lrgw_bg" :  lrgw_bg,
            "lsgw_fore"  : lsgw_fore,
            "lsgw_bg" :  lsgw_bg,
            "yunyao_fore" : yunyao_fore,
            "yunyao_bg" : yunyao_bg,
            "liuyao_fore" : liuyao_fore,
            "liuyao_bg" : liuyao_bg, 
            "xtsh_fore" :  xtsh_fore,
            "xtsh_bg" : xtsh_bg,
            "dysh_fore" :  dysh_fore,
            "dysh_bg" :  dysh_bg,
            "lnsh_fore" :  lnsh_fore,
            "lnsh_bg" : lnsh_bg,
            "lysh_fore" :  lysh_fore,
            "lysh_bg" : lysh_bg,
            "lrsh_fore" : lrsh_fore, 
            "lrsh_bg" : lrsh_bg,
            "lsss_fore" : lsss_fore,
            "lsss_bg" : lsss_bg,
            "shengong_fore" : shengong_fore,
            "shengong_bg" : shengong_bg, 
            "xiaoxian_fore" :  xiaoxian_fore,
            "xiaoxian_bg" : xiaoxian_bg, 
            "dyage_fore" : dyage_fore,
            "dyage_bg" :  dyage_bg,
            "month_fore" : month_fore, 
            "month_bg" :  month_bg,
            "tiangan_fore" : tiangan_fore,
            "tiangan_bg" : tiangan_bg, 
            "dizhi_fore" : dizhi_fore, 
            "dizhi_bg" : dizhi_bg,
			"changsheng_fore" : changsheng_fore,
			"changsheng_bg" : changsheng_bg
		};
 }
 
function compare(propertyName) {
    return function(object1, object2) {
      var value1 = object1[propertyName];
      var value2 = object2[propertyName];
      if (value2 < value1) {
        return 1;
      } else if (value2 > value1) {
        return -1;
      } else {
        return 0;
      }
    }
  } 
  
  
 function setSystemConfig(){
	if(arguments.length < 1){
		return false;
	}
	
	var param = arguments[0];
	
	try{
		eval("param = (" + param + ")");
	}catch(e){
		return false;
	}
	
	var wuGanSiHua = param.wugansihua;
	var gengGanSiHua = param.genggansihua;
	var renGanSiHua = param.rengansihua;
	var tianmaStar = param.tianmacfg;
	var runYue = param.runyue;
	var miaowang = param.miaowang;
	
	if(!wuGanSiHua){
		wuGanSiHua = 0;
	}
	
	wuGanSiHua = parseInt(wuGanSiHua);
	
	if(!(wuGanSiHua != 0 || wuGanSiHua != 1)){
		wuGanSiHua = 0;
	}
	
	if(!gengGanSiHua){
		gengGanSiHua = 0;
	}
	
	gengGanSiHua = parseInt(gengGanSiHua);
	
	if(!(gengGanSiHua != 0 || gengGanSiHua != 1 || gengGanSiHua != 2)){
		gengGanSiHua = 0;
	}
	
	if(!renGanSiHua){
		renGanSiHua = 0;
	}
	
	renGanSiHua = parseInt(renGanSiHua);
	
	if(!(renGanSiHua != 0 || renGanSiHua != 1)){
		renGanSiHua = 0;
	}
	
	if(!tianmaStar){
		tianmaStar = 0;
	}
	
	tianmaStar = parseInt(tianmaStar);
	
	if(!(tianmaStar != 0 || tianmaStar != 1)){
		tianmaStar = 0;
	}
	
	if(!runYue){
		runYue = 0;
	}
	
	runYue = parseInt(runYue);
	
	if(!(runYue != 0 || runYue != 1)){
		runYue = 0;
	}
	
	if(!miaowang){
		miaowang = 0;
	}
	
	miaowang = parseInt(miaowang);
	
	if(!(miaowang != 0 || miaowang != 1)){
		miaowang = 0;
	}
	
	var sysCfg = SystemConfig.newInstance();
	
	sysCfg.setSiHuaOfWu(wuGanSiHua);
	sysCfg.setSiHuaOfGeng(gengGanSiHua);
	sysCfg.setSiHuaOfRen(renGanSiHua);
	sysCfg.setTianMaStarConfig(tianmaStar);
	sysCfg.setRunYueConfig(runYue);
	sysCfg.showMiaoWang(0,0,0,miaowang);
	
	return SystemConfig.setConfig(sysCfg);
 }  
