/**
 * Interface.js
 * 紫微排盘接口类，对外暴露方法
 *
 * @date 2014-01-12
 * @version 0.1
 */

 /**
  * 保存用户基本信息
  */
 function saveUserBasicInfo(args){
	args = args.split(",");

	if(args.length < 6){
		return false;
	}

	var language = args[0];
	var username = args[1];
	var gender = args[2];
	var year = args[3];
	var month = args[4];
	var day = args[5];
	var hour = args[6].charAt(0);
	var isLunarDate = false;
	var isRunYue = false;

	if(args.length == 8){
		isLunarDate = args[7];
	}

	if(!(username && gender && year && month && day && hour)){
		return false;
	}

	if(!(gender == "男" || gender == "女")){
		return false;
	}

	if(year < 1901 || year > 2099){
		return false;
	}

	if(month < 1 || month > 12){
		return false;
	}

	if(day < 1 || day > 31){
		return false;
	}

	if(language != 1){
		language = 0;
	}


	if(isLunarDate){
		if(month.indexOf("闰") >= 0){
			isRunYue = true;
			month = month.replace("闰", "");
		}

		month = Util.convertLunarMonthStr2Integer(month);
		day = Util.convertLunarDayStr2Integer(day);

	}

	switch(hour){
		case "子" : hour = "DZ_ZI"; break;
		case "丑" : hour = "DZ_CHOU"; break;
		case "寅" : hour = "DZ_YIN"; break;
		case "卯" : hour = "DZ_MAO"; break;
		case "辰" : hour = "DZ_CHEN"; break;
		case "巳" : hour = "DZ_SI"; break;
		case "午" : hour = "DZ_WU"; break;
		case "未" : hour = "DZ_WEI"; break;
		case "申" : hour = "DZ_SHEN"; break;
		case "酉" : hour = "DZ_YOU"; break;
		case "戌" : hour = "DZ_XU"; break;
		case "亥" : hour = "DZ_HAI"; break;
		default : hour = "DZ_ZI"; break;
	}

	year = parseInt(year);
	month = parseInt(month);
	day = parseInt(day);
	hour = Util.getHourByLunarStr(hour);

	var user = User.newInstance(username, gender, year, month, day, hour, isLunarDate, isRunYue);

	window.taxen = new Object();

	window.taxen.ziwei = new Object();

	window.taxen.ziwei.users = new Array();

	window.taxen.ziwei.users.push({
		"languageConfig" : language,
		"user" : user
	});

	return user.getToken();
 }

 /**
  * 获取用户信息
  */
 function getUserInfo(userToken){
    if(!userToken){
		return false;
	}

	for(var i = 0 ; i < window.taxen.ziwei.users.length; i ++){
		if(userToken == window.taxen.ziwei.users[i].user.getToken()){
			var user = window.taxen.ziwei.users[i].user;
			var xianTianMingPan = user.getXianTianMingPan();
			var language = window.taxen.ziwei.users[i].languageConfig;
			var usrInfo = user.getUserInfo();

			var name = usrInfo.getName();
			var gender = usrInfo.getGender();
			var genderDescriptor = usrInfo.getGenderDescriptor();
			var birthDate = usrInfo.getBirthday();
			var birthday = birthDate.getYear() + "-" + birthDate.getMonth() + "-" + birthDate.getDay() + "-" + Util.getLunarHour(birthDate.getHour());
			var lunarBirthday = birthDate.getLunarYear() + "-" + (birthDate.isLunarRunYue() ? "闰" : "") + birthDate.getLunarMonth().index + "-" + birthDate.getLunarDay().index + "-" + Util.getLunarHour(birthDate.getHour());
			var bazi = usrInfo.getBaZi();
			var mingJu = usrInfo.getMingJu().name;

			var result = {
				"name" : name,
				"gender" : gender,
				"genderDescriptor" : genderDescriptor,
				"birthday" : birthday,
				"lunarBirthday" : lunarBirthday,
				"zodiac" : Util.getZodiacByDiZhi(bazi.nianZhu.split("$")[1]),
				"bazi" : bazi.nianZhu + "-" + bazi.yueZhu + "-" + bazi.riZhu + "-" + bazi.shiZhu,
				"mingJu" : mingJu

			};

			result = Translator.translateObject(result, language);
			result.mingJu += "|" + user.getUserInfo().getMingJu().index;

			return result;
		}
	}

	return false;
 }

 /**
  *  获取先天命盘中12宫位之一
  */
 function getXianTianMingPanSection(args){
	args = args.split(",");

	if(args.length == 0){
		return false;
	}

	var userToken = args[0];
	var index = 0;

	if(args.length > 1){
		index = parseInt(args[1]);
	}

	if(!userToken || index < 0 || index > 11){
		return false;
	}

	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		if(userToken == window.taxen.ziwei.users[i].user.getToken()){
			var user = window.taxen.ziwei.users[i].user;
			var language = window.taxen.ziwei.users[i].languageConfig;
			var xianTianMingPan = user.getXianTianMingPan();

			var items = xianTianMingPan.getItems();

			var item =  items[index];

			var index = item.getIndex();
			var tianGan = item.getTianGan();
			var diZhi = item.getDiZhi();
			var gongWei = item.getGongWei();
			var daXianBeginYear = item.getAgePeriod().begin;
			var daXianEndYear = item.getAgePeriod().end;
			var changSheng = item.getChangSheng12Shen();
			var taiSuiShaLu = item.getTaiSuiShaLu();
			var liuNianSuiQian = item.getLiuNianSuiQian();
			var liuNianJiangQian = item.getLiuNianJiangQian();
			var mingZhu = xianTianMingPan.getMingZhu();
			var shenZhu = xianTianMingPan.getShenZhu();
			var mingJu = user.getUserInfo().getMingJu().name;

			var mingGongIndex = xianTianMingPan.getMingGongIndex();
			var mingGongItem = items[mingGongIndex];
			var mingGongDiZhi = mingGongItem.getDiZhi();

			var stars = mingGongItem.getStars();
			var mingGongMainStarNameArray = new Array();
			for(var i = 0 ; i < stars.length; i ++){
				if(stars[i].getName().indexOf("MAINSTAR_") == 0){
					mingGongMainStarNameArray.push(stars[i].getName());
				}
			}

			if(mingGongMainStarNameArray.length == 0){
				mingGongItem = items[(mingGongIndex - 6 + 12) % 12];
				stars = mingGongItem.getStars();

				for(var i = 0 ; i < stars.length; i ++){
					if(stars[i].getName().indexOf("MAINSTAR_") == 0){
						mingGongMainStarNameArray.push(stars[i].getName());
					}
				}
			}

			mingGongMainStarNameArray.push(mingGongDiZhi);

			var result =  {
				"index" : index,
				"tianGan" : tianGan,
				"diZhi" : diZhi,
				"gongWei" : gongWei,
				"daXianBeginYear" : daXianBeginYear,
				"daXianEndYear" : daXianEndYear,
				"changSheng" : changSheng,
				"taiSuiShaLu" : taiSuiShaLu,
				"liuNianSuiQian" : liuNianSuiQian,
				"liuNianJiangQian" : liuNianJiangQian,
				"mingZhu" : mingZhu,
				"shenZhu" : shenZhu,
				"mingJu" : mingJu,
				"mingGong" : mingGongMainStarNameArray.join(" ")
			};

			result = Translator.translateObject(result, language);

			result.mingJu += "|" + user.getUserInfo().getMingJu().index;

            console.log("xiantain---->"+JSON.stringify(result));
			return result;
		}
	}

	return false;
 }

 /**
  * 获取先天命盘中12宫位之一的星星
  */
 function getXianTianMingPanSectionStars(args){
	args = args.split(",");

	if(args.length == 0){
		return false;
	}

	var userToken = args[0];
	var index = 0;

	if(args.length > 1){
		index = parseInt(args[1]);
	}

	if(!userToken || index < 0 || index > 11){
		return false;
	}

	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		if(userToken == window.taxen.ziwei.users[i].user.getToken()){
			var xianTianMingPan = window.taxen.ziwei.users[i].user.getXianTianMingPan();
			var language = window.taxen.ziwei.users[i].languageConfig;
			var items = xianTianMingPan.getItems();

			var item =  items[index];

			var stars = item.getStars();

			var starArray = new Array();
			var normalStarCfg = (SystemConfig.getConfig())._normalStarMiaoWang;

			for(var i = 0 ; i < stars.length; i ++){
				var star = stars[i];

				var starArrayItem = new Object();
				starArrayItem.index = i + 1;
				starArrayItem.name = star.getName();

				if(starArrayItem.name.indexOf("NORMALSTAR_") >= 0 && normalStarCfg == 'OFF'){
					starArrayItem.descriptor = false;
				}else{
					starArrayItem.descriptor = star.getDescriptor();
				}

				var color = ColorConfig.getStarColor(star.getName());
				starArrayItem.color = color.color;
				starArrayItem.bgcolor = color.bgcolor;
				starArrayItem.siHua = star.getSiXiang();

				starArrayItem = Translator.translateObject(starArrayItem, language);

				starArray.push(starArrayItem);
			}

			return starArray;
		}
	}

	return false;
 }

 /**
  * 获取流年命盘中12宫位之一
  */
 function getLiuNianMingPanSection(args){
	if(!args){
		return false;
	}

	var parts = args.split(",");

	if(parts.length < 3){
		return false;
	}

	var userToken = parts[0], year = parts[1], index = parts[2];

	year = parseInt(year);
	index = parseInt(index);

	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userConfig = window.taxen.ziwei.users[i];
		var language = userConfig.languageConfig;
		var user = userConfig.user;

		if(userToken == user.getToken()){
			var birthYear = user.getUserInfo().getBirthday().getLunarYear();

			if(birthYear > year || (birthYear + 120 < year)){
				return false;
			}

			var liuNianMingPan = user.getLiuNianMingPan(year);

			var items = liuNianMingPan.getItems();

			var item = items[index];

			var index = item.getIndex();
			var tianGan = item.getTianGan();
			var diZhi = item.getDiZhi();
			var gongWei = item.getGongWei();
			var month = item.getMonth().name;
			var changSheng = item.getChangSheng12Shen();
			var daYunGongWei = item.getDaYunGongWei();
			var liuNianGongWei = item.getLiuNianGongWei();
			var taiSuiShaLu = item.getTaiSuiShaLu();
			var liuNianSuiQian = item.getLiuNianSuiQian();
			var liuNianJiangQian = item.getLiuNianJiangQian();
			var xuSui = liuNianMingPan.getXuSui();
			var liuNian = year;
			var liuNianGanZhi = liuNianMingPan.getYearOfGanZhi();
			var liuNianDouJun = liuNianMingPan.getLiuNianDouJun();
			var xiaoXianIndex = liuNianMingPan.getXiaoXianIndex();

			var result = {
				"index" : index,
				"tianGan" : tianGan,
				"diZhi" : diZhi,
				"gongWei" : gongWei,
				"month" : month,
				"changSheng" : changSheng,
				"daYunGongWei" : daYunGongWei,
				"liuNianGongWei" : liuNianGongWei,
				"taiSuiShaLu" : taiSuiShaLu,
				"liuNianSuiQian" : liuNianSuiQian,
				"liuNianJiangQian" : liuNianJiangQian,
				"xuSui" : xuSui,
				"liuNian" : liuNian,
				"liuNianGanZhi" : liuNianGanZhi,
				"liuNianDouJun" : liuNianDouJun,
				"xiaoXianIndex" : xiaoXianIndex
			};

			result = Translator.translateObject(result, language);

			return result;
		}
	}

	return result;
 }

 /**
  * 获取流年命盘中12宫位之一的星星
  */
 function getLiuNianMingPanSectionStars(args){
	args = args.split(",");

	if(args.length == 0){
		return false;
	}

	var userToken = args[0];
	var index = 0;

	if(args.length > 1){
		index = parseInt(args[1]);
	}

	if(!userToken || index < 0 || index > 11){
		return false;
	}

	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		if(userToken == window.taxen.ziwei.users[i].user.getToken()){
			var userConfig = window.taxen.ziwei.users[i];

			var liuNianMingPan = userConfig.user.getLiuNianMingPan();
			var language = userConfig.languageConfig;

			var items = liuNianMingPan.getItems();

			var item =  items[index];

			var stars = item.getStars();

			var starArray = new Array();
			var normalStarCfg = (SystemConfig.getConfig())._normalStarMiaoWang;

			for(var i = 0 ; i < stars.length; i ++){
				var star = stars[i];

				var starArrayItem = new Object();
				starArrayItem.index = i + 1;
				starArrayItem.name = star.getName();

				if(starArrayItem.name.indexOf("NORMALSTAR_") >= 0 && normalStarCfg == 'OFF'){
					starArrayItem.descriptor = false;
				}else{
					starArrayItem.descriptor = star.getDescriptor();
				}

				var color = ColorConfig.getStarColor(star.getName());
				starArrayItem.color = color.color;
				starArrayItem.bgcolor = color.bgcolor;
				starArrayItem.siHua = star.getSiXiang();
				starArrayItem.daYunSiHua = star.getSiHuaOfDaYun();
				starArrayItem.liuNianSiHua = star.getSiHuaOfLiuNian();

				starArrayItem = Translator.translateObject(starArrayItem, language);

				starArray.push(starArrayItem);
			}

			return starArray;
		}
	}

	return false;
 }

 /**
  * 获取流年命盘中12宫位之一的流曜和运曜
  */
 function getLiuNianMingPanSectionXingYao(args){
	args = args.split(",");

	if(args.length < 2){
		return false;
	}

	var userToken = args[0];
	var type = parseInt(args[1]);

	type = (type != 1)? 0 : 1;

	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		if(userToken == window.taxen.ziwei.users[i].user.getToken()){
			var userConfig = window.taxen.ziwei.users[i];

			var liuNianMingPan = userConfig.user.getLiuNianMingPan();
			var language = userConfig.languageConfig;

			var items = liuNianMingPan.getItems();

			var result = new Array();
			for(var j = 0; j < items.length; j++){
				var item = items[j];
				var gongWei = item.getIndex() - 1;
				var resultItem = new Object();

				resultItem.gongWei = gongWei;
				resultItem.starArray = new Array();

				var stars = false;
				if(type == 1){
					stars = item.getDaYunStars();
				}else{
					stars = item.getLiuNianStars();
				}

				if(stars){
					for(var m = 0; m < stars.length; m ++){
						var star = stars[m];

						var xingYao = new Object();
						xingYao.name = star.starName;
						xingYao.shortName = star.shortName;

						xingYao = Translator.translateObject(xingYao, language);

						resultItem.starArray.push(xingYao);
					}
				}

				result.push(resultItem);
			}

			return result;
		}
	}

	return false;
 }

 /**
  * 获取大运命盘的某一宫位
  */
 function getDaYunMingPanSection(args){
	if(!args){
		return false;
	}

	var parts = args.split(",");

	if(parts.length < 3){
		return false;
	}

	var userToken = parts[0];
	var step = parseInt(parts[1]);
	var index = parseInt(parts[2]);

	if(step < 1 || step > 12){
		step = 1;
	}

	if(index < 0 || index > 11){
		index = 0;
	}

	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];

		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;

			var daYunMingPan = userCfg.user.getDaYunMingPan(step);

			var items = daYunMingPan.getItems();

			var item = items[index];

			var index = item.getIndex();
			var tianGan	= item.getTianGan();
			var diZhi = item.getDiZhi();
			var gongWei	= item.getGongWei();
			var agePeriod_begin	= item.getDaYunAgePeriod().begin;
			var agePeriod_end = item.getDaYunAgePeriod().end;
			var daYunGongWei = item.getDaYunGongWei();
			var changSheng = item.getChangSheng12Shen();
			var hasYunYao = item.getDaYunStars() ? 'true' : 'false';
			var xuSui = daYunMingPan.getXuSui();
			var liuNian	= daYunMingPan.getYear();
			var liuNianGanZhi = daYunMingPan.getYearOfGanZhi();
			var liuNianDouJun = daYunMingPan.getLiuNianDouJun().toString();

			var result = {
				"index" : index,
				"tianGan" : tianGan,
				"diZhi" : diZhi,
				"gongWei" :	gongWei,
				"agePeriod_begin" :	agePeriod_begin,
				"agePeriod_end" : agePeriod_end,
				"daYunGongWei" : daYunGongWei,
				"changSheng" :	changSheng,
				"hasYunYao" : hasYunYao,
				"xuSui" : xuSui,
				"liuNian" : liuNian,
				"liuNianGanZhi" : liuNianGanZhi,
				"liuNianDouJun" : liuNianDouJun
			};

			result = Translator.translateObject(result, language);
			return result;
		}
	}

	return false;
 }

 function getDaYunMingPanSectionStars(args){
	if(!args){
		return false;
	}

	args = args.split(",");

	if(args.length < 2){
		return false;
	}

	var userToken = args[0];
	var index = parseInt(args[1]);

	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];

		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;

			var daYunMingPan = userCfg.user.getDaYunMingPan();

			var items = daYunMingPan.getItems();

			var item = items[index];

			var stars = item.getStars();

			var starArray = new Array();
			var normalStarCfg = (SystemConfig.getConfig())._normalStarMiaoWang;

			for(var i = 0 ; i < stars.length; i ++){
				var star = stars[i];

				var starArrayItem = new Object();
				starArrayItem.index = i + 1;
				starArrayItem.name = star.getName();

				if(starArrayItem.name.indexOf("NORMALSTAR_") && normalStarCfg == 'OFF'){
					starArrayItem.descriptor = 'false';
				}else{
					starArrayItem.descriptor = star.getDescriptor();
				}

				var color = ColorConfig.getStarColor(star.getName());
				starArrayItem.color = color.color;
				starArrayItem.bgcolor = color.bgcolor;
				starArrayItem.siHua = star.getSiXiang().toString();
				starArrayItem.daYunSiHua = star.getSiHuaOfDaYun().toString();

				starArrayItem = Translator.translateObject(starArrayItem, language);

				starArray.push(starArrayItem);
			}
			return starArray;
		}
	}
 }

 /**
  * 获取大运命盘中一个宫位内的星曜
  */
 function getDaYunMingPanSectionXingYao(args){
	if(!args){
		return false;
	}

	args = args.split(",");

	if(args.length < 1){
		return false;
	}

	var userToken = args[0];

	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userConfig = window.taxen.ziwei.users[i];

		if(userToken == userConfig.user.getToken()){
			var daYunMingPan = userConfig.user.getDaYunMingPan();
			var language = userConfig.languageConfig;

			var items = daYunMingPan.getItems();

			var result = new Array();
			for(var j = 0; j < items.length; j++){
				var item = items[j];
				var gongWei = item.getIndex() - 1;
				var resultItem = new Object();

				resultItem.gongWei = gongWei;
				resultItem.starArray = new Array();

				var stars = item.getDaYunStars();

				if(stars){
					for(var m = 0; m < stars.length; m ++){
						var star = stars[m];

						var xingYao = new Object();
						xingYao.name = star.starName;
						xingYao.shortName = star.shortName;

						xingYao = Translator.translateObject(xingYao, language);

						resultItem.starArray.push(xingYao);
					}
				}

				result.push(resultItem);
			}

			return result;
		}
	}

	return false;
 }

 function getLiuYueMingPanSection(args){
	if(!args){
		return false;
	}

	args = args.split(",");

	if(args.length < 4){
		return false;
	}

	var userToken = args[0];
	var year = parseInt(args[1]);
	var month = args[2];
	var index = parseInt(args[3]);
	var isLunarMonth = false;

	if(year < 1901 || year > 2099){
		year = new Date().getFullYear();
	}

	if(month.indexOf("闰") >= 0){
		isLunarMonth = true;

		month = month.replace("闰", "");
	}

	month = Util.convertLunarMonthStr2Integer(month);

	if(month < 1 || month > 12){
		month = 1;
	}

	if(index < 0 || index > 11){
		index = 0;
	}

	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];

		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;

			var liuYueMingPan = userCfg.user.getLiuYueMingPan(year, month, isLunarMonth);

			var item = liuYueMingPan.getItems()[index];

			var index = item.getIndex();
			var tianGan = item.getTianGan();
			var diZhi = item.getDiZhi();
			var gongWei	= item.getGongWei();
			var month = item.getMonth().name;
			var changSheng	= item.getChangSheng12Shen();
			var daYunGongWei = item.getDaYunGongWei();
			var liuNianGongWei = item.getLiuNianGongWei();
			var taiSuiShaLu	= item.getTaiSuiShaLu();
			var liuNianSuiQian	= item.getLiuNianSuiQian();
			var liuNianJiangQian = item.getLiuNianJiangQian();
			var liuYueGongWei = item.getMonthGongWei();
			var liuYueGanZhi = liuYueMingPan.monthOfGanZhi;
			var xiaoXianIndex = liuYueMingPan.getXiaoXianIndex();

			var result = {
                "index" : index,
                "tianGan" : tianGan,
                "diZhi" : diZhi,
                "gongWei" : gongWei,
                "month" : month,
                "changSheng" : 	changSheng,
                "daYunGongWei" : daYunGongWei,
                "liuNianGongWei" : 	liuNianGongWei,
                "taiSuiShaLu" : taiSuiShaLu,
                "liuNianSuiQian" : 	liuNianSuiQian,
                "liuNianJiangQian" :  liuNianJiangQian,
				"liuYueGongWei" : liuYueGongWei,
				"liuYueGanZhi" : liuYueGanZhi,
				"xuSui" : liuYueMingPan.getXuSui(),
				"liuNianDouJun" : liuYueMingPan.getLiuNianDouJun(),
				"xiaoXianIndex" : xiaoXianIndex
			};

			result = Translator.translateObject(result, language);

			return result;
		}
	}
 }

 function getLiuYueMingPanSectionStars(args){
	if(!args){
		return false;
	}

	args = args.split(",");

	if(args.length < 2){
		return false;
	}

	var userToken = args[0];
	var index = parseInt(args[1]);

	if(index < 0 || index > 11){
		index = 0;
	}

	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];

		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;

			var liuYueMingPan = userCfg.user.getLiuYueMingPan();

			var item = liuYueMingPan.getItems()[index];

			var stars = item.getStars();

			var resultArray = new Array();
			var normalStarCfg = (SystemConfig.getConfig())._normalStarMiaoWang;

			for(var i = 0 ; i < stars.length; i ++){
				var star = stars[i];

				var starArrayItem = new Object();
				starArrayItem.index = i + 1;
				starArrayItem.name = star.getName();

				if(starArrayItem.name.indexOf("NORMALSTAR_") >= 0 && normalStarCfg == 'OFF'){
					starArrayItem.descriptor = false;
				}else{
					starArrayItem.descriptor = star.getDescriptor();
				}

				var color = ColorConfig.getStarColor(star.getName());
				starArrayItem.color = color.color;
				starArrayItem.bgcolor = color.bgcolor;
				starArrayItem.siHua = star.getSiXiang();
				starArrayItem.daYunSiHua = star.getSiHuaOfDaYun();
				starArrayItem.liuNianSiHua = star.getSiHuaOfLiuNian();
				starArrayItem.liuYueSiHua = star.getSiHuaOfLiuYue();

				starArrayItem = Translator.translateObject(starArrayItem, language);

				resultArray.push(starArrayItem);
			}

			return resultArray;
		}
	}

	return false;
 }

 function getLiuYueMingPanSectionXingYao(args){
	if(!args){
		return false;
	}

	args = args.split(",");

	if(args.length < 2){
		return false;
	}

	var userToken = args[0];
	var type = parseInt(args[1]);

	type = (type != 1)? 0 : 1;

	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userConfig = window.taxen.ziwei.users[i];
		if(userToken == userConfig.user.getToken()){
			var liuYueMingPan = userConfig.user.getLiuYueMingPan();
			var language = userConfig.languageConfig;

			var items = liuYueMingPan.getItems();

			var result = new Array();
			for(var j = 0; j < items.length; j++){
				var item = items[j];
				var gongWei = item.getIndex() - 1;
				var resultItem = new Object();

				resultItem.gongWei = gongWei;
				resultItem.starArray = new Array();

				var stars = false;

				if(type == 1){
					stars = item.getDaYunStars();
				}else{
					stars = item.getLiuNianStars();
				}

				if(stars){
					for(var m = 0; m < stars.length; m ++){
						var star = stars[m];

						var xingYao = new Object();
						xingYao.name = star.starName;
						xingYao.shortName = star.shortName;

						xingYao = Translator.translateObject(xingYao, language);

						resultItem.starArray.push(xingYao);
					}
				}

				result.push(resultItem);
			}

			return result;
		}
	}

	return false;
 }

 function getLiuRiMingPanSection(args){
	if(!args){
		return false;
	}

	args = args.split(",");

	if(args.length < 5){
		return false;
	}

	var userToken = args[0];
	var year = parseInt(args[1]);
	var month = args[2];
	var day = Util.convertLunarDayStr2Integer(args[3]);
	var index = parseInt(args[4]);
	var isLunarMonth = false;

	if(year < 1901 || year > 2099){
		year = new Date().getFullYear();
	}

	if(month.indexOf("闰") >= 0){
		isLunarMonth = true;

		month = month.replace("闰", "");
	}

	month = Util.convertLunarMonthStr2Integer(month);

	if(month < 1 || month > 12){
		month = 1;
	}

	if(index < 0 || index > 11){
		index = 0;
	}


	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];

		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;

			var liuRiMingPan = userCfg.user.getLiuRiMingPan(year, month, day, isLunarMonth);

			var item = liuRiMingPan.getItems()[index];

			var index = item.getIndex();
			var tianGan = item.getTianGan();
			var diZhi = item.getDiZhi();
			var gongWei	= item.getGongWei();
			var month = item.getMonth().name;
			var changSheng	= item.getChangSheng12Shen();
			var daYunGongWei = item.getDaYunGongWei();
			var liuNianGongWei = item.getLiuNianGongWei();
			var liuYueGongWei = item.getMonthGongWei();
			var taiSuiShaLu	= item.getTaiSuiShaLu();
			var liuNianSuiQian	= item.getLiuNianSuiQian();
			var liuNianJiangQian = item.getLiuNianJiangQian();
			var liuRiGongWei = item.getDayGongWei();

            console.log("开始🐖--》"+"------------------------------------");
			var liuYueGongWeiIndex = Util.getIndexByGongWei(liuYueGongWei);
            if(liuYueGongWeiIndex != 0){
                liuYueGongWeiIndex = 12 - liuYueGongWeiIndex;
            }
            var dateInfo = liuRiMingPan.dateInfoArray[liuYueGongWeiIndex];

            console.log("开始🐖--》"+dateInfo);

			var liuNianGanZhi = liuRiMingPan.getYearOfGanZhi();
			var liuYueGanZhi = liuRiMingPan.monthOfGanZhi;
			var liuRiGanZhi = liuRiMingPan.dayOfGanZhi;
			var xiaoXianIndex = liuRiMingPan.getXiaoXianIndex();

			var result = {
                "index" : index,
                "tianGan" : tianGan,
                "diZhi" : diZhi,
                "gongWei" : gongWei,
                "month" : month,
                "changSheng" : 	changSheng,
                "daYunGongWei" : daYunGongWei,
                "liuNianGongWei" : 	liuNianGongWei,
				"liuYueGongWei" : liuYueGongWei,
				"liuRiGongWei" : liuRiGongWei,
                "taiSuiShaLu" : taiSuiShaLu,
                "liuNianSuiQian" : 	liuNianSuiQian,
                "liuNianJiangQian" :  liuNianJiangQian,
				"liuNianGanZhi" : liuNianGanZhi,
		        "liuYueGanZhi" : liuYueGanZhi,
				"liuRiGanZhi" : liuRiGanZhi,
				"xuSui" : liuRiMingPan.getXuSui(),
				"liuNianDouJun" : liuRiMingPan.getLiuNianDouJun(),
				"xiaoXianIndex" : xiaoXianIndex,
				"dateInfo" : dateInfo
			};

			result = Translator.translateObject(result, language);

			return result;
		}
	}
 }

 function getLiuRiMingPanSectionStars(args){
	if(!args){
		return false;
	}

	args = args.split(",");

	if(args.length < 2){
		return false;
	}

	var userToken = args[0];
	var index = parseInt(args[1]);

	if(index < 0 || index > 11){
		index = 0;
	}

	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];

		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;

			var liuRiMingPan = userCfg.user.getLiuRiMingPan();

			var item = liuRiMingPan.getItems()[index];

			var stars = item.getStars();

			var resultArray = new Array();
			var normalStarCfg = (SystemConfig.getConfig())._normalStarMiaoWang;

			for(var i = 0 ; i < stars.length; i ++){
				var star = stars[i];

				var starArrayItem = new Object();
				starArrayItem.index = i + 1;
				starArrayItem.name = star.getName();

				if(starArrayItem.name.indexOf("NORMALSTAR_") >= 0 && normalStarCfg == 'OFF'){
					starArrayItem.descriptor = false;
				}else{
					starArrayItem.descriptor = star.getDescriptor();
				}

				var color = ColorConfig.getStarColor(star.getName());
				starArrayItem.color = color.color;
				starArrayItem.bgcolor = color.bgcolor;
				starArrayItem.siHua = star.getSiXiang();
				starArrayItem.daYunSiHua = star.getSiHuaOfDaYun();
				starArrayItem.liuNianSiHua = star.getSiHuaOfLiuNian();
				starArrayItem.liuYueSiHua = star.getSiHuaOfLiuYue();
				starArrayItem.liuRiSiHua = star.getSiHuaOfLiuRi();

				starArrayItem = Translator.translateObject(starArrayItem, language);

				resultArray.push(starArrayItem);
			}

			return resultArray;
		}
	}

	return false;
 }

 function getLiuRiMingPanSectionXingYao(args){
	if(!args){
		return false;
	}

	args = args.split(",");

	if(args.length < 2){
		return false;
	}

	var userToken = args[0];
	var type = parseInt(args[1]);

	type = (type != 1)? 0 : 1;

	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userConfig = window.taxen.ziwei.users[i];
		if(userToken == userConfig.user.getToken()){
			var liuRiMingPan = userConfig.user.getLiuRiMingPan();
			var language = userConfig.languageConfig;

			var items = liuRiMingPan.getItems();

			var result = new Array();
			for(var j = 0; j < items.length; j++){
				var item = items[j];
				var gongWei = item.getIndex() - 1;
				var resultItem = new Object();

				resultItem.gongWei = gongWei;
				resultItem.starArray = new Array();

				var stars = false;

				if(type == 1){
					stars = item.getDaYunStars();
				}else{
					stars = item.getLiuNianStars();
				}

				if(stars){
					for(var m = 0; m < stars.length; m ++){
						var star = stars[m];

						var xingYao = new Object();
						xingYao.name = star.starName;
						xingYao.shortName = star.shortName;

						xingYao = Translator.translateObject(xingYao, language);

						resultItem.starArray.push(xingYao);
					}
				}

				result.push(resultItem);
			}

			return result;
		}
	}

	return false;
 }

 function getLiuShiMingPanSection(args){
	if(!args){
		return false;
	}

	args = args.split(",");

	if(args.length < 6){
		return false;
	}

	var userToken = args[0];
	var year = parseInt(args[1]);
	var month = args[2];
	var day = Util.convertLunarDayStr2Integer(args[3]);
	var hour = args[4];
	var index = parseInt(args[5]);
	var isLunarRunYue = false;

	if(year < 1901 || year > 2099){
		year = new Date().getFullYear();
	}

	if(month.indexOf("闰") >= 0){
		isLunarRunYue = true;

		month = month.replace("闰", "");
	}

	month = Util.convertLunarMonthStr2Integer(month);

	if(month < 1 || month > 12){
		month = 1;
	}

	hour = Util.getHourByLunarStr(Util.parseLunarHour(hour.replace("时", "")));


	if(index < 0 || index > 11){
		index = 0;
	}

	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];

console.log("enter function---------ssdfasdfasdf---->"+userToken);

		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;

			var liuShiMingPan = userCfg.user.getLiuShiMingPan(year, month, day, hour, isLunarRunYue);



			console.log("enter function---------流时命盘--->"+liuShiMingPan);

			var item = liuShiMingPan.getItems()[index];


			console.log("enter function---------流时命盘--item------>"+item);

			var index = item.getIndex();
			var tianGan = item.getTianGan();
			var diZhi = item.getDiZhi();
			var gongWei	= item.getGongWei();
			var month = item.getMonth().name;
			var changSheng	= item.getChangSheng12Shen();
			var daYunGongWei = item.getDaYunGongWei();
			var liuNianGongWei = item.getLiuNianGongWei();
			var liuYueGongWei = item.getMonthGongWei();
			var liuRiGongWei = item.getDayGongWei();
			var liuShiGongWei = item.getHourGongWei();
			var taiSuiShaLu	= item.getTaiSuiShaLu();
			var liuNianSuiQian	= item.getLiuNianSuiQian();
			var liuNianJiangQian = item.getLiuNianJiangQian();
			var hour = item.getLunarHour();
			var liuNianGanZhi = liuShiMingPan.getYearOfGanZhi();
			var liuYueGanZhi = liuShiMingPan.monthOfGanZhi;
			var liuRiGanZhi = liuShiMingPan.dayOfGanZhi;
			var liuShiGanZHi = liuShiMingPan.hourOfGanZhi;

			var result = {
                "index" : index,
                "tianGan" : tianGan,
                "diZhi" : diZhi,
                "gongWei" : gongWei,
                "month" : month,
                "changSheng" : 	changSheng,
                "daYunGongWei" : daYunGongWei,
                "liuNianGongWei" : 	liuNianGongWei,
				"liuYueGongWei" : liuYueGongWei,
				"liuRiGongWei" : liuRiGongWei,
				"liuShiGongWei" : liuShiGongWei,
				"hour" : hour,
                "taiSuiShaLu" : taiSuiShaLu,
                "liuNianSuiQian" : 	liuNianSuiQian,
                "liuNianJiangQian" :  liuNianJiangQian,
				"liuNianGanZhi" : liuNianGanZhi,
		        "liuYueGanZhi" : liuYueGanZhi,
				"liuRiGanZhi" : liuRiGanZhi,
				"liuShiGanZhi" : liuShiGanZHi,
				"xuSui" : liuShiMingPan.getXuSui(),
				"liuNianDouJun" : liuShiMingPan.getLiuNianDouJun(),
				"xiaoXianIndex" : liuShiMingPan.getXiaoXianIndex()
			};

			result = Translator.translateObject(result, language);

			return result;
		}
	}

	return false;
 }

 function getLiuShiMingPanSectionStars(args){
	if(!args){
		return false;
	}

	args = args.split(",");

	if(args.length < 2){
		return false;
	}

	var userToken = args[0];
	var index = parseInt(args[1]);

	if(index < 0 || index > 11){
		index = 0;
	}

	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];

		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;

			var liuShiMingPan = userCfg.user.getLiuShiMingPan();
			var item = liuShiMingPan.getItems()[index];

			var stars = item.getStars();

			var resultArray = new Array();
			var normalStarCfg = (SystemConfig.getConfig())._normalStarMiaoWang;

			for(var i = 0 ; i < stars.length; i ++){
				var star = stars[i];

				var starArrayItem = new Object();
				starArrayItem.index = i + 1;
				starArrayItem.name = star.getName();

				if(starArrayItem.name.indexOf("NORMALSTAR_") >= 0 && normalStarCfg == 'OFF'){
					starArrayItem.descriptor = false;
				}else{
					starArrayItem.descriptor = star.getDescriptor();
				}

				var color = ColorConfig.getStarColor(star.getName());
				starArrayItem.color = color.color;
				starArrayItem.bgcolor = color.bgcolor;
				starArrayItem.siHua = star.getSiXiang();
				starArrayItem.daYunSiHua = star.getSiHuaOfDaYun();
				starArrayItem.liuNianSiHua = star.getSiHuaOfLiuNian();
				starArrayItem.liuYueSiHua = star.getSiHuaOfLiuYue();
				starArrayItem.liuRiSiHua = star.getSiHuaOfLiuRi();
				starArrayItem.liuShiSiHua = star.getSiHuaOfLiuShi();

				starArrayItem = Translator.translateObject(starArrayItem, language);

				resultArray.push(starArrayItem);
			}
        var ss = JSON.stringify(resultArray);
        console.log("xingxing"+ss);
			return resultArray;
		}

	}

	return false;
 }

 function getLiuShiMingPanSectionXingYao(args){
	if(!args){
		return false;
	}

	args = args.split(",");

	if(args.length < 2){
		return false;
	}

	var userToken = args[0];
	var type = parseInt(args[1]);

	type = (type != 1)? 0 : 1;

	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userConfig = window.taxen.ziwei.users[i];
		if(userToken == userConfig.user.getToken()){

		console.log("enter function------------->"+userToken);

			var liuShiMingPan = userConfig.user.getLiuShiMingPan();
			var language = userConfig.languageConfig;

			var items = liuShiMingPan.getItems();

			var result = new Array();
			for(var j = 0; j < items.length; j++){
				var item = items[j];
				var gongWei = item.getIndex() - 1;
				var resultItem = new Object();

				resultItem.gongWei = gongWei;
				resultItem.starArray = new Array();

				var stars = false;

				if(type == 1){
					stars = item.getDaYunStars();
				}else{
					stars = item.getLiuNianStars();
				}

				if(stars){
					for(var m = 0; m < stars.length; m ++){
						var star = stars[m];

						var xingYao = new Object();
						xingYao.name = star.starName;
						xingYao.shortName = star.shortName;

						xingYao = Translator.translateObject(xingYao, language);

						resultItem.starArray.push(xingYao);
					}
				}

				result.push(resultItem);
			}
			var ss = JSON.stringify(result);
            console.log("XingYao--->"+ss);
			return result;
		}
	}

	return false;
 }

 function getLiuFenMingPanSection(args){
 	if(!args){
		return false;
	}

	args = args.split(",");

	var hour = args[4];
	if(args.length < 7){
		return false;
	}


	var min = parseInt(args[5].replace("分",""));

	if(hour == '子时' && min < 60){
		var a = args[1]+","+args[2]+","+args[3]+","+"-";
		var time = convertLunarDate2GregorianDate_itf(a).split("-");
//ios需要获取前一天 安卓不要
//		var time = getPreGregorianDay(convertLunarDate2GregorianDate_itf(a)).split("-");
		console.log("时间----》"+time);

		if(time.length<3){
			return false;
		}
		hour = 23 ;
		var lunarDate = PerpetualCalendar.convertGregorianDate2LunarDate(time[0],time[1],time[2],hour);
		var isLunarRunYue = lunarDate.isRunYue;
		var year = parseInt(lunarDate.year);
		var month = parseInt(lunarDate.month);
		var day = parseInt(lunarDate.day);
	}else{
		var year = parseInt(args[1]);
		var month = args[2];
		var day = Util.convertLunarDayStr2Integer(args[3]);
		var isLunarRunYue = false;
		hour = Util.getHourByLunarStr(Util.parseLunarHour(hour.replace("时", "")));

		if(month.indexOf("闰") >= 0){
			isLunarRunYue = true;
			month = month.replace("闰", "");
		}

		month = Util.convertLunarMonthStr2Integer(month);
	}

	var userToken = args[0];
	var index = parseInt(args[6]);



	if(year < 1901 || year > 2099){
		year = new Date().getFullYear();
	}

	if(month < 1 || month > 12){
		month = 1;
	}


	if(min<0 || min >120){
		min = 0;
	}else{
		if(hour != 23){
			hour = hour -1 ;
		}
	}


	if(index < 0 || index > 11){
		index = 0;
	}

	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];

		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;

			var liuFenMingPan = userCfg.user.getLiuFenMingPan(year, month, day, hour,min,isLunarRunYue);
			var xtMingPan = userCfg.user.getXianTianMingPan();
            var daXianBeginYear = xtMingPan.getItems()[index].getAgePeriod().begin;
            var daXianEndYear = xtMingPan.getItems()[index].getAgePeriod().end;

			liuShiMingPan = userCfg.user.getLiuShiMingPan(year, month, day, hour, isLunarRunYue);

			var item = liuFenMingPan.getItems()[index];

			var index = item.getIndex();
			var tianGan = item.getTianGan();
			var diZhi = item.getDiZhi();
			var gongWei	= item.getGongWei();
			var month = item.getMonth().name;
			var changSheng	= item.getChangSheng12Shen();
			var daYunGongWei = item.getDaYunGongWei();
			var liuNianGongWei = item.getLiuNianGongWei();
			var liuYueGongWei = item.getMonthGongWei();
			var liuRiGongWei = item.getDayGongWei();
			var liuShiGongWei = item.getHourGongWei();
			var liuMinGongWei = item.getMinGongWei();
			var taiSuiShaLu	= item.getTaiSuiShaLu();
			var liuNianSuiQian	= item.getLiuNianSuiQian();
			var liuNianJiangQian = item.getLiuNianJiangQian();
			var hour = item.getLunarHour();
			var liuNianGanZhi = liuFenMingPan.getYearOfGanZhi();
			var liuYueGanZhi = liuFenMingPan.monthOfGanZhi;
			var liuRiGanZhi = liuFenMingPan.dayOfGanZhi;
			var liuShiGanZHi = liuFenMingPan.hourOfGanZhi;




			var result = {
                "index" : index,
                "tianGan" : tianGan,
                "diZhi" : diZhi,
                "gongWei" : gongWei,
                "month" : month,
                "changSheng" : 	changSheng,
                "daYunGongWei" : daYunGongWei,
                "liuNianGongWei" : 	liuNianGongWei,
				"liuYueGongWei" : liuYueGongWei,
				"liuRiGongWei" : liuRiGongWei,
				"liuShiGongWei" : liuShiGongWei,
				"liuMinGongWei" :liuMinGongWei,
				"hour" : hour,
				"min" : min,
                "taiSuiShaLu" : taiSuiShaLu,
                "liuNianSuiQian" : 	liuNianSuiQian,
                "liuNianJiangQian" :  liuNianJiangQian,
				"liuNianGanZhi" : liuNianGanZhi,
		        "liuYueGanZhi" : liuYueGanZhi,
				"liuRiGanZhi" : liuRiGanZhi,
				"liuShiGanZhi" : liuShiGanZHi,
				"xuSui" : liuFenMingPan.getXuSui(),
				"liuNianDouJun" : liuFenMingPan.getLiuNianDouJun(),
				"xiaoXianIndex" : liuFenMingPan.getXiaoXianIndex(),
				"daXianBeginYear" : daXianBeginYear,
				"daXianEndYear" : daXianEndYear
			};

			result = Translator.translateObject(result, language);
            var  ss = JSON.stringify(result);
            console.log(ss);
			return JSON.stringify(result);
		}
	}

	return false;
 }





 function modifySysFont(args){
	if(!args){
		return false;
	}

	var parts = args.split(",");

	if(parts.length < 2){
		return false;
	}

	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userConfig = window.taxen.ziwei.users[i];

		if(parts[0] == userConfig.user.getToken()){
			var config = 0;

			if(parts[1] == "1"){
				config = 1;
			}

			userConfig.languageConfig = config;

			return true;
		}
	}

	return false;
 }

 function getColor(){
	var xtgw_fore = BizEnum.COLORCONFIG.XIANTIANGONGWEI.color, //	先天宫位前景色
		xtgw_bg = BizEnum.COLORCONFIG.XIANTIANGONGWEI.bgcolor, //	先天宫位背景色
		dygw_fore = BizEnum.COLORCONFIG.DAYUNGONGWEI.color, //	大运宫位前景色
		dygw_bg = BizEnum.COLORCONFIG.DAYUNGONGWEI.bgcolor, //	大运宫位背景色
		lngw_fore = BizEnum.COLORCONFIG.LIUNIANGONGWEI.color, //	流年宫位前景色
		lngw_bg = BizEnum.COLORCONFIG.LIUNIANGONGWEI.bgcolor, //	流年宫位背景色
		lygw_fore = BizEnum.COLORCONFIG.LIUYUEGONGWEI.color, //	流月宫位前景色
		lygw_bg = BizEnum.COLORCONFIG.LIUYUEGONGWEI.bgcolor, //	流月宫位背景色
		lrgw_fore = BizEnum.COLORCONFIG.LIURIGONGWEI.color, //	流日宫位前景色
		lrgw_bg = BizEnum.COLORCONFIG.LIURIGONGWEI.bgcolor, //	流日宫位背景色
		lsgw_fore = BizEnum.COLORCONFIG.LIUSHIGONGWEI.color, //	流时宫位前景色
		lsgw_bg = BizEnum.COLORCONFIG.LIUSHIGONGWEI.bgcolor, //	流时宫位背景色
		yunyao_fore = BizEnum.COLORCONFIG.YUNYAO.color, //	运曜前景色
		yunyao_bg = BizEnum.COLORCONFIG.YUNYAO.bgcolor, //	运曜背景色
		liuyao_fore = BizEnum.COLORCONFIG.LIUYAO.color, //	流曜前景色
		liuyao_bg = BizEnum.COLORCONFIG.LIUYAO.bgcolor, //	流曜背景色
		xtsh_fore = BizEnum.COLORCONFIG.XIANTIANSIHUA.color, //	先天四化前景色
		xtsh_bg = BizEnum.COLORCONFIG.XIANTIANSIHUA.bgcolor, //	先天四化背景色
		dysh_fore = BizEnum.COLORCONFIG.DAYUNSIHUA.color, //	大运四化前景色
		dysh_bg = BizEnum.COLORCONFIG.DAYUNSIHUA.bgcolor, //	大运四化背景色
		lnsh_fore = BizEnum.COLORCONFIG.LIUNIANSIHUA.color, //	流年四化前景色
		lnsh_bg = BizEnum.COLORCONFIG.LIUNIANSIHUA.bgcolor, //	流年四化背景色
		lysh_fore = BizEnum.COLORCONFIG.LIUYUESIHUA.color, //	流月四化前景色
		lysh_bg = BizEnum.COLORCONFIG.LIUYUESIHUA.bgcolor, //	流月四化背景色
		lrsh_fore = BizEnum.COLORCONFIG.LIURISIHUA.color, //	流日四化前景色
		lrsh_bg = BizEnum.COLORCONFIG.LIURISIHUA.bgcolor, //	流日四化背景色
		lsss_fore = BizEnum.COLORCONFIG.LIUSHISIHUA.color, //	流时四化前景色
		lsss_bg = BizEnum.COLORCONFIG.LIUSHISIHUA.bgcolor, //	流时四化背景色
		shengong_fore = BizEnum.COLORCONFIG.SHENGONG.color, //	身宫前景色
		shengong_bg = BizEnum.COLORCONFIG.SHENGONG.bgcolor, //	身宫背景色
		xiaoxian_fore = BizEnum.COLORCONFIG.XIAOXIAN.color, //	小限前景色
		xiaoxian_bg = BizEnum.COLORCONFIG.XIAOXIAN.bgcolor, //	小限背景色
		dyage_fore = BizEnum.COLORCONFIG.AGEPERIOD.color, //	大运年龄前景色
		dyage_bg = BizEnum.COLORCONFIG.AGEPERIOD.bgcolor, //	大运年龄背景色
		month_fore = BizEnum.COLORCONFIG.LIUNIANYUE.color, //	月份前景色
		month_bg = BizEnum.COLORCONFIG.LIUNIANYUE.bgcolor, //	月份背景色
		tiangan_fore = BizEnum.COLORCONFIG.TIANGAN.color, //	天干前景色
		tiangan_bg = BizEnum.COLORCONFIG.TIANGAN.bgcolor, //	天干背景色
		dizhi_fore = BizEnum.COLORCONFIG.DIZHI.color, //	地支前景色
		dizhi_bg = BizEnum.COLORCONFIG.DIZHI.bgcolor, //	地支背景色
		miaowang_fore = BizEnum.COLORCONFIG.MIAOWANG.color,
		miaowang_bg = BizEnum.COLORCONFIG.MIAOWANG.bgcolor,
		changsheng_fore = BizEnum.COLORCONFIG.CHANGSHENG.color,
		changsheng_bg = BizEnum.COLORCONFIG.CHANGSHENG.bgcolor,
		tssl_fore = BizEnum.COLORCONFIG.TAISUISHALU.color,
		tssl_bg = BizEnum.COLORCONFIG.TAISUISHALU.bgcolor,
		lnsq_fore = BizEnum.COLORCONFIG.LIUNIANSUIQIAN.color,
		lnsq_bg = BizEnum.COLORCONFIG.LIUNIANSUIQIAN.bgcolor,
		lnjq_fore = BizEnum.COLORCONFIG.LIUNIANJIANGQIAN.color,
		lnjq_bg = BizEnum.COLORCONFIG.LIUNIANJIANGQIAN.bgcolor;


		return {
			"tssl_fore" : tssl_fore,
			"tssl_bg" : tssl_bg,
            "lnsq_fore" : lnsq_fore,
            "lnsq_bg" : lnsq_bg,
            "lnjq_fore" :  lnjq_fore,
            "lnjq_bg" :  lnjq_bg,
			"miaowang_fore" : miaowang_fore,
			"miaowang_bg" : miaowang_bg,
            "xtgw_fore" : xtgw_fore,
            "xtgw_bg" : xtgw_bg,
            "dygw_fore" :  dygw_fore,
            "dygw_bg" :  dygw_bg,
            "lngw_fore" : lngw_fore,
            "lngw_bg" :  lngw_bg,
            "lygw_fore" :  lygw_fore,
            "lygw_bg" :  lygw_bg,
            "lrgw_fore"  :  lrgw_fore,
            "lrgw_bg" :  lrgw_bg,
            "lsgw_fore"  : lsgw_fore,
            "lsgw_bg" :  lsgw_bg,
            "yunyao_fore" : yunyao_fore,
            "yunyao_bg" : yunyao_bg,
            "liuyao_fore" : liuyao_fore,
            "liuyao_bg" : liuyao_bg,
            "xtsh_fore" :  xtsh_fore,
            "xtsh_bg" : xtsh_bg,
            "dysh_fore" :  dysh_fore,
            "dysh_bg" :  dysh_bg,
            "lnsh_fore" :  lnsh_fore,
            "lnsh_bg" : lnsh_bg,
            "lysh_fore" :  lysh_fore,
            "lysh_bg" : lysh_bg,
            "lrsh_fore" : lrsh_fore,
            "lrsh_bg" : lrsh_bg,
            "lsss_fore" : lsss_fore,
            "lsss_bg" : lsss_bg,
            "shengong_fore" : shengong_fore,
            "shengong_bg" : shengong_bg,
            "xiaoxian_fore" :  xiaoxian_fore,
            "xiaoxian_bg" : xiaoxian_bg,
            "dyage_fore" : dyage_fore,
            "dyage_bg" :  dyage_bg,
            "month_fore" : month_fore,
            "month_bg" :  month_bg,
            "tiangan_fore" : tiangan_fore,
            "tiangan_bg" : tiangan_bg,
            "dizhi_fore" : dizhi_fore,
            "dizhi_bg" : dizhi_bg,
			"changsheng_fore" : changsheng_fore,
			"changsheng_bg" : changsheng_bg
		};
 }

 function getCurrentLunarYear(){
	var date = new Date();

	var year = date.getFullYear();
	var month = date.getMonth() + 1;
	var day = date.getDate();

	var lunarDate = PerpetualCalendar.convertGregorianDate2LunarDate(year, month, day, 1);

	lunarDate.month = Translator.translate(BizEnum.LUNARMONTH[lunarDate.month - 1].name, 0);

	var result = {
		"lunarYear" : lunarDate.year,
		"lunarMonth" : lunarDate.month,
		"lunarDay" : lunarDate.day
	};

	if(lunarDate.isRunYue){
		result.lunarMonth = "闰" + result.lunarMonth;
	}

	return result;
 }

 function getAllMonthByLunarYear(year){
	if(!year || year < 1901 || year > 2099){
		return false;
	}

	var monthArray = new Array();

	var lunarMonth = BizEnum.LUNARMONTH;

	var yearData = new PerpetualCalendar().init().getCalendar()[year - 1901];

	var runYueIndex = yearData.runYueIndex;

	var monthLength = runYueIndex > 0 ? 13 : 12;

	var index = 0;

    while(index <= 11){
		var month = lunarMonth[index];
		monthArray.push(Translator.translateObject(month).name);

		if(month.index == runYueIndex){
			monthArray.push("闰" + Translator.translateObject(month).name);
		}

		index ++;
	}

	return monthArray;
 }

 function getDayArrayByLunarYearAndMonth(args){
	if(!args){
		return false;
	}

	args = args.split(",");

	if(args.length < 2){
		return false;
	}

	var year = parseInt(args[0]);
	var month = args[1];
	var isRunYue = false;

	if(args[1].indexOf("闰") >= 0){
		isRunYue = true;
	}

	month = month.replace("闰", "");

	month = Util.convertLunarMonthStr2Integer(month);

	var result = Util.getDayArrayByLunarYearAndMonth(year, month, isRunYue);

	var newResult = new Array();

	for(var i = 0 ; i < result.length; i ++){
		newResult.push(Translator.translateTianGanDiZhi(result[i]));
	}

	return newResult;
 }

 function convertLunarDate2GregorianDate_itf(args){

	if(!args){
		return false;
	}


	args = args.split(",");

	if(args.length < 3){
		return false;
	}

	var year = parseInt(args[0]);
	var month = args[1];
	var day = args[2];
	var isRunYue = false;

	if(month.indexOf("闰") >= 0){
		isRunYue = true;
	}

	month = month.replace("闰", "");
	month = Util.convertLunarMonthStr2Integer(month);

	day = Util.convertLunarDayStr2Integer(day);

	var gregorianDate = PerpetualCalendar.convertLunarDate2GregorianDate(year, month, day, 2, isRunYue);

	if(args.length == 4){
		return gregorianDate.getFullYear() + args[3] + (gregorianDate.getMonth() + 1) + args[3] + gregorianDate.getDate();
	}else{
	return gregorianDate.getFullYear() + "年" + (gregorianDate.getMonth() + 1) + "月" + gregorianDate.getDate() + "日";
 	}
}

 function getNextLunarDay(args){
	if(!args){
		return false;
	}

	args = args.split(",");

	if(args.length < 3){
		return false;
	}

	var lunarYear = args[0];
	var lunarMonth = args[1];
	var lunarDay = args[2];

	var result = Util.getNextLunarDay(lunarYear, lunarMonth, lunarDay);

	var year = result.year;
	var month = Util.convertInteger2LunarMonth(result.month);
	var day = Util.convertInteger2LunarDayStr(result.day);

	return year + "-" + (result.isRunYue ? "闰" : "") + Translator.translate(month,0) + "-" + Translator.translateTianGanDiZhi(day,0);
 }

 function getNextGregorianDay(args){
	if(!args){
		return false;
	}

	args = args.split(",");

	if(args.length < 3){
		return false;
	}

	var year = parseInt(args[0]);
	var month = parseInt(args[1]);
	var day = parseInt(args[2]);

	var result = Util.getNextGregorianDay(year, month, day);

	return result.getFullYear() + "-" + (result.getMonth() + 1) + "-" + result.getDate();
 }

  function getPreGregorianDay(args){
	if(!args){
		return false;
	}

	args = args.split("-");

	if(args.length < 3){
		return false;
	}

	var year = parseInt(args[0]);
	var month = parseInt(args[1]);
	var day = parseInt(args[2]);

	var result = Util.getPreGregorianDay(year, month, day);

	return result.getFullYear() + "-" + result.getMonth() + "-" + result.getDate();
 }


 function setSystemConfig(){
	if(arguments.length < 1){
		return false;
	}

	var param = arguments[0];

	try{
		eval("param = (" + param + ")");
	}catch(e){
		return false;
	}

	var wuGanSiHua = param.wugansihua;
	var gengGanSiHua = param.genggansihua;
	var renGanSiHua = param.rengansihua;
	var tianmaStar = param.tianmacfg;
	var runYue = param.runyue;
	var miaowang = param.miaowang;

	if(!wuGanSiHua){
		wuGanSiHua = 0;
	}

	wuGanSiHua = parseInt(wuGanSiHua);

	if(!(wuGanSiHua != 0 || wuGanSiHua != 1)){
		wuGanSiHua = 0;
	}

	if(!gengGanSiHua){
		gengGanSiHua = 0;
	}

	gengGanSiHua = parseInt(gengGanSiHua);

	if(!(gengGanSiHua != 0 || gengGanSiHua != 1 || gengGanSiHua != 2)){
		gengGanSiHua = 0;
	}

	if(!renGanSiHua){
		renGanSiHua = 0;
	}

	renGanSiHua = parseInt(renGanSiHua);

	if(!(renGanSiHua != 0 || renGanSiHua != 1)){
		renGanSiHua = 0;
	}

	if(!tianmaStar){
		tianmaStar = 0;
	}

	tianmaStar = parseInt(tianmaStar);

	if(!(tianmaStar != 0 || tianmaStar != 1)){
		tianmaStar = 0;
	}

	if(!runYue){
		runYue = 0;
	}

	runYue = parseInt(runYue);

	if(!(runYue != 0 || runYue != 1)){
		runYue = 0;
	}

	if(!miaowang){
		miaowang = 0;
	}

	miaowang = parseInt(miaowang);

	if(!(miaowang != 0 || miaowang != 1)){
		miaowang = 0;
	}

	var sysCfg = SystemConfig.newInstance();

	sysCfg.setSiHuaOfWu(wuGanSiHua);
	sysCfg.setSiHuaOfGeng(gengGanSiHua);
	sysCfg.setSiHuaOfRen(renGanSiHua);
	sysCfg.setTianMaStarConfig(tianmaStar);
	sysCfg.setRunYueConfig(runYue);
	sysCfg.showMiaoWang(0,0,0,miaowang);

	return SystemConfig.setConfig(sysCfg);
 }



function getEnergy(args){

    if(args){
        args = args.split(",");
    }else{
        return false;
    }
    var token = args[0];
    console.log("getEnergyJS---"+token);
	var time = args[1].split("-");

	var xianTianMingPan = null;
	var energyDesp = ['负能量 暴强', '负能量 强', '负能量 中强', '负能量 次强', '正负能量 2:8', '正负能量 4:6', '正负能量 5:5', '正负能量 7:3', '正能量 次强', '正能量 中强', '正能量 强', '正能量 暴强'];
	var energyLevel = ['大凶', '凶', '中凶', '次凶', '凶中带吉', '凶中带吉', '吉中带凶', '吉中带凶',  '次吉', '中吉','吉', '大吉'];

	for(var i=0;i<time.length;i++){
		time[i] = parseInt(time[i]);
	}

	if(time.length < 5){
		return false;
	}

	var lunarDate = PerpetualCalendar.convertGregorianDate2LunarDate(time[0],time[1],time[2],time[3]);
	var myDaYunMingPan;
	var liuNianMingPan;
	var liuYueMingPan;
	var liuRiMingPan;
	var liuShiMingPan;
	var liuFenMingPan;
	var language;
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		if(token == window.taxen.ziwei.users[i].user.getToken()){
			var user = window.taxen.ziwei.users[i].user;

			var userConfig = window.taxen.ziwei.users[i];
			language = userConfig.languageConfig;


			xianTianMingPan = user.getXianTianMingPan();


			var myBirthLunarYear = user.getUserInfo().getBirthday().getLunarYear();
			var myMingJu = user.getUserInfo().getMingJu().index;

			var thisYear = lunarDate.year;
			var myXuSui = lunarDate.year - myBirthLunarYear + 1;
			var myDaYunIndex = parseInt(((myXuSui - myMingJu) / 10) + 1);
			myDaYunMingPan = user.getDaYunMingPan(myDaYunIndex);

			liuNianMingPan = user.getLiuNianMingPan(thisYear);

			liuYueMingPan = user.getLiuYueMingPan(thisYear,lunarDate.month,lunarDate.isRunYue);

			liuRiMingPan = user.getLiuRiMingPan(thisYear,lunarDate.month,lunarDate.day,lunarDate.isRunYue);

			liuShiMingPan = user.getLiuShiMingPan(thisYear,lunarDate.month,lunarDate.day,time[3],lunarDate.isRunYue);

			liuFenMingPan = user.getLiuFenMingPan(thisYear,lunarDate.month,lunarDate.day,lunarDate.hour,time[4],lunarDate.isRunYue);
		}
	}

	var xianTianLevel = EnergyCalculator.getSpecifyGongWeiEnergyLevel("GONGWEI_MINGGONG", xianTianMingPan, "XianTianMingPan");

	var daYunLevel = EnergyCalculator.getSpecifyGongWeiEnergyLevel("GONGWEI_MINGGONG", myDaYunMingPan, "DaYunMingPan");

	var liuNianLevel = EnergyCalculator.getSpecifyGongWeiEnergyLevel("GONGWEI_MINGGONG", liuNianMingPan, "LiuNianMingPan");

	var liuYueLevel = EnergyCalculator.getSpecifyGongWeiEnergyLevel("GONGWEI_MINGGONG", liuYueMingPan, "LiuYueMingPan");

	var liuRiLevel = EnergyCalculator.getSpecifyGongWeiEnergyLevel("GONGWEI_MINGGONG", liuRiMingPan, "LiuRiMingPan");

	var liuShiLevel = EnergyCalculator.getSpecifyGongWeiEnergyLevel("GONGWEI_MINGGONG", liuShiMingPan, "LiuShiMingPan");

	var liuFenLevel = EnergyCalculator.getSpecifyGongWeiEnergyLevel("GONGWEI_MINGGONG", liuFenMingPan, "LiuFenMingPan");

	var allDesp = [];

	if(xianTianLevel > 0){
		var result = {
			"mingPanType" : "先天命盘",
			"subType" : "先天运势",
			"energyValue" : xianTianLevel,
			"energyText" : energyDesp[xianTianLevel - 1],
			"energyLevel" : energyLevel[xianTianLevel - 1]
		};

		result = Translator.translateZiWeiDouShu(result,language);
		allDesp.push(result);
	}

	if(daYunLevel > 0){
		var ganzhi;
		var items = myDaYunMingPan.getItems();
		for(var i = 0; i < items.length;i++){
			if(items[i].getDaYunGongWei().indexOf("MINGGONG") >= 0){
				ganzhi = items[i].getTianGan()+"$"+items[i].getDiZhi();
			}
		}
		ganzhi = Translator.translateTianGanDiZhi(ganzhi,language);
		var result = {
			"mingPanType" : "大运命盘",
			"subType" : ganzhi+"运势",
			"energyValue" : daYunLevel,
			"energyText" : energyDesp[daYunLevel - 1],
			"energyLevel" : energyLevel[daYunLevel - 1]
		};
		result = Translator.translateZiWeiDouShu(result,language);
		allDesp.push(result);
	}

	if(liuNianLevel > 0){
		var ganzhi = Translator.translateTianGanDiZhi(liuNianMingPan.getYearOfGanZhi(),language);
		var result = {
			"mingPanType" : "流年命盘",
			"subType" : ganzhi+"流年",
			"energyValue" : liuNianLevel,
			"energyText" : energyDesp[liuNianLevel - 1],
			"energyLevel" : energyLevel[liuNianLevel - 1]
		};
		result = Translator.translateZiWeiDouShu(result,language);
		allDesp.push(result);
	}

	if(liuYueLevel > 0){
		var ganzhi = Translator.translateTianGanDiZhi(liuNianMingPan.getYearOfGanZhi(),0);
		var result = {
			"mingPanType" : "流月命盘",
			"subType" :  BizEnum_Simplified.LUNARMONTH[lunarDate.month - 1].name+"流月",
			"energyValue" : liuYueLevel,
			"energyText" : energyDesp[liuYueLevel - 1],
			"energyLevel" : energyLevel[liuYueLevel - 1]
		};
		result = Translator.translateZiWeiDouShu(result,language);
		allDesp.push(result);
	}

	if(liuRiLevel > 0){
		var result = {
			"mingPanType" : "流日命盘",
			"subType" :  "今日流日",
			"energyValue" : liuRiLevel,
			"energyText" : energyDesp[liuRiLevel - 1],
			"energyLevel" : energyLevel[liuRiLevel - 1]
		};
		result = Translator.translateZiWeiDouShu(result,language);
		allDesp.push(result);
	}

	if(liuShiLevel > 0){
		var ganzhi = Translator.translateTianGanDiZhi(liuShiMingPan.hourOfGanZhi,0).substring(1);
		var result = {
			"mingPanType" : "流时命盘",
			"subType" :  ganzhi+"时流时",
			"energyValue" : liuShiLevel,
			"energyText" : energyDesp[liuShiLevel - 1],
			"energyLevel" : energyLevel[liuShiLevel - 1]
		};
		result = Translator.translateZiWeiDouShu(result,language);
		allDesp.push(result);
	}

    var minute = time[4];
   if(minute<10){
        minute = "0"+time[4];
   }
	if(liuFenLevel > 0){
		var result = {
			"mingPanType" : "流分命盘",
			"subType" :  time[3]+":"+minute,
			"energyValue" : liuFenLevel,
			"energyText" : energyDesp[liuFenLevel - 1],
			"energyLevel" : energyLevel[liuFenLevel - 1]
		};
		result = Translator.translateZiWeiDouShu(result,language);
		allDesp.push(result);
	}

	return JSON.stringify(allDesp);
}


/**
 * 获取用户的大运年限
 *
 */
function getDaYunagePeriod(args){
    if(!args){
        return false;
    }

    if(args.length < 2){
        return false;
    }

    args = args.split(",");

    var userToken = args[0];

    for(var i = 0; i < window.taxen.ziwei.users.length; i++){
        var userCfg = window.taxen.ziwei.users[i];

        if(userToken == userCfg.user.getToken()){
            var language = userCfg.languageConfig;

            var daYunMingPan = userCfg.user.getDaYunMingPan(1);

            var items = daYunMingPan.getItems();
            var isClockWise = true;
            var currentDaYun = false;

            var year = daYunMingPan.getYear();

            var myDate = parseInt(args[1]);

            var starArray = new Array();
            for(var i = 0; i < items.length; i++){
                var index = i + 1;
                var endYear = year + i * 10;
                var starArrayItem = new Object();
                var item = items[i];
                var agePeriod_begin    = item.getDaYunAgePeriod().begin;
                var agePeriod_end = item.getDaYunAgePeriod().end;

                var tianGan    = item.getTianGan();
                var diZhi = item.getDiZhi();

                if(myDate >= endYear && myDate < endYear + 10){
                    currentDaYun = index;
                }

                starArrayItem.tianGan = tianGan;
                starArrayItem.diZhi = diZhi;
                starArrayItem.agePeriod_begin = agePeriod_begin;
                starArrayItem.agePeriod_end = agePeriod_end;
                starArrayItem = Translator.translateObject(starArrayItem, language);

                starArray.push(starArrayItem);
            }

            starArray.sort(compare("agePeriod_begin"));
//            return {
//                     "daYunAgePeriod" : starArray,
//                     "currentDaYun" : currentDaYun,
//                     "currentDaYunIndex" : currentDaYun - 1
//                     };

            var result = {
            			  "currentDaYun" : currentDaYun,
            			  "currentDaYunIndex" : currentDaYun - 1
            			  };

            result = Translator.translateObject(result, language);

            console.log("xiantain---->"+result);
            			return JSON.stringify(result);
        }
    }
}


function compare(propertyName) {
    return function(object1, object2) {
        var value1 = object1[propertyName];
        var value2 = object2[propertyName];
        if (value2 < value1) {
            return 1;
        } else if (value2 > value1) {
            return -1;
        } else {
            return 0;
        }
    }
}




