/**
 * Interface.js
 * 紫微排盘接口类，对外暴露方法
 *
 * @date 2014-01-12
 * @version 0.1
 */
 
 /**
  * 保存用户基本信息
  */
 function saveUserBasicInfo(args){
	args = args.split(",");

	if(args.length < 6){
		return false;
	}
	
	var language = parseInt(args[0]);
	var username = args[1];
	var gender = args[2];
	var year = args[3];
	var month = args[4];
	var day = args[5];
	var hour = args[6].charAt(0);
	var isLunarDate = false;
	var isRunYue = false;

	if(args.length == 8){
		isLunarDate = args[7];
	}
 
	if(!(username && gender && year && month && day && hour)){
		return false;
	}
	
	if(!(gender == "男" || gender == "女")){
		return false;
	}
	
	if(year < 1901 || year > 2099){
		return false;
	}
	
	if(language != 1){
		language = 0;
	}
	
	
	if(isLunarDate){
		if(month.indexOf("闰") >= 0){
			isRunYue = true;
			month = month.replace("闰", "");
		}
		
		month = Util.convertLunarMonthStr2Integer(month);
		day = Util.convertLunarDayStr2Integer(day);
		
	}
	
	if(month < 1 || month > 12){
		return false;
	}
	
	if(day < 1 || day > 31){
		return false;
	}

	switch(hour){
		case "子" : hour = "DZ_ZI"; break; 
		case "丑" : hour = "DZ_CHOU"; break; 
		case "寅" : hour = "DZ_YIN"; break; 
		case "卯" : hour = "DZ_MAO"; break; 
		case "辰" : hour = "DZ_CHEN"; break; 
		case "巳" : hour = "DZ_SI"; break; 
		case "午" : hour = "DZ_WU"; break; 
		case "未" : hour = "DZ_WEI"; break; 
		case "申" : hour = "DZ_SHEN"; break; 
		case "酉" : hour = "DZ_YOU"; break; 
		case "戌" : hour = "DZ_XU"; break; 
		case "亥" : hour = "DZ_HAI"; break; 
		default : hour = "DZ_ZI"; break;
	}
 
	year = parseInt(year);
	month = parseInt(month);
	day = parseInt(day);
	hour = Util.getHourByLunarStr(hour);
 
	var user = User.newInstance(username, gender, year, month, day, hour, isLunarDate, isRunYue);
	
	window.taxen = new Object();
	
	window.taxen.ziwei = new Object();
	
	window.taxen.ziwei.users = new Array();
	
	window.taxen.ziwei.users.push({
		"languageConfig" : language,
		"user" : user
	});
	
	return user.getToken();
 }
 
 /**
  * 获取用户信息
  */
 function getUserInfo(userToken){
    if(!userToken){
		return false;
	}
	
	for(var i = 0 ; i < window.taxen.ziwei.users.length; i ++){
		if(userToken == window.taxen.ziwei.users[i].user.getToken()){
			var user = window.taxen.ziwei.users[i].user;
			var language = window.taxen.ziwei.users[i].languageConfig;
			var usrInfo = user.getUserInfo();
			
			var name = usrInfo.getName();
			var gender = usrInfo.getGender();
			var genderDescriptor = usrInfo.getGenderDescriptor();
			var birthDate = usrInfo.getBirthday();
			var birthday = birthDate.getYear() + "-" + birthDate.getMonth() + "-" + birthDate.getDay() + "-" + Util.getLunarHour(birthDate.getHour());
			var lunarBirthday = birthDate.getLunarYear() + "-" + (birthDate.isLunarRunYue() ? "闰" : "") + birthDate.getLunarMonth().index + "-" + birthDate.getLunarDay().index + "-" + Util.getLunarHour(birthDate.getHour());
			var bazi = usrInfo.getBaZi();

			var result = {
				"name" : name, 
				"gender" : gender, 
				"genderDescriptor" : genderDescriptor, 
				"birthday" : birthday, 
				"lunarBirthday" : lunarBirthday, 
				"zodiac" : Util.getZodiacByDiZhi(bazi.nianZhu.split("$")[1]),
				"bazi" : bazi.nianZhu + "-" + bazi.yueZhu + "-" + bazi.riZhu + "-" + bazi.shiZhu
			};
			
			result = Translator.translateObject(result, language);
			
			return result;
		}
	}
	
	return false;
 }
 
 /**  
  *  获取先天命盘中12宫位之一
  */
 function getXianTianMingPanSection(args){
	args = args.split(",");

	if(args.length == 0){
		return false;
	}
 
	var userToken = args[0];
	var index = 0;
	
	if(args.length > 1){
		index = parseInt(args[1]);
	}
	
	if(!userToken || index < 0 || index > 11){
		return false;
	}
 
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		if(userToken == window.taxen.ziwei.users[i].user.getToken()){
			var user = window.taxen.ziwei.users[i].user;
			var language = window.taxen.ziwei.users[i].languageConfig;
			var xianTianMingPan = user.getXianTianMingPan();
			
			var items = xianTianMingPan.getItems();
			
			var item =  items[index];
			
			var index = item.getIndex();
			var tianGan = item.getTianGan();
			var diZhi = item.getDiZhi();
			var gongWei = item.getGongWei();
			var daXianBeginYear = item.getAgePeriod().begin;
			var daXianEndYear = item.getAgePeriod().end;
			var changSheng = item.getChangSheng12Shen();
			var taiSuiShaLu = item.getTaiSuiShaLu();
			var liuNianSuiQian = item.getLiuNianSuiQian();
			var liuNianJiangQian = item.getLiuNianJiangQian();
			var mingZhu = xianTianMingPan.getMingZhu();
			var shenZhu = xianTianMingPan.getShenZhu();
			var mingJu = user.getUserInfo().getMingJu().name;		
					
			var mingGongIndex = xianTianMingPan.getMingGongIndex();		
			var mingGongItem = items[mingGongIndex];
			var mingGongDiZhi = mingGongItem.getDiZhi();
			
			var stars = mingGongItem.getStars();
			var mingGongMainStarNameArray = new Array();
			for(var i = 0 ; i < stars.length; i ++){
				if(stars[i].getName().indexOf("MAINSTAR_") == 0){
					mingGongMainStarNameArray.push(stars[i].getName());
				}
			}
			
			if(mingGongMainStarNameArray.length == 0){
				mingGongItem = items[(mingGongIndex - 6 + 12) % 12];
				stars = mingGongItem.getStars();
				
				for(var i = 0 ; i < stars.length; i ++){
					if(stars[i].getName().indexOf("MAINSTAR_") == 0){
						mingGongMainStarNameArray.push(stars[i].getName());
					}
				}
			}
			
			mingGongMainStarNameArray.push(mingGongDiZhi);

			var result =  {
				"index" : index,
				"tianGan" : tianGan,
				"diZhi" : diZhi,
				"gongWei" : gongWei,
				"daXianBeginYear" : daXianBeginYear,
				"daXianEndYear" : daXianEndYear,
				"changSheng" : changSheng,
				"taiSuiShaLu" : taiSuiShaLu,
				"liuNianSuiQian" : liuNianSuiQian,
				"liuNianJiangQian" : liuNianJiangQian,
				"mingZhu" : mingZhu,
				"shenZhu" : shenZhu,
				"mingJu" : mingJu,
				"mingGong" : mingGongMainStarNameArray.join(" ")
			};
			
			result = Translator.translateObject(result, language);
			
			return result;
		}
	}
	
	return false;
 }
 
 /**
  * 获取先天命盘中12宫位之一的星星
  */
 function getXianTianMingPanSectionStars(args){
	args = args.split(",");

	if(args.length == 0){
		return false;
	}
 
	var userToken = args[0];
	var index = 0;
	
	if(args.length > 1){
		index = parseInt(args[1]);
	}
 
	if(!userToken || index < 0 || index > 11){
		return false;
	}
 
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		if(userToken == window.taxen.ziwei.users[i].user.getToken()){
			var xianTianMingPan = window.taxen.ziwei.users[i].user.getXianTianMingPan();
			var language = window.taxen.ziwei.users[i].languageConfig;
			var items = xianTianMingPan.getItems();
			
			var item =  items[index];
			
			var stars = item.getStars();
			
			var starArray = new Array();
			
			for(var i = 0 ; i < stars.length; i ++){
				var star = stars[i];
				
				var starArrayItem = new Object();
				starArrayItem.index = i + 1;
				starArrayItem.name = star.getName();
				starArrayItem.descriptor = star.getDescriptor();
				
				var color = ColorConfig.getStarColor(star.getName());
				starArrayItem.color = color.color;
				starArrayItem.bgcolor = col	or.bgcolor;
				starArrayItem.siHua = star.getSiXiang();
				
				starArrayItem = Translator.translateObject(starArrayItem, language);
				
				starArray.push(starArrayItem);
			}
			
			return starArray;
		}
	}
	
	return false;
 }
 
 /**
  * 获取流年命盘中12宫位之一
  */
 function getLiuNianMingPanSection(args){
	if(!args){
		return false;
	}
	
	var parts = args.split(",");
	
	if(parts.length < 3){
		return false;
	}
	
	var userToken = parts[0], year = parts[1], index = parts[2];
	
	year = parseInt(year);
	index = parseInt(index);
	
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userConfig = window.taxen.ziwei.users[i];
		var language = userConfig.languageConfig;
		var user = userConfig.user;
		
		if(userToken == user.getToken()){
			var liuNianMingPan = user.getLiuNianMingPan(year);
			
			var items = liuNianMingPan.getItems();
			
			var item = items[index];
			
			var index = item.getIndex();
			var tianGan = item.getTianGan();
			var diZhi = item.getDiZhi();
			var gongWei = item.getGongWei();
			var month = item.getMonth().index;
			var changSheng = item.getChangSheng12Shen();
			var daYunGongWei = item.getDaYunGongWei();
			var liuNianGongWei = item.getLiuNianGongWei();
			var taiSuiShaLu = item.getTaiSuiShaLu();
			var liuNianSuiQian = item.getLiuNianSuiQian();
			var liuNianJiangQian = item.getLiuNianJiangQian();		
			var hasYunLiuYao = (item.getDaYunStars() || item.getLiuNianStars()) ? true : false;
			var xuSui = liuNianMingPan.getXuSui();
			var liuNian = year;
			var liuNianGanZhi = liuNianMingPan.getYearOfGanZhi();
			var liuNianDouJun = liuNianMingPan.getLiuNianDouJun();
			
			var result = {
				"index" : index,
				"tianGan" : tianGan,
				"diZhi" : diZhi,
				"gongWei" : gongWei,
				"month" : month,
				"changSheng" : changSheng,
				"daYunGongWei" : daYunGongWei,
				"liuNianGongWei" : liuNianGongWei,
				"taiSuiShaLu" : taiSuiShaLu,
				"liuNianSuiQian" : liuNianSuiQian,
				"liuNianJiangQian" : liuNianJiangQian,
				"hasYunLiuYao" : hasYunLiuYao,
				"xuSui" : xuSui,
				"liuNian" : liuNian,
				"liuNianGanZhi" : liuNianGanZhi,
				"liuNianDouJun" : liuNianDouJun
			};
			
			result = Translator.translateObject(result, language);
			
			return result;
		}
	}
	
	return result;
 }
 
 /**
  * 获取流年命盘中12宫位之一的星星
  */
 function getLiuNianMingPanSectionStars(args){
	args = args.split(",");

	if(args.length == 0){
		return false;
	}
 
	var userToken = args[0];
	var index = 0;
	
	if(args.length > 1){
		index = parseInt(args[1]);
	}
 
	if(!userToken || index < 0 || index > 11){
		return false;
	}
 
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		if(userToken == window.taxen.ziwei.users[i].user.getToken()){
			var userConfig = window.taxen.ziwei.users[i];
		
			var liuNianMingPan = userConfig.user.getLiuNianMingPan();
			var language = userConfig.languageConfig;

			var items = liuNianMingPan.getItems();
			
			var item =  items[index];
			
			var stars = item.getStars();
			
			var starArray = new Array();
			
			for(var i = 0 ; i < stars.length; i ++){
				var star = stars[i];
				
				var starArrayItem = new Object();
				starArrayItem.index = i + 1;
				starArrayItem.name = star.getName();
				starArrayItem.descriptor = star.getDescriptor();
				
				var color = ColorConfig.getStarColor(star.getName());
				starArrayItem.color = color.color;
				starArrayItem.bgcolor = color.bgcolor;
				starArrayItem.siHua = star.getSiXiang();
				starArrayItem.daYunSiHua = star.getSiHuaOfDaYun();
				starArrayItem.liuNianSiHua = star.getSiHuaOfLiuNian();
				
				starArrayItem = Translator.translateObject(starArrayItem, language);
				
				starArray.push(starArrayItem);
			}
			
			return starArray;
		}
	}
	
	return false;
 }
 
 /**
  * 获取流年命盘中12宫位之一的流曜和运曜
  */
 function getLiuNianMingPanSectionXingYao(args){
	args = args.split(",");

	if(args.length == 0){
		return false;
	}
 
	var userToken = args[0];
	var index = 0;
	
	if(args.length > 1){
		index = parseInt(args[1]);
	}
 
	if(!userToken || index < 0 || index > 11){
		return false;
	}
 
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		if(userToken == window.taxen.ziwei.users[i].user.getToken()){
			var userConfig = window.taxen.ziwei.users[i];
		
			var liuNianMingPan = userConfig.user.getLiuNianMingPan();
			var language = userConfig.languageConfig;

			var items = liuNianMingPan.getItems();
			
			var item =  items[index];
			
			var yunYao = item.getDaYunStars();
			var liuYao = item.getLiuNianStars();
			
			var result = new Array();
			
			if(yunYao){
				for(var i = 0 ; i < yunYao.length; i ++){
					var xingYao = new Object();
					xingYao.type = "YUNYAO";
					xingYao.name = yunYao[i].starName;
					xingYao.shortName = yunYao[i].shortName;					
					xingYao = Translator.translateObject(xingYao, language);
					
					result.push(xingYao);
				}
			}
			
			if(liuYao){
				for(var i = 0 ; i < liuYao.length; i ++){
					var xingYao = new Object();
					xingYao.type = "LIUYAO";
					xingYao.name = liuYao[i].starName;
					xingYao.shortName = liuYao[i].shortName;
					xingYao = Translator.translateObject(xingYao, language);
					
					result.push(xingYao);
				}
			}
			
			return result;
		}
	}
	
	return false;
 }
 
 /**
  * 获取大运命盘的某一宫位
  */
 function getDaYunMingPanSection(args){
	if(!args){
		return false;
	}
	
	var parts = args.split(",");
	
	if(parts.length < 3){
		return false;
	}
	
	var userToken = parts[0];
	var step = parseInt(parts[1]);
	var index = parseInt(parts[2]);
	
	if(step < 1 || step > 12){
		step = 1;
	}
	
	if(index < 0 || index > 11){
		index = 0;
	}
	
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];
		
		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;
		
			var daYunMingPan = userCfg.user.getDaYunMingPan(step);
			
			var items = daYunMingPan.getItems();
			
			var item = items[index];
			
			var index = item.getIndex();
			var tianGan	= item.getTianGan();
			var diZhi = item.getDiZhi();
			var gongWei	= item.getGongWei();
			var agePeriod_begin	= item.getDaYunAgePeriod().begin;
			var agePeriod_end = item.getDaYunAgePeriod().end;
			var daYunGongWei = item.getDaYunGongWei();
			var changSheng = item.getChangSheng12Shen();
			var hasYunYao = item.getDaYunStars() ? true : false;
			var xuSui = daYunMingPan.getXuSui();
			var liuNian	= daYunMingPan.getYear();
			var liuNianGanZhi = daYunMingPan.getYearOfGanZhi();
			var liuNianDouJun = daYunMingPan.getLiuNianDouJun();
			
			var result = {
				"index" : index,  
				"tianGan" : tianGan,	
				"diZhi" : diZhi,
				"gongWei" :	gongWei,
				"agePeriod_begin" :	agePeriod_begin,
				"agePeriod_end" : agePeriod_end,	
				"daYunGongWei" : daYunGongWei,	
				"changSheng" :	changSheng,
				"hasYunYao" : hasYunYao,
				"xuSui" : xuSui,	
				"liuNian" : liuNian,	
				"liuNianGanZhi" : liuNianGanZhi,	
				"liuNianDouJun" : liuNianDouJun	
			};

			result = Translator.translateObject(result, language);
			
			return result;
		}
	}
	
	return false;
 }
 
 function getDaYunMingPanSectionStars(args){
	if(!args){
		return false;
	}
	
	args = args.split(",");
	
	if(args.length < 2){
		return false;
	}
	
	var userToken = args[0];
	var index = parseInt(args[1]);
	
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];
		
		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;
		
			var daYunMingPan = userCfg.user.getDaYunMingPan();
			
			var items = daYunMingPan.getItems();
			
			var item = items[index];
			
			var stars = item.getStars();
			
			var starArray = new Array();
			
			for(var i = 0 ; i < stars.length; i ++){
				var star = stars[i];
				
				var starArrayItem = new Object();
				starArrayItem.index = i + 1;
				starArrayItem.name = star.getName();
				starArrayItem.descriptor = star.getDescriptor();
				
				var color = ColorConfig.getStarColor(star.getName());
				starArrayItem.color = color.color;
				starArrayItem.bgcolor = color.bgcolor;
				starArrayItem.siHua = star.getSiXiang();
				starArrayItem.daYunSiHua = star.getSiHuaOfDaYun();
				
				starArrayItem = Translator.translateObject(starArrayItem, language);
				
				starArray.push(starArrayItem);
			}
			
			return starArray;
		}
	}
 }
 
 /**
  * 获取大运命盘中一个宫位内的星曜
  */
 function getDaYunMingPanSectionXingYao(args){
	if(!args){
		return false;
	}
	
	args = args.split(",");
	
	if(args.length < 2){
		return false;
	}
	
	var userToken = args[0];
	var index = parseInt(args[1]);
	
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];
		
		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;
		
			var daYunMingPan = userCfg.user.getDaYunMingPan();
			
			var items = daYunMingPan.getItems();
			
			var item = items[index];
			
			var daYunStars = item.getDaYunStars();
			
			if(daYunStars){
				var result = new Array();
				
				for(var i = 0; i < daYunStars.length; i ++){
					var xingYao = new Object();
					xingYao.name = daYunStars[i].starName;
					xingYao.shortName = daYunStars[i].shortName;					
					xingYao = Translator.translateObject(xingYao, language);
					
					result.push(xingYao);
				}
			}
			
			return result;
		}
	}
	
	return false;
 }
 
 function getLiuYueMingPanSection(args){
	if(!args){
		return false;
	}
	
	args = args.split(",");
	
	if(args.length < 4){
		return false;
	}
	
	var userToken = args[0];
	var year = parseInt(args[1]);
	var month = parseInt(args[2]);
	var index = parseInt(args[3]);
	var isLunarMonth = false;
	
	if(year < 1901 || year > 2099){
		year = new Date().getFullYear();
	}
	
	if(month < 1 || month > 12){
		month = 1;
	}
	
	if(index < 0 || index > 11){
		index = 0;
	}
	
	if(args.length == 5){
		isLunarMonth = args[4];
	}
	
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];
		
		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;
			
			var liuYueMingPan = userCfg.user.getLiuYueMingPan(year, month, isLunarMonth);
			
			var item = liuYueMingPan.getItems()[index];
			
			var index = item.getIndex();
			var tianGan = item.getTianGan();
			var diZhi = item.getDiZhi();
			var gongWei	= item.getGongWei();
			var month = item.getMonth().name;
			var changSheng	= item.getChangSheng12Shen();
			var daYunGongWei = item.getDaYunGongWei();
			var liuNianGongWei = item.getLiuNianGongWei();
			var taiSuiShaLu	= item.getTaiSuiShaLu();
			var liuNianSuiQian	= item.getLiuNianSuiQian();
			var liuNianJiangQian = item.getLiuNianJiangQian();
			var hasYunLiuYao = (item.getDaYunStars() || item.getLiuNianStars()) ? true : false;
			
			var result = {
                "index" : index,
                "tianGan" : tianGan,
                "diZhi" : diZhi,
                "gongWei" : gongWei,
                "month" : month,
                "changSheng" : 	changSheng,
                "daYunGongWei" : daYunGongWei,
                "liuNianGongWei" : 	liuNianGongWei,
                "taiSuiShaLu" : taiSuiShaLu,
                "liuNianSuiQian" : 	liuNianSuiQian,
                "liuNianJiangQian" :  liuNianJiangQian,
                "hasYunLiuYao" :  hasYunLiuYao
			};
			
			result = Translator.translateObject(result, language);
			
			return result;
		}
	}	
 }
 
 function getLiuYueMingPanSectionStars(args){
	if(!args){
		return false;
	}
	
	args = args.split(",");
	
	if(args.length < 2){
		return false;
	}
	
	var userToken = args[0];
	var index = parseInt(args[1]);
	
	if(index < 0 || index > 11){
		index = 0;
	}
	
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];
		
		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;
	
			var liuYueMingPan = userCfg.user.getLiuYueMingPan();
			
			var item = liuYueMingPan.getItems()[index];
			
			var stars = item.getStars();
			
			var resultArray = new Array();
			
			for(var i = 0 ; i < stars.length; i ++){
				var star = stars[i];
				
				var starArrayItem = new Object();
				starArrayItem.index = i + 1;
				starArrayItem.name = star.getName();
				starArrayItem.descriptor = star.getDescriptor();
				
				var color = ColorConfig.getStarColor(star.getName());
				starArrayItem.color = color.color;
				starArrayItem.bgcolor = color.bgcolor;
				starArrayItem.siHua = star.getSiXiang();
				starArrayItem.daYunSiHua = star.getSiHuaOfDaYun();
				starArrayItem.liuNianSiHua = star.getSiHuaOfLiuNian();
				starArrayItem.liuYueSiHua = star.getSiHuaOfLiuYue();
				
				starArrayItem = Translator.translateObject(starArrayItem, language);
				
				resultArray.push(starArrayItem);
			}
			
			return resultArray;
		}
	}
	
	return false;
 }
 
 function getLiuYueMingPanSectionXingYao(args){
	if(!args){
		return false;
	}
	
	args = args.split(",");
	
	if(args.length < 2){
		return false;
	}
	
	var userToken = args[0];
	var index = parseInt(args[1]);
	
	if(index < 0 || index > 11){
		index = 0;
	}
	
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];
		
		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;
		
			var liuYueMingPan = userCfg.user.getLiuYueMingPan();
			
			var items = liuYueMingPan.getItems();
			
			var item = items[index];
					
			var yunYao = item.getDaYunStars();
			var liuYao = item.getLiuNianStars();
			
			var result = new Array();
			
			if(yunYao){
				for(var i = 0 ; i < yunYao.length; i ++){
					var xingYao = new Object();
					xingYao.type = "YUNYAO";
					xingYao.name = yunYao[i].starName;
					xingYao.shortName = yunYao[i].shortName;					
					xingYao = Translator.translateObject(xingYao, language);
					
					result.push(xingYao);
				}
			}
			
			if(liuYao){
				for(var i = 0 ; i < liuYao.length; i ++){
					var xingYao = new Object();
					xingYao.type = "LIUYAO";
					xingYao.name = liuYao[i].starName;
					xingYao.shortName = liuYao[i].shortName;
					xingYao = Translator.translateObject(xingYao, language);
					
					result.push(xingYao);
				}
			}
			
			return result;
		}
	}
	
	return false;
 }
 
 function getLiuRiMingPanSection(args){
	if(!args){
		return false;
	}
	
	args = args.split(",");
	
	if(args.length < 5){
		return false;
	}
	
	var userToken = args[0];
	var year = parseInt(args[1]);
	var month = parseInt(args[2]);
	var day = parseInt(args[3]);
	var index = parseInt(args[4]);
	var isLunarMonth = false;
	
	if(year < 1901 || year > 2099){
		year = new Date().getFullYear();
	}
	
	if(month < 1 || month > 12){
		month = 1;
	}
	
	if(index < 0 || index > 11){
		index = 0;
	}
	
	if(args.length == 6){
		isLunarMonth = args[5];
	}
	
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];
		
		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;
			
			var liuRiMingPan = userCfg.user.getLiuRiMingPan(year, month, day, isLunarMonth);
			
			var item = liuRiMingPan.getItems()[index];
			
			var index = item.getIndex();
			var tianGan = item.getTianGan();
			var diZhi = item.getDiZhi();
			var gongWei	= item.getGongWei();
			var month = item.getMonth().name;
			var changSheng	= item.getChangSheng12Shen();
			var daYunGongWei = item.getDaYunGongWei();
			var liuNianGongWei = item.getLiuNianGongWei();
			var liuYueGongWei = item.getMonthGongWei();
			var taiSuiShaLu	= item.getTaiSuiShaLu();
			var liuNianSuiQian	= item.getLiuNianSuiQian();
			var liuNianJiangQian = item.getLiuNianJiangQian();
			var hasYunLiuYao = (item.getDaYunStars() || item.getLiuNianStars()) ? true : false;
			
			var result = {
                "index" : index,
                "tianGan" : tianGan,
                "diZhi" : diZhi,
                "gongWei" : gongWei,
                "month" : month,
                "changSheng" : 	changSheng,
                "daYunGongWei" : daYunGongWei,
                "liuNianGongWei" : 	liuNianGongWei,
				"liuYueGongWei" : liuYueGongWei,
                "taiSuiShaLu" : taiSuiShaLu,
                "liuNianSuiQian" : 	liuNianSuiQian,
                "liuNianJiangQian" :  liuNianJiangQian,
                "hasYunLiuYao" :  hasYunLiuYao
			};
			
			result = Translator.translateObject(result, language);
			
			return result;
		}
	}	
 }
 
 function getLiuRiMingPanSectionStars(args){
	if(!args){
		return false;
	}
	
	args = args.split(",");
	
	if(args.length < 2){
		return false;
	}
	
	var userToken = args[0];
	var index = parseInt(args[1]);
	
	if(index < 0 || index > 11){
		index = 0;
	}
	
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];
		
		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;
	
			var liuRiMingPan = userCfg.user.getLiuRiMingPan();
			
			var item = liuRiMingPan.getItems()[index];
			
			var stars = item.getStars();
			
			var resultArray = new Array();
			
			for(var i = 0 ; i < stars.length; i ++){
				var star = stars[i];
				
				var starArrayItem = new Object();
				starArrayItem.index = i + 1;
				starArrayItem.name = star.getName();
				starArrayItem.descriptor = star.getDescriptor();
				
				var color = ColorConfig.getStarColor(star.getName());
				starArrayItem.color = color.color;
				starArrayItem.bgcolor = color.bgcolor;
				starArrayItem.siHua = star.getSiXiang();
				starArrayItem.daYunSiHua = star.getSiHuaOfDaYun();
				starArrayItem.liuNianSiHua = star.getSiHuaOfLiuNian();
				starArrayItem.liuYueSiHua = star.getSiHuaOfLiuYue();
				starArrayItem.liuRiSiHua = star.getSiHuaOfLiuRi();
				
				starArrayItem = Translator.translateObject(starArrayItem, language);
				
				resultArray.push(starArrayItem);
			}
			
			return resultArray;
		}
	}
	
	return false;
 }
 
 function getLiuRiMingPanSectionXingYao(args){
	if(!args){
		return false;
	}
	
	args = args.split(",");
	
	if(args.length < 2){
		return false;
	}
	
	var userToken = args[0];
	var index = parseInt(args[1]);
	
	if(index < 0 || index > 11){
		index = 0;
	}
	
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];
		
		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;
		
			var liuRiMingPan = userCfg.user.getLiuRiMingPan();
			
			var items = liuRiMingPan.getItems();
			
			var item = items[index];
					
			var yunYao = item.getDaYunStars();
			var liuYao = item.getLiuNianStars();
			
			var result = new Array();
			
			if(yunYao){
				for(var i = 0 ; i < yunYao.length; i ++){
					var xingYao = new Object();
					xingYao.type = "YUNYAO";
					xingYao.name = yunYao[i].starName;
					xingYao.shortName = yunYao[i].shortName;					
					xingYao = Translator.translateObject(xingYao, language);
					
					result.push(xingYao);
				}
			}
			
			if(liuYao){
				for(var i = 0 ; i < liuYao.length; i ++){
					var xingYao = new Object();
					xingYao.type = "LIUYAO";
					xingYao.name = liuYao[i].starName;
					xingYao.shortName = liuYao[i].shortName;
					xingYao = Translator.translateObject(xingYao, language);
					
					result.push(xingYao);
				}
			}
			
			return result;
		}
	}
	
	return false;
 }
 
 function getLiuShiMingPanSection(args){
	if(!args){
		return false;
	}
	
	args = args.split(",");
	
	if(args.length < 6){
		return false;
	}
	
	var userToken = args[0];
	var year = parseInt(args[1]);
	var month = parseInt(args[2]);
	var day = parseInt(args[3]);
	var hour = parseInt(args[4]);
	var index = parseInt(args[5]);
	var isLunarRunYue = false;
	
	if(args.length >= 7){
		isLunarRunYue = args[6];
	}
	
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];
		
		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;
			
			var liuShiMingPan = userCfg.user.getLiuShiMingPan(year, month, day, hour, isLunarRunYue);
			
			var item = liuShiMingPan.getItems()[index];
			
			var index = item.getIndex();
			var tianGan = item.getTianGan();
			var diZhi = item.getDiZhi();
			var gongWei	= item.getGongWei();
			var month = item.getMonth().name;
			var changSheng	= item.getChangSheng12Shen();
			var daYunGongWei = item.getDaYunGongWei();
			var liuNianGongWei = item.getLiuNianGongWei();
			var liuYueGongWei = item.getMonthGongWei();
			var taiSuiShaLu	= item.getTaiSuiShaLu();
			var liuNianSuiQian	= item.getLiuNianSuiQian();
			var liuNianJiangQian = item.getLiuNianJiangQian();
			var hasYunLiuYao = (item.getDaYunStars() || item.getLiuNianStars()) ? true : false;
			var hour = item.getLunarHour();
			
			var result = {
                "index" : index,
                "tianGan" : tianGan,
                "diZhi" : diZhi,
                "gongWei" : gongWei,
                "month" : month,
                "changSheng" : 	changSheng,
                "daYunGongWei" : daYunGongWei,
                "liuNianGongWei" : 	liuNianGongWei,
				"liuYueGongWei" : liuYueGongWei,
				"hour" : hour,
                "taiSuiShaLu" : taiSuiShaLu,
                "liuNianSuiQian" : 	liuNianSuiQian,
                "liuNianJiangQian" :  liuNianJiangQian,
                "hasYunLiuYao" :  hasYunLiuYao
			};
			
			result = Translator.translateObject(result, language);
			
			return result;
		}
	}	
	
	return false;
 }
 
 function getLiuShiMingPanSectionStars(args){
	if(!args){
		return false;
	}
	
	args = args.split(",");
	
	if(args.length < 2){
		return false;
	}
	
	var userToken = args[0];
	var index = parseInt(args[1]);
	
	if(index < 0 || index > 11){
		index = 0;
	}
	
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];
		
		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;
	
			var liuShiMingPan = userCfg.user.getLiuShiMingPan();
			
			var item = liuShiMingPan.getItems()[index];
			
			var stars = item.getStars();
			
			var resultArray = new Array();
			
			for(var i = 0 ; i < stars.length; i ++){
				var star = stars[i];
				
				var starArrayItem = new Object();
				starArrayItem.index = i + 1;
				starArrayItem.name = star.getName();
				starArrayItem.descriptor = star.getDescriptor();
				
				var color = ColorConfig.getStarColor(star.getName());
				starArrayItem.color = color.color;
				starArrayItem.bgcolor = color.bgcolor;
				starArrayItem.siHua = star.getSiXiang();
				starArrayItem.daYunSiHua = star.getSiHuaOfDaYun();
				starArrayItem.liuNianSiHua = star.getSiHuaOfLiuNian();
				starArrayItem.liuYueSiHua = star.getSiHuaOfLiuYue();
				starArrayItem.liuRiSiHua = star.getSiHuaOfLiuRi();
				starArrayItem.liuShiSiHua = star.getSiHuaOfLiuShi();
				
				starArrayItem = Translator.translateObject(starArrayItem, language);
				
				resultArray.push(starArrayItem);
			}
			
			return resultArray;
		}
	}
	
	return false;
 }
 
 function getLiuShiMingPanSectionXingYao(args){
	if(!args){
		return false;
	}
	
	args = args.split(",");
	
	if(args.length < 2){
		return false;
	}
	
	var userToken = args[0];
	var index = parseInt(args[1]);
	
	if(index < 0 || index > 11){
		index = 0;
	}
	
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userCfg = window.taxen.ziwei.users[i];
		
		if(userToken == userCfg.user.getToken()){
			var language = userCfg.languageConfig;
		
			var liuShiMingPan = userCfg.user.getLiuShiMingPan();
			
			var items = liuShiMingPan.getItems();
			
			var item = items[index];
					
			var yunYao = item.getDaYunStars();
			var liuYao = item.getLiuNianStars();
			
			var result = new Array();
			
			if(yunYao){
				for(var i = 0 ; i < yunYao.length; i ++){
					var xingYao = new Object();
					xingYao.type = "YUNYAO";
					xingYao.name = yunYao[i].starName;
					xingYao.shortName = yunYao[i].shortName;					
					xingYao = Translator.translateObject(xingYao, language);
					
					result.push(xingYao);
				}
			}
			
			if(liuYao){
				for(var i = 0 ; i < liuYao.length; i ++){
					var xingYao = new Object();
					xingYao.type = "LIUYAO";
					xingYao.name = liuYao[i].starName;
					xingYao.shortName = liuYao[i].shortName;
					xingYao = Translator.translateObject(xingYao, language);
					
					result.push(xingYao);
				}
			}
			
			return result;
		}
	}
	
	return false;
 }
 
 function modifySysFont(args){
	if(!args){
		return false;
	}
 
	var parts = args.split(",");
	
	if(parts.length < 2){
		return false;
	}
	
	for(var i = 0; i < window.taxen.ziwei.users.length; i++){
		var userConfig = window.taxen.ziwei.users[i];
		
		if(parts[0] == userConfig.user.getToken()){
			var config = 0;
			
			if(parts[1] == "1"){
				config = 1;
			}
		
			userConfig.languageConfig = config;
			
			return true;
		}
	}
	
	return false;
 }
 
 function getColor(){
	var xtgw_fore = BizEnum.COLORCONFIG.XIANTIANGONGWEI.color, //	先天宫位前景色	
		xtgw_bg = BizEnum.COLORCONFIG.XIANTIANGONGWEI.bgcolor, //	先天宫位背景色	
		dygw_fore = BizEnum.COLORCONFIG.DAYUNGONGWEI.color, //	大运宫位前景色	
		dygw_bg = BizEnum.COLORCONFIG.DAYUNGONGWEI.bgcolor, //	大运宫位背景色	
		lngw_fore = BizEnum.COLORCONFIG.LIUNIANGONGWEI.color, //	流年宫位前景色	
		lngw_bg = BizEnum.COLORCONFIG.LIUNIANGONGWEI.bgcolor, //	流年宫位背景色	
		lygw_fore = BizEnum.COLORCONFIG.LIUYUEGONGWEI.color, //	流月宫位前景色	
		lygw_bg = BizEnum.COLORCONFIG.LIUYUEGONGWEI.bgcolor, //	流月宫位背景色	
		lrgw_fore = BizEnum.COLORCONFIG.LIURIGONGWEI.color, //	流日宫位前景色	
		lrgw_bg = BizEnum.COLORCONFIG.LIURIGONGWEI.bgcolor, //	流日宫位背景色	
		lsgw_fore = BizEnum.COLORCONFIG.LIUSHIGONGWEI.color, //	流时宫位前景色	
		lsgw_bg = BizEnum.COLORCONFIG.LIUSHIGONGWEI.bgcolor, //	流时宫位背景色	
		yunyao_fore = BizEnum.COLORCONFIG.YUNYAO.color, //	运曜前景色	
		yunyao_bg = BizEnum.COLORCONFIG.YUNYAO.bgcolor, //	运曜背景色	
		liuyao_fore = BizEnum.COLORCONFIG.LIUYAO.color, //	流曜前景色	
		liuyao_bg = BizEnum.COLORCONFIG.LIUYAO.bgcolor, //	流曜背景色	
		xtsh_fore = BizEnum.COLORCONFIG.XIANTIANSIHUA.color, //	先天四化前景色	
		xtsh_bg = BizEnum.COLORCONFIG.XIANTIANSIHUA.bgcolor, //	先天四化背景色	
		dysh_fore = BizEnum.COLORCONFIG.DAYUNSIHUA.color, //	大运四化前景色	
		dysh_bg = BizEnum.COLORCONFIG.DAYUNSIHUA.bgcolor, //	大运四化背景色	
		lnsh_fore = BizEnum.COLORCONFIG.LIUNIANSIHUA.color, //	流年四化前景色	
		lnsh_bg = BizEnum.COLORCONFIG.LIUNIANSIHUA.bgcolor, //	流年四化背景色 	
		lysh_fore = BizEnum.COLORCONFIG.LIUYUESIHUA.color, //	流月四化前景色	
		lysh_bg = BizEnum.COLORCONFIG.LIUYUESIHUA.bgcolor, //	流月四化背景色	
		lrsh_fore = BizEnum.COLORCONFIG.LIURISIHUA.color, //	流日四化前景色	
		lrsh_bg = BizEnum.COLORCONFIG.LIURISIHUA.bgcolor, //	流日四化背景色	
		lsss_fore = BizEnum.COLORCONFIG.LIUSHISIHUA.color, //	流时四化前景色	
		lsss_bg = BizEnum.COLORCONFIG.LIUSHISIHUA.bgcolor, //	流时四化背景色	
		shengong_fore = BizEnum.COLORCONFIG.SHENGONG.color, //	身宫前景色	
		shengong_bg = BizEnum.COLORCONFIG.SHENGONG.bgcolor, //	身宫背景色	
		xiaoxian_fore = BizEnum.COLORCONFIG.XIAOXIAN.color, //	小限前景色	
		xiaoxian_bg = BizEnum.COLORCONFIG.XIAOXIAN.bgcolor, //	小限背景色	
		dyage_fore = BizEnum.COLORCONFIG.AGEPERIOD.color, //	大运年龄前景色	
		dyage_bg = BizEnum.COLORCONFIG.AGEPERIOD.bgcolor, //	大运年龄背景色	
		month_fore = BizEnum.COLORCONFIG.LIUNIANYUE.color, //	月份前景色	
		month_bg = BizEnum.COLORCONFIG.LIUNIANYUE.bgcolor, //	月份背景色	
		tiangan_fore = BizEnum.COLORCONFIG.TIANGAN.color, //	天干前景色	
		tiangan_bg = BizEnum.COLORCONFIG.TIANGAN.bgcolor, //	天干背景色	
		dizhi_fore = BizEnum.COLORCONFIG.DIZHI.color, //	地支前景色	
		dizhi_bg = BizEnum.COLORCONFIG.DIZHI.bgcolor, //	地支背景色
		miaowang_fore = BizEnum.COLORCONFIG.MIAOWANG.color,
		miaowang_bg = BizEnum.COLORCONFIG.MIAOWANG.bgcolor,
		changsheng_fore = BizEnum.COLORCONFIG.CHANGSHENG.color,
		changsheng_bg = BizEnum.COLORCONFIG.CHANGSHENG.bgcolor,
		tssl_fore = BizEnum.COLORCONFIG.TAISUISHALU.color,
		tssl_bg = BizEnum.COLORCONFIG.TAISUISHALU.bgcolor,
		lnsq_fore = BizEnum.COLORCONFIG.LIUNIANSUIQIAN.color,
		lnsq_bg = BizEnum.COLORCONFIG.LIUNIANSUIQIAN.bgcolor,
		lnjq_fore = BizEnum.COLORCONFIG.LIUNIANJIANGQIAN.color,
		lnjq_bg = BizEnum.COLORCONFIG.LIUNIANJIANGQIAN.bgcolor;
		
		
		return {
			"tssl_fore" : tssl_fore,
			"tssl_bg" : tssl_bg,
            "lnsq_fore" : lnsq_fore,
            "lnsq_bg" : lnsq_bg,
            "lnjq_fore" :  lnjq_fore,
            "lnjq_bg" :  lnjq_bg,
			"miaowang_fore" : miaowang_fore,
			"miaowang_bg" : miaowang_bg,
            "xtgw_fore" : xtgw_fore,
            "xtgw_bg" : xtgw_bg,
            "dygw_fore" :  dygw_fore,
            "dygw_bg" :  dygw_bg,
            "lngw_fore" : lngw_fore, 
            "lngw_bg" :  lngw_bg,
            "lygw_fore" :  lygw_fore,
            "lygw_bg" :  lygw_bg,
            "lrgw_fore"  :  lrgw_fore, 
            "lrgw_bg" :  lrgw_bg,
            "lsgw_fore"  : lsgw_fore,
            "lsgw_bg" :  lsgw_bg,
            "yunyao_fore" : yunyao_fore,
            "yunyao_bg" : yunyao_bg,
            "liuyao_fore" : liuyao_fore,
            "liuyao_bg" : liuyao_bg, 
            "xtsh_fore" :  xtsh_fore,
            "xtsh_bg" : xtsh_bg,
            "dysh_fore" :  dysh_fore,
            "dysh_bg" :  dysh_bg,
            "lnsh_fore" :  lnsh_fore,
            "lnsh_bg" : lnsh_bg,
            "lysh_fore" :  lysh_fore,
            "lysh_bg" : lysh_bg,
            "lrsh_fore" : lrsh_fore, 
            "lrsh_bg" : lrsh_bg,
            "lsss_fore" : lsss_fore,
            "lsss_bg" : lsss_bg,
            "shengong_fore" : shengong_fore,
            "shengong_bg" : shengong_bg, 
            "xiaoxian_fore" :  xiaoxian_fore,
            "xiaoxian_bg" : xiaoxian_bg, 
            "dyage_fore" : dyage_fore,
            "dyage_bg" :  dyage_bg,
            "month_fore" : month_fore, 
            "month_bg" :  month_bg,
            "tiangan_fore" : tiangan_fore,
            "tiangan_bg" : tiangan_bg, 
            "dizhi_fore" : dizhi_fore, 
            "dizhi_bg" : dizhi_bg,
			"changsheng_fore" : changsheng_fore,
			"changsheng_bg" : changsheng_bg
		};
 }