/**
 * PersonalInfo.js
 * 个人信息
 *
 * @date 2014-01-08
 * @version 0.3
 * @description 重新梳理PersonalInfo类的功能，去除命主、身主等属性
 */
 
 namespace("com.taxen.framework.ziwei.core");
 
 function PersonalInfo(){
	this._name = false;                // 姓名
	this._birthday = false;            // 生日
	this._baZi = false;                // 八字
	this._gender = false;              // 性别
	this._genderDescriptor = false;    // 性别描述符（阴|阳）
	this._mingJu = false;              // 命局
 }
 
 // 农历
 PersonalInfo.newInstance = function(name, gender, year, month, day, hour, isRunYue){
	isRunYue = isRunYue ? true : false;
 
	var personalInfo = new PersonalInfo();
	
	personalInfo.setName(name);
	personalInfo.setBirthday(PerpetualCalendar.getCalendarDay(year, month, day, hour, isRunYue));
	personalInfo.setGender(gender == "男" ? BizEnum.GENDER[0] : BizEnum.GENDER[1]);
	personalInfo.setBaZi({
		"nianZhu" : personalInfo.getBirthday().getYearOfGanZhiWithFeast(),
		"yueZhu" : personalInfo.getBirthday().getMonthOfGanZhi(),
		"riZhu" : personalInfo.getBirthday().getDayOfGanZhi(),
		"shiZhu" : personalInfo.getBirthday().getHourOfGanZhi()
	});
	
	return personalInfo;
 };
 
 // 公历
 PersonalInfo.newInstance2 = function(name, gender, year, month, day, hour){
	
 };
 
 PersonalInfo.prototype.setName = function(name){
	this._name = name;
	
	return this;
 };
 
 PersonalInfo.prototype.getName = function(){
	return this._name;
 };
 
 PersonalInfo.prototype.getBirthday = function(){
	return this._birthday;
 };
 
 PersonalInfo.prototype.setBirthday = function(birthday){
	this._birthday = birthday;
	
	return this;
 };
 
 PersonalInfo.prototype.getBaZi = function(){
	return this._baZi;
 };
 
 PersonalInfo.prototype.setBaZi = function(baZi){
	this._baZi = baZi;
	
	return this;
 };
 
 PersonalInfo.prototype.getGender = function(){
	return this._gender;
 };
 
 PersonalInfo.prototype.setGender = function(gender){
	this._gender = gender;
	
	var yearGanZhi = this._birthday.getYearOfGanZhi().split("$");
	var descriptor = Util.getYinYangMapByDIZHI(yearGanZhi[1]);
	
	this.setGenderDescriptor(descriptor);
	
	return this;
 };
 
 PersonalInfo.prototype.getGenderDescriptor = function(){
	return this._genderDescriptor;
 };
 
 PersonalInfo.prototype.setGenderDescriptor = function(genderDescriptor){
	this._genderDescriptor = genderDescriptor;
	
	return this;
 };
 
 PersonalInfo.prototype.getMingJu = function(){
	return this._mingJu;
 };
 
 PersonalInfo.prototype.setMingJu = function(mingGong){
	mingGong = mingGong.split("$");
	var tiangan = mingGong[0];
	var dizhi = mingGong[1];
	
	mingGong = tiangan.split("_")[1] + dizhi.split("_")[1];
	
	mingGong = "JIAZI_" + mingGong; 
 
	var mingJu = -1;
	switch(mingGong){
		case "JIAZI_JIAZI" : 
		case "JIAZI_YICHOU" : mingJu = 4; break;
		case "JIAZI_BINGYIN" : 
		case "JIAZI_DINGMAO" : mingJu = 6; break;
		case "JIAZI_WUCHEN" : 
		case "JIAZI_JISI" : mingJu = 3; break;
		case "JIAZI_GENGWU" : 
		case "JIAZI_XINWEI" : mingJu = 5; break;
		case "JIAZI_RENSHEN" : 
		case "JIAZI_GUIYOU" : mingJu = 4; break; 
		case "JIAZI_JIAXU" : 
		case "JIAZI_YIHAI" : mingJu = 6; break; 
		case "JIAZI_BINGZI" : 
		case "JIAZI_DINGCHOU" : mingJu = 2; break;
		case "JIAZI_WUYIN" : 
		case "JIAZI_JIMAO" : mingJu = 5; break;
		case "JIAZI_GENGCHEN" : 
		case "JIAZI_XINSI" : mingJu = 4; break;
		case "JIAZI_RENWU" : 
		case "JIAZI_GUIWEI" : mingJu = 3; break; 
		case "JIAZI_JIASHEN" : 
		case "JIAZI_YIYOU" : mingJu = 2; break;
		case "JIAZI_BINGXU" : 
		case "JIAZI_DINGHAI" : mingJu = 5; break; 
		case "JIAZI_WUZI" : 
		case "JIAZI_JICHOU" : mingJu = 6; break;
		case "JIAZI_GENGYIN" : 
		case "JIAZI_XINMAO" : mingJu = 3; break;
		case "JIAZI_RENCHEN" : 
		case "JIAZI_GUISI" : mingJu = 2; break; 
		case "JIAZI_JIAWU" : 
		case "JIAZI_YIWEI" : mingJu = 4; break; 
		case "JIAZI_BINGSHEN" : 
		case "JIAZI_DINGYOU" : mingJu = 6; break;
		case "JIAZI_WUXU" : 
		case "JIAZI_JIHAI" : mingJu = 3; break; 
		case "JIAZI_GENGZI" : 
		case "JIAZI_XINCHOU" : mingJu = 5; break;
		case "JIAZI_RENYIN" : 
		case "JIAZI_GUIMAO" : mingJu = 4; break; 
		case "JIAZI_JIACHEN" : 
		case "JIAZI_YISI" : mingJu = 6; break; 
		case "JIAZI_BINGWU" : 
		case "JIAZI_DINGWEI" : mingJu = 2; break;
		case "JIAZI_WUSHEN" : 
		case "JIAZI_JIYOU" : mingJu = 5; break; 
		case "JIAZI_GENGXU" : 
		case "JIAZI_XINHAI" : mingJu = 4; break; 
		case "JIAZI_RENZI" : 
		case "JIAZI_GUICHOU" : mingJu = 3; break; 
		case "JIAZI_JIAYIN" : 
		case "JIAZI_YIMAO" : mingJu = 2; break; 
		case "JIAZI_BINGCHEN" : 
		case "JIAZI_DINGSI" : mingJu = 5; break; 
		case "JIAZI_WUWU" : 
		case "JIAZI_JIWEI" : mingJu = 6; break; 
		case "JIAZI_GENGSHEN" : 
		case "JIAZI_XINYOU" : mingJu = 3; break; 
		case "JIAZI_RENXU" : 
		case "JIAZI_GUIHAI" : mingJu = 2; break; 
		default : break;
	}

	this._mingJu = Util.getMingJuByIndex(mingJu);
	
	return this;
 };