/**
 * perpetualcalendar.js
 * 万年历， 提供1901至2099年之间的公历和农历的对应关系
 *
 * @date 2013-12-31
 * @version 0.1
 *
 * @date 2014-01-08 
 * @version 0.2
 * @description 增加命名空间
 */
 
 namespace("com.taxen.framework.ziwei.calendar");
 
 function PerpetualCalendar(){
	this._perpetualCalendar = false;
	
	this.init();
 }
 
 /**
  * 将公历转换为农历
  */
 PerpetualCalendar.convertGregorianDate2LunarDate = function(year, month, day, hour){
	var calendar = new PerpetualCalendar();
	
	var basePerpetualCalenderItem = calendar.getCalendar()[year-1901],    // 获取该年的数据
		baseSpringFestivalDate = basePerpetualCalenderItem.springFestivalDate,
		lunarYear = year;
	
	var springFestivalMonth = baseSpringFestivalDate.getMonth() + 1;
	var springFestivalDay = baseSpringFestivalDate.getDate();
	
	if(month < springFestivalMonth || (month == springFestivalMonth && day < springFestivalDay)){
		basePerpetualCalenderItem = calendar.getCalendar()[year-1901-1];
		baseSpringFestivalDate = basePerpetualCalenderItem.springFestivalDate;
		lunarYear --;
	}
	
	
	var intervalDays = PerpetualCalendar.getIntervalDays(baseSpringFestivalDate, new Date(year, month -1, day));
	var monthInfo = basePerpetualCalenderItem.monthInfo;
	
	for(var i = 0 ; i < monthInfo.length; i ++){
		if(intervalDays <= monthInfo[i]){
			var isRunYue = false;
			if(basePerpetualCalenderItem.runYueIndex < 0){
				i ++;
			}else{
				if(i < basePerpetualCalenderItem.runYueIndex){
					i ++;
				}else if(i == basePerpetualCalenderItem.runYueIndex){
					i = basePerpetualCalenderItem.runYueIndex;
					
					isRunYue = true;
				}
			}
			
			return LunarDate.createLunarDate(lunarYear, i, intervalDays, 0, isRunYue);
		}
	
		intervalDays -= monthInfo[i];
	}
	
	return springFestivalDate;
 };
 
 /**
  * 将农历转公历
  */
 PerpetualCalendar.convertLunarDate2GregorianDate = function(lunarYear, month, day, hour, isRunYue){
	var calendar = new PerpetualCalendar();
	
	var basePerpetualCalenderItem = calendar.getCalendar()[lunarYear-1901],
		baseSpringFestivalDate = basePerpetualCalenderItem.springFestivalDate,
		baseSpringFestivalMonth = baseSpringFestivalDate.getMonth() + 1,
		baseSpringFestivalDay = baseSpringFestivalDate.getDate();
	
	if(basePerpetualCalenderItem.runYueIndex > 0 && (month > basePerpetualCalenderItem.runYueIndex || (isRunYue && month == basePerpetualCalenderItem.runYueIndex))){
		month ++;
	}
	
	
	var monthInfo = basePerpetualCalenderItem.monthInfo;
	var totalDays = 0;
	
	for(var i = 0 ; i < month - 1; i ++){
		totalDays += monthInfo[i];
	}
	
	totalDays += day;
	var feb = PerpetualCalendar.isLeapYear(lunarYear) ? 29 : 28;
	var defaultMonths = [31,feb, 31,30,31,30,31,31,30,31,30,31];
	
	if(totalDays < (defaultMonths[baseSpringFestivalMonth-1] - baseSpringFestivalDay -1)){
		return new Date(lunarYear, baseSpringFestivalMonth-1, baseSpringFestivalDay + totalDays - 1);
	}
	
	totalDays -= (defaultMonths[baseSpringFestivalMonth-1] - baseSpringFestivalDay + 1);
	
	for(var i = baseSpringFestivalMonth ; i < defaultMonths.length; i ++){
		if(totalDays < defaultMonths[i]){
			return new Date(lunarYear, i, totalDays);
		}
		
		totalDays -= defaultMonths[i];
	}
	
	lunarYear ++;
	
	for(var i = 0 ; i < defaultMonths.length; i ++){
		if(totalDays < defaultMonths[i]){
			return new Date(lunarYear, i, totalDays);
		}
		
		totalDays -= defaultMonths[i];
	}
 };
 
 PerpetualCalendar.getYearData = function(year){
	var calendar = new PerpetualCalendar();
	
	return calendar.getCalendar()[year-1901];
 };
 
/**
 * 求出距离公历1901年2月19（春节）的天数
 */
PerpetualCalendar.getTotalDaysByDate = function(year, month, day){
	var totalDays = 0;
	
	for(var i = 1902; i < year; i ++){
		if(PerpetualCalendar.isLeapYear(i)){
			totalDays += 366;
		}else{
			totalDays += 365;
		}
	}
	
	totalDays += (365 - 31 - 18);
	
	totalDays += (PerpetualCalendar.getTotalDaysByMonth(month, PerpetualCalendar.isLeapYear(year)) + day);
	
	return totalDays;
};

/**
 * 获取两个日期之间的间隔天数(公历)
 */
PerpetualCalendar.getIntervalDays = function(startDate, endDate){
	var totalDays = 0;

	for(var i = startDate.getFullYear(); i < endDate.getFullYear(); i++){
		if(PerpetualCalendar.isLeapYear(i)){
			totalDays += 366;
		}else{
			totalDays += 365;
		}
	}
	
	var extraDays = PerpetualCalendar.getTotalDaysByMonth(startDate.getMonth() + 1, PerpetualCalendar.isLeapYear(startDate.getFullYear())) + startDate.getDate();
	
	var addedDays = PerpetualCalendar.getTotalDaysByMonth(endDate.getMonth() + 1, PerpetualCalendar.isLeapYear(endDate.getFullYear())) + endDate.getDate();
	
	totalDays = totalDays + addedDays - extraDays;
	
	return totalDays + 1;
};

 PerpetualCalendar.prototype.init = function(){
	var that = this;
	that._perpetualCalendar = new Array();
 
	var dateData = that.get1901To2099LunarDateData();
	
	for(var i = 0 ; i < dateData.length;  i++){
		var dateDataItem = dateData[i];
		var year = 1901 + i;
		var yearOfGanZhi = PerpetualCalendar.getLunarYearGanZhiStr(year);
		
		var springFestivalInfo = dateDataItem & 0x7f;
		
		var springFestivalMonth = springFestivalInfo >> 5;
		
		var springFestivalDay = springFestivalInfo & 0x1f;
		
		var springFestivalDate = new Date(year, springFestivalMonth - 1, springFestivalDay);
		
		var monthInfo = (dateDataItem >> 7)& 0x1fff ;  
		
		var runYueIndex = -1;
		var monthSize = 12;
		
		// 该农历年有闰月
		if(dateDataItem > 0x100000){
			runYueIndex = dateDataItem >> 20;
			
			monthSize = 13;
		}

		var monthArray = new Array();
		var defaultValue = 0x1fff;
		
		for(var j = 0; j < monthSize; j ++){
			var month = monthInfo & defaultValue;
			
			month = month >> (12-j);
			
			if(month == 1){
				monthArray.push(30);
			}else{
				monthArray.push(29);
			}
			
			defaultValue = defaultValue >> 1;
		}
		
		 that._perpetualCalendar.push({
			"index" : i,
			"year" : year,
			"springFestivalDate" : springFestivalDate,
			"monthInfo" : monthArray,
			"runYueIndex" : runYueIndex
		 });
	}
	
	return that;
 };
 
 PerpetualCalendar.isLeapYear = function(year){
	if((year % 4 == 0 && year % 100 != 0) || year % 400 == 0){
		return true;
	}
	
	return false;
};

PerpetualCalendar.getTotalDaysByMonth = function(month, isLeapYear){
	if(month < 1){
		return false;
	}
	
	var defaultMonthDays = [0,31,28,31,30,31,30,31,31,30,31,30];
	var total = 0 ;
	
	for(var i = 0 ; i < month; i ++){
		total += defaultMonthDays[i];
	}
	
	if(month > 2 && isLeapYear){
		total ++;
	}
	
	return total;
}
 
 PerpetualCalendar.prototype.get1901To2099LunarDateData = function(){

	// 共使用24来表示数据，其中0~6位表示春节信息(0~4表示春节的公历日期，5~6表示春节的公历月份)
	// 7~19位表示农历的1~13个月的大小(农历大月30天用1表示，小月29天用0表示)y
	// 20~23位表示当年闰月的月份，如果为0表示无闰月
	
	var lunarDateData = [
		0x04AE53,0x0A5748,0x5526BD,0x0D2650,0x0D9544,0x46AAB9,0x056A4D,0x09AD42,0x24AEB6,0x04AE4A,         /*1901-1910*/
		0x6A4DBE,0x0A4D52,0x0D2546,0x5D52BA,0x0B544E,0x0D6A43,0x296D37,0x095B4B,0x749BC1,0x049754,         /*1911-1920*/
		0x0A4B48,0x5B25BC,0x06A550,0x06D445,0x4ADAB8,0x02B64D,0x095742,0x2497B7,0x04974A,0x664B3E,         /*1921-1930*/
		0x0D4A51,0x0EA546,0x56D4BA,0x05AD4E,0x02B644,0x393738,0x092E4B,0x7C96BF,0x0C9553,0x0D4A48,         /*1931-1940*/
		0x6DA53B,0x0B554F,0x056A45,0x4AADB9,0x025D4D,0x092D42,0x2C95B6,0x0A954A,0x7B4ABD,0x06CA51,         /*1941-1950*/
		0x0B5546,0x555ABB,0x04DA4E,0x0A5B43,0x352BB8,0x052B4C,0x8A953F,0x0E9552,0x06AA48,0x6AD53C,		   /*1951-1960*/
		0x0AB54F,0x04B645,0x4A5739,0x0A574D,0x052642,0x3E9335,0x0D9549,0x75AABE,0x056A51,0x096D46,         /*1961-1970*/
		0x54AEBB,0x04AD4F,0x0A4D43,0x4D26B7,0x0D254B,0x8D52BF,0x0B5452,0x0B6A47,0x696D3C,0x095B50,         /*1971-1980*/
		0x049B45,0x4A4BB9,0x0A4B4D,0xAB25C2,0x06A554,0x06D449,0x6ADA3D,0x0AB651,0x095746,0x5497BB,         /*1981-1990*/
		0x04974F,0x064B44,0x36A537,0x0EA54A,0x86B2BF,0x05AC53,0x0AB647,0x5936BC,0x092E50,0x0C9645,         /*1991-2000*/
		0x4D4AB8,0x0D4A4C,0x0DA541,0x25AAB6,0x056A49,0x7AADBD,0x025D52,0x092D47,0x5C95BA,0x0A954E,         /*2001-2010*/
		0x0B4A43,0x4B5537,0x0AD54A,0x955ABF,0x04BA53,0x0A5B48,0x652BBC,0x052B50,0x0A9345,0x474AB9,         /*2011-2020*/
		0x06AA4C,0x0AD541,0x24DAB6,0x04B64A,0x69573D,0x0A4E51,0x0D2646,0x5E933A,0x0D534D,0x05AA43,         /*2021-2030*/
		0x36B537,0x096D4B,0xB4AEBF,0x04AD53,0x0A4D48,0x6D25BC,0x0D254F,0x0D5244,0x5DAA38,0x0B5A4C,         /*2031-2040*/
		0x056D41,0x24ADB6,0x049B4A,0x7A4BBE,0x0A4B51,0x0AA546,0x5B52BA,0x06D24E,0x0ADA42,0x355B37,         /*2041-2050*/
		0x09374B,0x8497C1,0x049753,0x064B48,0x66A53C,0x0EA54F,0x06B244,0x4AB638,0x0AAE4C,0x092E42,         /*2051-2060*/
		0x3C9735,0x0C9649,0x7D4ABD,0x0D4A51,0x0DA545,0x55AABA,0x056A4E,0x0A6D43,0x452EB7,0x052D4B,         /*2061-2070*/
		0x8A95BF,0x0A9553,0x0B4A47,0x6B553B,0x0AD54F,0x055A45,0x4A5D38,0x0A5B4C,0x052B42,0x3A93B6,         /*2071-2080*/
		0x069349,0x7729BD,0x06AA51,0x0AD546,0x54DABA,0x04B64E,0x0A5743,0x452738,0x0D264A,0x8E933E,         /*2081-2090*/
		0x0D5252,0x0DAA47,0x66B53B,0x056D4F,0x04AE45,0x4A4EB9,0x0A4D4C,0x0D1541,0x2D92B5                   /*2091-2099*/ 
	];
	
	return lunarDateData;
 };
 
  /**
  * 根据年份获取该年的立春时间
  *
  * @remark 如果没有输入年份，则默认输入今年的立春时间
  */
 PerpetualCalendar.getSpringBeginDateByYear = function(year){
	//计算公式：[Y*D+C]-L

    //公式解读：年数的后2位乘0.2422加3.87取整数减闰年数。21世纪C值=3.87，22世纪C值=4.15。
 
	if(!year){
		year = new Date().getFullYear();
	}
	
	var c = 0;
	var weight = 0.2422;
	
	if(year >= 2000 && year < 2100){
		c = 3.87
	}
	
	if(year >= 2100 && year < 2200){
		c = 4.15
	}
	
	year = year % 100;
	
	var day = Math.floor((year * weight + c) - ((year -1)/4));
	
	return new Date(year, 1, day);
 };
 
 PerpetualCalendar.prototype.getCalendar = function(){
	return this._perpetualCalendar;
 };
 
 PerpetualCalendar.getLunarYearGanZhiStr = function(year){
	if(year == null){
		return false;
	}
	
	year = year - 3;
	
	if(year < 0){
		year = -year;
	}
	
	var tianGanIndex = (year % 10 + 10 - 1)%10 ;
	var diZhiIndex = (year % 12 + 12 -1)%12;
	
	return BizEnum.TIANGAN[tianGanIndex] + BizEnum.DIZHI[diZhiIndex];
 };
 
 /**
  * 是否是闰年
  */ 
 PerpetualCalendar.isLeapYear = function(year){
	if((year % 4 == 0 && year % 100 != 0) || year % 400 == 0){
		return true;
	}
	
	return false;
 };