/**
 * simplefeastcalculator.js 
 * 简单的节气计算器
 *
 * @date 2014-01-03
 * @version 0.1
 */
 
 function SimpleFeastCalculator(){
 
 }
 
 SimpleFeastCalculator.consts = {
	"FEAST" : ["小寒", "大寒", "立春", "雨水", "惊蛰", "春分", "清明", "谷雨", "立夏", "小满", "芒种", "夏至", "小暑", "大暑", "立秋", "处暑", "白露", "秋分", "寒露", "霜降", "立冬", "小雪", "大雪", "冬至"],
	"TIMEDIFFERENCE" : [0.00, 1272494.40, 2548020.60, 3830143.80, 5120226.60, 6420865.80, 7732018.80,
						9055272.60, 10388958.00, 11733065.40, 13084292.40, 14441592.00, 15800560.80,
						17159347.20, 18513766.20, 19862002.20, 21201005.40, 22529659.80, 23846845.20,
						25152606.00, 26447687.40, 27733451.40, 29011921.20, 30285477.60],   // 时间差
	"BASETIMEPOINT" :  2415025.5868055555,         // 已知1900年小寒时刻为1月6日02:05:00 儒略历数
	"YEARLENGTH" : 365.242,           // 儒略年长度 
	"AVGYEARMONTHINFO" : [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31],  // 平年的每月天数信息
	"LEAPYEARMONTHINFO" : [31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31],  // 闰年的每月天数信息				   
 };
 
  SimpleFeastCalculator.calculateFeast = function(year, feast){
	if(!(year && feast)){
		return false;
	}
  
	var index = -1;
	
	for(var i = 0 ; i < BizEnum.FEASTS.length; i ++){
		if(BizEnum.FEASTS[i] === feast){
			index = i;
		}
	}
	
	if(index < 0){
		return false;
	}
	
	return SimpleFeastCalculator._calculateFeast(year, index);
  };
 
 SimpleFeastCalculator._calculateFeast = function(year, feastIndex){
	if(feastIndex < 0 || feastIndex > 23){
		return false;
	}
	
	//var specifyFeast = 365.24219878 * (year - 1900) + SimpleFeastCalculator.consts.TIMEDIFFERENCE[feastIndex] / 86400;
	
	//var integratedDay =SimpleFeastCalculator.consts.BASETIMEPOINT + specifyFeast;   // 积日
	
	var integratedDay = SimpleFeastCalculator.consts.YEARLENGTH * (year - 1900) + 6.18799 + 15.22567 * feastIndex - 1.9 * Math.sin(0.262 * feastIndex);
	
	//return integratedDay;
	var leftYear = Math.floor(integratedDay / SimpleFeastCalculator.consts.YEARLENGTH);

	var days = ((integratedDay / SimpleFeastCalculator.consts.YEARLENGTH) - leftYear) * SimpleFeastCalculator.consts.YEARLENGTH;
	
//	days += (8 / 24);
	
	var monthInfo = ZiWei.isLeapYear(year) ? SimpleFeastCalculator.consts.LEAPYEARMONTHINFO : SimpleFeastCalculator.consts.AVGYEARMONTHINFO;
	
	var month = 0;
	var day = -1;
	
	for(var i = 0 ; i < monthInfo.length; i ++){
		if(days < monthInfo[i]){
			day = days;
			
			break;
		}
		
		month ++;
		days -= monthInfo[i];
	}

	return new Date(year, month, day);
 };
 
 /**
  * 获取节气与月份对应表
  */
 SimpleFeastCalculator.getFeastMonthMap = function(){
	var map = new Array();
	
	for(var i = 0 ; i < BizEnum.FEASTS.length; i ++){
		var entry = {
			"feastName" : BizEnum.FEASTS[i],
			"month" : Math.floor(i/2) + 1,
			"index" : i % 2 == 0 ? 1 : 2
		};
		
		map.push(entry);
	}
	
	return map;
 };
 
 SimpleFeastCalculator.ifEnterNextFeast = function(year, month, day){
	if(!(year && month && day)){
		return false;
	}
	
	if(year < 1901 || year > 2099 || month < 1 || month > 12 || day < 1 || day > 31){
		return false;
	}
 
	var yearFeastData = SimpleFeastCalculator.getFeastsDataByYear(year);
	
	var jieQiObj = yearFeastData.feasts[(month -1) * 2];
    var zhongQiObj = yearFeastData.feasts[month * 2 - 1];
	
	if(jieQiObj.day == day){
		return jieQiObj.feastName;
	}
	
	if(zhongQiObj.day == day){
		return zhongQiObj.feastName;
	}
	
	return false;
 };
 
 SimpleFeastCalculator.getDaysOffSet = function(year, month, day, isDirect)
 {
	if(!(year && month && day)){
		return false;
	}
	
	if(year < 1901 || year > 2099 || month < 1 || month > 12 || day < 1 || day > 31){
		return false;
	}
 
	var yearFeastData = SimpleFeastCalculator.getFeastsDataByYear(year);

	var jieQiIndex = (month -1) * 2;
    var jieQiObj = yearFeastData.feasts[jieQiIndex];

	if(day < jieQiObj.day)
	{
		if(isDirect)
		{
			var fromDate = new Date(year, month - 1, day);
			var toDate = new Date(year, month - 1, jieQiObj.day);
			
			return PerpetualCalendar.getIntervalDays(fromDate, toDate) - 1;
		}
		else
		{
			if(jieQiIndex == 0)
			{
				yearFeastData = SimpleFeastCalculator.getFeastsDataByYear(year - 1);
				jieQiObj = yearFeastData.feasts[22];
				var toDate = new Date(year, month - 1, day);
				var fromDate = new Date(year - 1, 11, jieQiObj.day);
			
				return PerpetualCalendar.getIntervalDays(fromDate, toDate) - 1;
			}
			else
			{
				jieQiObj = yearFeastData.feasts[jieQiIndex - 2];
				var toDate = new Date(year, month -1, day);
				var fromDate = new Date(year, month - 2, jieQiObj.day);
			
				return PerpetualCalendar.getIntervalDays(fromDate, toDate) - 1;
			}
		}
	}
	else if(day == jieQiObj.day)
	{
		if(isDirect)
		{
			if(jieQiIndex == 22)
			{
				yearFeastData = SimpleFeastCalculator.getFeastsDataByYear(year + 1);
				jieQiObj = yearFeastData.feasts[0];
				var fromDate = new Date(year, month - 1, day);
				var toDate = new Date(year + 1, 0, jieQiObj.day);
				
				return PerpetualCalendar.getIntervalDays(fromDate, toDate) - 1;
			}
			else
			{
				jieQiObj = yearFeastData.feasts[jieQiIndex + 2];
				var fromDate = new Date(year, month - 1, day);
				var toDate = new Date(year, jieQiObj.month - 1, jieQiObj.day);
				
				return PerpetualCalendar.getIntervalDays(fromDate, toDate) - 1;
			}
		}
		else
		{
			if(jieQiIndex == 0)
			{
				yearFeastData = SimpleFeastCalculator.getFeastsDataByYear(year - 1);
				jieQiObj = yearFeastData.feasts[22];
				var toDate = new Date(year, month - 1, day);
				var fromDate = new Date(year - 1, 11, jieQiObj.day);
			
				return PerpetualCalendar.getIntervalDays(fromDate, toDate) - 1;
			}
			else
			{
				jieQiObj = yearFeastData.feasts[jieQiIndex - 2];
				var toDate = new Date(year, month - 1, day);
				var fromDate = new Date(year, month - 2, jieQiObj.day);
			
				return PerpetualCalendar.getIntervalDays(fromDate, toDate) - 1;
			}
		}
	}
	else
	{
		if(isDirect)
		{
			if(jieQiIndex == 22)
			{
				yearFeastData = SimpleFeastCalculator.getFeastsDataByYear(year + 1);
				jieQiObj = yearFeastData.feasts[0];
				var fromDate = new Date(year, month - 1, day);
				var toDate = new Date(year + 1, 0, jieQiObj.day);
				
				return PerpetualCalendar.getIntervalDays(fromDate, toDate) - 1;
			}
			else
			{
				jieQiObj = yearFeastData.feasts[jieQiIndex + 2];
				var fromDate = new Date(year, month - 1, day);
				var toDate = new Date(year, jieQiObj.month - 1, jieQiObj.day);
				
				return PerpetualCalendar.getIntervalDays(fromDate, toDate) - 1;
			}
		}
		else
		{
			var toDate = new Date(year, month - 1, day);
			var fromDate = new Date(year, month - 1, jieQiObj.day);
		
			return PerpetualCalendar.getIntervalDays(fromDate, toDate) - 1;
		}
	}

	return false;
 }
 
 /**
  * 根据公历时间获取当前节气
  */
 SimpleFeastCalculator.getFeastByDate = function(year, month, day){
	if(!(year && month && day)){
		return false;
	}
	
	if(year < 1901 || year > 2099 || month < 1 || month > 12 || day < 1 || day > 31){
		return false;
	}
 
	var yearFeastData = SimpleFeastCalculator.getFeastsDataByYear(year);
	
	var jieQiObj = yearFeastData.feasts[(month -1) * 2];
    var zhongQiObj = yearFeastData.feasts[month * 2 - 1];

	if(day < jieQiObj.day){
		if(month == 1){
			var temp = SimpleFeastCalculator.getFeastsDataByYear(year-1);
			
			return temp.feasts[temp.feasts.length-1].feastName;
		}
		
		return yearFeastData.feasts[(month - 1)* 2 - 1].feastName;
	}
	
	if(day >= zhongQiObj.day){
		return zhongQiObj.feastName;
	}
	
	if(day < zhongQiObj.day && day >= jieQiObj.day){
		return jieQiObj.feastName;
	}
 };
 
 /**
  * 根据年份获取节气数据(1901-2099)
  */
 SimpleFeastCalculator.getFeastsDataByYear = function(year){
	if(!year || year < 1901 || year > 2099){
		return false;
	}
	
	var data = SimpleFeastCalculator.parseData();
	
	return data[year-1901];
 };
 
 /**
  * 解析数据
  */
 SimpleFeastCalculator.parseData = function(){
	var data = SimpleFeastCalculator.getFeastsData();
	
	var feastsData = new Array();
	
	for(var i = 0 ; i < data.length; i ++){
		var year = 1901 + i;
		
		var feasts = data[i];
		
		var yearFeastData = new Array();
		
		for(var j = 0 ; j < feasts.length; j ++){
			SimpleFeastCalculator.consts.FEAST
			
			var feast = feasts[j];
			
			var jieQi = 15 - (feast >> 4);
			
			var zhongQi = 15 + (feast & 0xf);
			
			var month = j + 1;
			
			var jieQiObj = {
				"feastName" : BizEnum.FEASTS[2*j],
				"month" : month,
				"day" : jieQi,
				"nextFeast" :  BizEnum.FEASTS[2*j+1]
			};
			
			var zhongQiObj = {
				"feastName" : BizEnum.FEASTS[2*j+1],
				"month" : month,
				"day" : zhongQi,
				"nextFeast" :  BizEnum.FEASTS[2*(j+1) % 24]
			};
			
			yearFeastData.push(jieQiObj);
			yearFeastData.push(zhongQiObj);
		}
		
		feastsData.push({
			"year" : year,
			"feasts" : yearFeastData
		});
	}
	
	return feastsData;
 };
 
 SimpleFeastCalculator.getSpringBeginDateByYear = function(year){
	if(!year || year > 2099 || year < 1901){
		year = new Date().getFullYear();
	}
	
	var totalData = SimpleFeastCalculator.parseData();
	
	var yearData = totalData[year - 1901];
	
	var liChun = yearData.feasts[2];           // 立春
	
	return new Date(year, liChun.month - 1, liChun.day);
 };
 
 SimpleFeastCalculator.getFeastsData = function(){
	var data = [
	  [0x96,0xB4,0x96,0xA6,0x97,0x97,0x78,0x79,0x79,0x69,0x78,0x77],    //1901   
      [0x96,0xA4,0x96,0x96,0x97,0x87,0x79,0x79,0x79,0x69,0x78,0x78],    //1902   
      [0x96,0xA5,0x87,0x96,0x87,0x87,0x79,0x69,0x69,0x69,0x78,0x78],    //1903   
      [0x86,0xA5,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x79,0x78,0x87],    //1904   
      [0x96,0xB4,0x96,0xA6,0x97,0x97,0x78,0x79,0x79,0x69,0x78,0x77],    //1905   
      [0x96,0xA4,0x96,0x96,0x97,0x97,0x79,0x79,0x79,0x69,0x78,0x78],    //1906   
      [0x96,0xA5,0x87,0x96,0x87,0x87,0x79,0x69,0x69,0x69,0x78,0x78],    //1907   
      [0x86,0xA5,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x69,0x78,0x87],    //1908   
      [0x96,0xB4,0x96,0xA6,0x97,0x97,0x78,0x79,0x79,0x69,0x78,0x77],    //1909   
      [0x96,0xA4,0x96,0x96,0x97,0x97,0x79,0x79,0x79,0x69,0x78,0x78],    //1910   
      [0x96,0xA5,0x87,0x96,0x87,0x87,0x79,0x69,0x69,0x69,0x78,0x78],    //1911   
      [0x86,0xA5,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x69,0x78,0x87],    //1912   
      [0x95,0xB4,0x96,0xA6,0x97,0x97,0x78,0x79,0x79,0x69,0x78,0x77],    //1913   
      [0x96,0xB4,0x96,0xA6,0x97,0x97,0x79,0x79,0x79,0x69,0x78,0x78],    //1914   
      [0x96,0xA5,0x97,0x96,0x97,0x87,0x79,0x79,0x69,0x69,0x78,0x78],    //1915   
      [0x96,0xA5,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x79,0x77,0x87],    //1916   
      [0x95,0xB4,0x96,0xA6,0x96,0x97,0x78,0x79,0x78,0x69,0x78,0x87],    //1917   
      [0x96,0xB4,0x96,0xA6,0x97,0x97,0x79,0x79,0x79,0x69,0x78,0x77],    //1918   
      [0x96,0xA5,0x97,0x96,0x97,0x87,0x79,0x79,0x69,0x69,0x78,0x78],    //1919   
      [0x96,0xA5,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x79,0x77,0x87],    //1920   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x78,0x79,0x78,0x69,0x78,0x87],    //1921   
      [0x96,0xB4,0x96,0xA6,0x97,0x97,0x79,0x79,0x79,0x69,0x78,0x77],    //1922   
      [0x96,0xA4,0x96,0x96,0x97,0x87,0x79,0x79,0x69,0x69,0x78,0x78],    //1923   
      [0x96,0xA5,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x79,0x77,0x87],    //1924   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x78,0x79,0x78,0x69,0x78,0x87],    //1925   
      [0x96,0xB4,0x96,0xA6,0x97,0x97,0x78,0x79,0x79,0x69,0x78,0x77],    //1926   
      [0x96,0xA4,0x96,0x96,0x97,0x87,0x79,0x79,0x79,0x69,0x78,0x78],    //1927   
      [0x96,0xA5,0x96,0xA5,0x96,0x96,0x88,0x78,0x78,0x78,0x87,0x87],    //1928   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x79,0x77,0x87],    //1929   
      [0x96,0xB4,0x96,0xA6,0x97,0x97,0x78,0x79,0x79,0x69,0x78,0x77],    //1930   
      [0x96,0xA4,0x96,0x96,0x97,0x87,0x79,0x79,0x79,0x69,0x78,0x78],    //1931   
      [0x96,0xA5,0x96,0xA5,0x96,0x96,0x88,0x78,0x78,0x78,0x87,0x87],    //1932   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x69,0x78,0x87],    //1933   
      [0x96,0xB4,0x96,0xA6,0x97,0x97,0x78,0x79,0x79,0x69,0x78,0x77],    //1934   
      [0x96,0xA4,0x96,0x96,0x97,0x97,0x79,0x79,0x79,0x69,0x78,0x78],    //1935   
      [0x96,0xA5,0x96,0xA5,0x96,0x96,0x88,0x78,0x78,0x78,0x87,0x87],    //1936   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x69,0x78,0x87],    //1937   
      [0x96,0xB4,0x96,0xA6,0x97,0x97,0x78,0x79,0x79,0x69,0x78,0x77],    //1938   
      [0x96,0xA4,0x96,0x96,0x97,0x97,0x79,0x79,0x79,0x69,0x78,0x78],    //1939   
      [0x96,0xA5,0x96,0xA5,0x96,0x96,0x88,0x78,0x78,0x78,0x87,0x87],    //1940   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x69,0x78,0x87],    //1941   
      [0x96,0xB4,0x96,0xA6,0x97,0x97,0x78,0x79,0x79,0x69,0x78,0x77],    //1942   
      [0x96,0xA4,0x96,0x96,0x97,0x97,0x79,0x79,0x79,0x69,0x78,0x78],    //1943   
      [0x96,0xA5,0x96,0xA5,0xA6,0x96,0x88,0x78,0x78,0x78,0x87,0x87],    //1944   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x79,0x77,0x87],    //1945   
      [0x95,0xB4,0x96,0xA6,0x97,0x97,0x78,0x79,0x78,0x69,0x78,0x77],    //1946   
      [0x96,0xB4,0x96,0xA6,0x97,0x97,0x79,0x79,0x79,0x69,0x78,0x78],    //1947   
      [0x96,0xA5,0xA6,0xA5,0xA6,0x96,0x88,0x88,0x78,0x78,0x87,0x87],    //1948   
      [0xA5,0xB4,0x96,0xA5,0x96,0x97,0x88,0x79,0x78,0x79,0x77,0x87],    //1949   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x78,0x79,0x78,0x69,0x78,0x77],    //1950   
      [0x96,0xB4,0x96,0xA6,0x97,0x97,0x79,0x79,0x79,0x69,0x78,0x78],    //1951   
      [0x96,0xA5,0xA6,0xA5,0xA6,0x96,0x88,0x88,0x78,0x78,0x87,0x87],    //1952   
      [0xA5,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x79,0x77,0x87],    //1953   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x78,0x79,0x78,0x68,0x78,0x87],    //1954   
      [0x96,0xB4,0x96,0xA6,0x97,0x97,0x78,0x79,0x79,0x69,0x78,0x77],    //1955   
      [0x96,0xA5,0xA5,0xA5,0xA6,0x96,0x88,0x88,0x78,0x78,0x87,0x87],    //1956   
      [0xA5,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x79,0x77,0x87],    //1957   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x69,0x78,0x87],    //1958   
      [0x96,0xB4,0x96,0xA6,0x97,0x97,0x78,0x79,0x79,0x69,0x78,0x77],    //1959   
      [0x96,0xA4,0xA5,0xA5,0xA6,0x96,0x88,0x88,0x88,0x78,0x87,0x87],    //1960   
      [0xA5,0xB4,0x96,0xA5,0x96,0x96,0x88,0x78,0x78,0x78,0x87,0x87],    //1961   
      [0x96,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x69,0x78,0x87],    //1962   
      [0x96,0xB4,0x96,0xA6,0x97,0x97,0x78,0x79,0x79,0x69,0x78,0x77],    //1963   
      [0x96,0xA4,0xA5,0xA5,0xA6,0x96,0x88,0x88,0x88,0x78,0x87,0x87],    //1964   
      [0xA5,0xB4,0x96,0xA5,0x96,0x96,0x88,0x78,0x78,0x78,0x87,0x87],    //1965   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x69,0x78,0x87],    //1966   
      [0x96,0xB4,0x96,0xA6,0x97,0x97,0x78,0x79,0x79,0x69,0x78,0x77],    //1967   
      [0x96,0xA4,0xA5,0xA5,0xA6,0xA6,0x88,0x88,0x88,0x78,0x87,0x87],    //1968   
      [0xA5,0xB4,0x96,0xA5,0x96,0x96,0x88,0x78,0x78,0x78,0x87,0x87],    //1969   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x69,0x78,0x87],    //1970   
      [0x96,0xB4,0x96,0xA6,0x97,0x97,0x78,0x79,0x79,0x69,0x78,0x77],    //1971   
      [0x96,0xA4,0xA5,0xA5,0xA6,0xA6,0x88,0x88,0x88,0x78,0x87,0x87],    //1972   
      [0xA5,0xB5,0x96,0xA5,0xA6,0x96,0x88,0x78,0x78,0x78,0x87,0x87],    //1973   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x69,0x78,0x87],    //1974   
      [0x96,0xB4,0x96,0xA6,0x97,0x97,0x78,0x79,0x78,0x69,0x78,0x77],    //1975   
      [0x96,0xA4,0xA5,0xB5,0xA6,0xA6,0x88,0x89,0x88,0x78,0x87,0x87],    //1976   
      [0xA5,0xB4,0x96,0xA5,0x96,0x96,0x88,0x88,0x78,0x78,0x87,0x87],    //1977   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x79,0x78,0x87],    //1978   
      [0x96,0xB4,0x96,0xA6,0x96,0x97,0x78,0x79,0x78,0x69,0x78,0x77],    //1979   
      [0x96,0xA4,0xA5,0xB5,0xA6,0xA6,0x88,0x88,0x88,0x78,0x87,0x87],    //1980   
      [0xA5,0xB4,0x96,0xA5,0xA6,0x96,0x88,0x88,0x78,0x78,0x77,0x87],    //1981   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x79,0x77,0x87],    //1982   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x78,0x79,0x78,0x69,0x78,0x77],    //1983   
      [0x96,0xB4,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x87],    //1984   
      [0xA5,0xB4,0xA6,0xA5,0xA6,0x96,0x88,0x88,0x78,0x78,0x87,0x87],    //1985   
      [0xA5,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x79,0x77,0x87],    //1986   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x79,0x78,0x69,0x78,0x87],    //1987   
      [0x96,0xB4,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x86],    //1988   
      [0xA5,0xB4,0xA5,0xA5,0xA6,0x96,0x88,0x88,0x88,0x78,0x87,0x87],    //1989   
      [0xA5,0xB4,0x96,0xA5,0x96,0x96,0x88,0x78,0x78,0x79,0x77,0x87],    //1990   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x69,0x78,0x87],    //1991   
      [0x96,0xB4,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x86],    //1992   
      [0xA5,0xB3,0xA5,0xA5,0xA6,0x96,0x88,0x88,0x88,0x78,0x87,0x87],    //1993   
      [0xA5,0xB4,0x96,0xA5,0x96,0x96,0x88,0x78,0x78,0x78,0x87,0x87],    //1994   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x76,0x78,0x69,0x78,0x87],    //1995   
      [0x96,0xB4,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x86],    //1996   
      [0xA5,0xB3,0xA5,0xA5,0xA6,0xA6,0x88,0x88,0x88,0x78,0x87,0x87],    //1997   
      [0xA5,0xB4,0x96,0xA5,0x96,0x96,0x88,0x78,0x78,0x78,0x87,0x87],    //1998   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x69,0x78,0x87],    //1999 
      [0x96,0xB4,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x86],    //2000   
      [0xA5,0xB3,0xA5,0xA5,0xA6,0xA6,0x88,0x88,0x88,0x78,0x87,0x87],    //2001   
      [0xA5,0xB4,0x96,0xA5,0x96,0x96,0x88,0x78,0x78,0x78,0x87,0x87],    //2002   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x69,0x78,0x87],    //2003   
      [0x96,0xB4,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x86],    //2004   
      [0xA5,0xB3,0xA5,0xA5,0xA6,0xA6,0x88,0x88,0x88,0x78,0x87,0x87],    //2005   
      [0xA5,0xB4,0x96,0xA5,0xA6,0x96,0x88,0x88,0x78,0x78,0x87,0x87],    //2006   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x69,0x78,0x87],    //2007   
      [0x96,0xB4,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x87,0x78,0x87,0x86],    //2008   
      [0xA5,0xB3,0xA5,0xB5,0xA6,0xA6,0x88,0x88,0x88,0x78,0x87,0x87],    //2009   
      [0xA5,0xB4,0x96,0xA5,0xA6,0x96,0x88,0x88,0x78,0x78,0x87,0x87],    //2010   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x79,0x78,0x87],    //2011   
      [0x96,0xB4,0xA5,0xB5,0xA5,0xA6,0x87,0x88,0x87,0x78,0x87,0x86],    //2012   
      [0xA5,0xB3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x87],    //2013   
      [0xA5,0xB4,0x96,0xA5,0xA6,0x96,0x88,0x88,0x78,0x78,0x87,0x87],    //2014   
      [0x95,0xB4,0x96,0xA5,0x96,0x97,0x88,0x78,0x78,0x79,0x77,0x87],    //2015   
      [0x95,0xB4,0xA5,0xB4,0xA5,0xA6,0x87,0x88,0x87,0x78,0x87,0x86],    //2016   
      [0xA5,0xC3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x87],    //2017   
      [0xA5,0xB4,0xA6,0xA5,0xA6,0x96,0x88,0x88,0x78,0x78,0x87,0x87],    //2018   
      [0xA5,0xB4,0x96,0xA5,0x96,0x96,0x88,0x78,0x78,0x79,0x77,0x87],    //2019   
      [0x95,0xB4,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x78,0x87,0x86],    //2020   
      [0xA5,0xC3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x86],    //2021   
      [0xA5,0xB4,0xA5,0xA5,0xA6,0x96,0x88,0x88,0x88,0x78,0x87,0x87],    //2022   
      [0xA5,0xB4,0x96,0xA5,0x96,0x96,0x88,0x78,0x78,0x79,0x77,0x87],    //2023   
      [0xA5,0xB4,0x96,0xA5,0x96,0x96,0x88,0x78,0x78,0x79,0x77,0x87],    //2023   
      [0x95,0xB4,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x78,0x87,0x96],    //2024   
      [0xA5,0xC3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x86],    //2025   
      [0xA5,0xB3,0xA5,0xA5,0xA6,0xA6,0x88,0x88,0x88,0x78,0x87,0x87],    //2026   
      [0xA5,0xB4,0x96,0xA5,0x96,0x96,0x88,0x78,0x78,0x78,0x87,0x87],    //2027   
      [0x95,0xB4,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x78,0x87,0x96],    //2028   
      [0xA5,0xC3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x86],    //2029   
      [0xA5,0xB3,0xA5,0xA5,0xA6,0xA6,0x88,0x88,0x88,0x78,0x87,0x87],    //2030   
      [0xA5,0xB4,0x96,0xA5,0x96,0x96,0x88,0x78,0x78,0x78,0x87,0x87],    //2031   
      [0x95,0xB4,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x78,0x87,0x96],    //2032   
      [0xA5,0xC3,0xA5,0xB5,0xA6,0xA6,0x88,0x88,0x88,0x78,0x87,0x86],    //2033   
      [0xA5,0xB3,0xA5,0xA5,0xA6,0xA6,0x88,0x78,0x88,0x78,0x87,0x87],    //2034   
      [0xA5,0xB4,0x96,0xA5,0xA6,0x96,0x88,0x88,0x78,0x78,0x87,0x87],    //2035   
      [0x95,0xB4,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x78,0x87,0x96],    //2036   
      [0xA5,0xC3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x86],    //2037   
      [0xA5,0xB3,0xA5,0xA5,0xA6,0xA6,0x88,0x88,0x88,0x78,0x87,0x87],    //2038   
      [0xA5,0xB4,0x96,0xA5,0xA6,0x96,0x88,0x88,0x78,0x78,0x87,0x87],    //2039   
      [0x95,0xB4,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x78,0x87,0x96],    //2040   
      [0xA5,0xC3,0xA5,0xB5,0xA5,0xA6,0x87,0x88,0x87,0x78,0x87,0x86],    //2041   
      [0xA5,0xB3,0xA5,0xB5,0xA6,0xA6,0x88,0x88,0x88,0x78,0x87,0x87],    //2042   
      [0xA5,0xB4,0x96,0xA5,0xA6,0x96,0x88,0x88,0x78,0x78,0x87,0x87],    //2043   
      [0x95,0xB4,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x88,0x87,0x96],    //2044   
      [0xA5,0xC3,0xA5,0xB4,0xA5,0xA6,0x87,0x88,0x87,0x78,0x87,0x86],    //2045   
      [0xA5,0xB3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x87],    //2046   
      [0xA5,0xB4,0x96,0xA5,0xA6,0x96,0x88,0x88,0x78,0x78,0x87,0x87],    //2047   
      [0x95,0xB4,0xA5,0xB4,0xA5,0xA5,0x97,0x87,0x87,0x88,0x86,0x96],    //2048   
      [0xA4,0xC3,0xA5,0xA5,0xA5,0xA6,0x97,0x87,0x87,0x78,0x87,0x86],    //2049   
      [0xA5,0xC3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x78,0x78,0x87,0x87],    //2050
	  [0xA5,0xB4,0xA5,0xA5,0xA6,0x96,0x88,0x88,0x88,0x78,0x87,0x87],    //2051 
	  [0xA5,0xB4,0xA5,0xB4,0xA5,0xA5,0x97,0x87,0x87,0x88,0x86,0x96],    //2052 
	  [0xA4,0xC3,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x78,0x87,0x86],    //2053 
	  [0xA5,0xC3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x87],    //2054 
	  [0xA5,0xB4,0xA5,0xA5,0xA6,0xA6,0x88,0x88,0x88,0x78,0x87,0x87],    //2055 
      [0xA5,0xB4,0xA5,0xB4,0xA5,0xA5,0x97,0x87,0x87,0x88,0x86,0x96],    //2056 
      [0xA4,0xC3,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x78,0x87,0x96],    //2057 
      [0xA5,0xC3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x86],    //2058 
      [0xA5,0xB4,0xA5,0xA5,0xA6,0xA6,0x88,0x88,0x88,0x78,0x87,0x87],    //2059 
      [0xA5,0xB4,0xA5,0xB4,0xA5,0xA5,0x97,0x87,0x87,0x87,0x96,0x96],    //2060 
      [0xA4,0xC3,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x78,0x87,0x96],    //2061 
      [0xA5,0xC3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x86],    //2062 
      [0xA5,0xB3,0xA5,0xA5,0xA6,0xA6,0x88,0x88,0x88,0x78,0x87,0x87],    //2063 
      [0xA5,0xB4,0xA5,0xB4,0xA5,0xA5,0x97,0x87,0x87,0x87,0x96,0x96],    //2064 
      [0xA4,0xC3,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x78,0x87,0x96],    //2065 
      [0xA5,0xC3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x86],    //2066 
      [0xA5,0xB3,0xA5,0xA5,0xA6,0xA6,0x88,0x88,0x88,0x78,0x87,0x87],    //2067 
      [0xA5,0xB4,0xA5,0xB4,0xB5,0xA5,0x97,0x97,0x87,0x87,0x96,0x96],    //2068 
      [0xA4,0xC3,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x78,0x87,0x96],    //2060 
      [0xA5,0xC3,0xA5,0xB5,0xA5,0xA6,0x87,0x88,0x87,0x78,0x87,0x86],    //2070 
      [0xA5,0xB3,0xA5,0xA5,0xA6,0xA6,0x88,0x88,0x88,0x78,0x87,0x87],    //2071 
      [0xA5,0xB4,0xA5,0xB4,0xB5,0xA5,0x97,0x97,0x87,0x87,0x96,0x96],    //2072 
      [0xA4,0xC3,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x88,0x87,0x96],    //2073 
      [0xA5,0xC3,0xA5,0xB5,0xA5,0xA6,0x87,0x88,0x87,0x78,0x87,0x86],    //2074 
      [0xA5,0xB3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x87],    //2075 
      [0xA5,0xB4,0xA5,0xB4,0xB5,0xA5,0x97,0x97,0x87,0x87,0x96,0x96],    //2076 
      [0xA4,0xC3,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x88,0x87,0x96],    //2077 
      [0xA5,0xC3,0xA5,0xB4,0xA5,0xA6,0x97,0x88,0x87,0x78,0x87,0x86],    //2078 
      [0xA5,0xB3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x87],    //2079 
      [0xA5,0xB4,0xA5,0xB4,0xB5,0xA5,0x97,0x97,0x87,0x87,0x96,0x96],    //2080 
      [0xA4,0xC3,0xA5,0xB4,0xA5,0xA5,0x97,0x87,0x87,0x88,0x86,0x96],    //2081 
      [0xA5,0xC3,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x78,0x87,0x86],    //2082 
      [0xA5,0xC3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x87],    //2083 
      [0xA5,0xB4,0xB4,0xB4,0xB5,0xA5,0x97,0x97,0x97,0x87,0x96,0x96],    //2084 
      [0xB4,0xC3,0xA5,0xB4,0xA5,0xA5,0x97,0x87,0x87,0x88,0x86,0x96],    //2085 
      [0xA4,0xC3,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x78,0x87,0x86],    //2086 
      [0xA5,0xC3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x87],    //2087 
      [0xA5,0xB4,0xB4,0xB4,0xB5,0xB5,0x97,0x97,0x97,0x87,0x96,0x96],    //2088 
      [0xB4,0xC3,0xA5,0xB4,0xA5,0xA5,0x97,0x87,0x87,0x88,0x86,0x96],    //2089 
      [0xA4,0xC3,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x78,0x87,0x96],    //2090 
      [0xA5,0xC3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x86],    //2091 
      [0xA5,0xB4,0xB4,0xB4,0xB5,0xB5,0x97,0x97,0x97,0x87,0x96,0x96],    //2092 
      [0xB4,0xC3,0xA5,0xB4,0xA5,0xA5,0x97,0x87,0x87,0x87,0x96,0x96],    //2093 
      [0xA4,0xC3,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x78,0x87,0x96],    //2094 
      [0xA5,0xC3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x86],    //2095 
      [0xA5,0xB3,0xB4,0xB4,0xB5,0xB5,0x97,0x97,0x97,0x87,0x96,0x96],    //2096 
      [0xB4,0xC3,0xA5,0xB4,0xA5,0xA5,0x97,0x97,0x87,0x87,0x96,0x96],    //2097 
      [0xA4,0xC3,0xA5,0xB4,0xA5,0xA6,0x97,0x87,0x87,0x78,0x87,0x96],    //2098 
      [0xA5,0xC3,0xA5,0xB5,0xA6,0xA6,0x87,0x88,0x88,0x78,0x87,0x86],    //2099
      [0xA5,0xB3,0xA5,0xA5,0xA6,0xA6,0x88,0x88,0x88,0x78,0x87,0x87]     //2100   
	];
	
	return data;
 }