/**
 * MingPan.js
 * 命盘，基类，其他命盘继承自此
 *
 * @date 2014-01-08
 * @version 0.1
 */
 
namespace("com.taxen.framework.ziwei.core");

function MingPan(){
	this._items = false;                                         // 12宫位
	this._mingGongIndex = false;                                 // 命宫的位置
	this._shenGongIndex = false;                                 // 身宫的位置
	this._luCunIndex = false;                                    // 禄存位置
}

MingPan.prototype.init = function(personalInfo){
	// 1. 创建12块区域
	// 2. 设置每个宫位的地支
	// 3. 设置每个宫位的天干
	// 4. 设置每个宫位的宫位
	// 5. 设置星星组合
	// 6. 设置12长生
	
	this.createItems();
	this.setTianGan(personalInfo.getBirthday().getYearOfGanZhi().split("$")[0]);
	
	var sysCfg = SystemConfig.getConfig();

	var runYueConfig = sysCfg.getRunYueConfig();
	
	var lunarMonth = personalInfo.getBirthday().getLunarMonth().index;
	var isRunYue = personalInfo.getBirthday().isLunarRunYue();
	
	if(isRunYue){
		if("ASNEXTMONTH" == runYueConfig){
			lunarMonth ++;
		}else{
			if(personalInfo.getBirthday().getLunarDay().index >= 16){
				lunarMonth ++;
			}
		}
	}
	
	this.set12Gong(lunarMonth, personalInfo.getBirthday().getLunarHour());
	
	var mingGongGanZhi = this._items[this._mingGongIndex].getTianGan() + this._items[this._mingGongIndex].getDiZhi();
	personalInfo.setMingJu(mingGongGanZhi);
	
	this.setStars(personalInfo);
};

MingPan.prototype.getMingGongIndex = function(){
	return this._mingGongIndex;
};

MingPan.prototype.getItems = function(){
	return this._items;
};

/**
 * 创建12宫位
 */
MingPan.prototype.createItems = function(){
	var itemArr = new Array();
	
	for(var i = 0 ; i < 12; i ++){
		var item = new Section();
		
		item.setIndex(i + 1);
		item.setDiZhi(Util.getDiZhiByIndex(i));
		
		itemArr.push(item);
	}
	
	this._items = itemArr;
};

/**
 * 设置每个item的天干
 *
 * 依据：
 * 甲己之年丙作首，乙庚之年戊为头。
 * 丙辛岁首庚寅起，丁壬壬寅顺行流
 * 唯有戊癸从何起，正月便从甲寅行
 */
MingPan.prototype.setTianGan = function(tianGan){
	var index;
	
	if(tianGan === "TG_JIA" || tianGan === "TG_JI"){
		index = 2;
	}else if(tianGan === "TG_YI" || tianGan === "TG_GENG"){
		index = 4;
	}else if(tianGan === "TG_BING" || tianGan === "TG_XIN"){
		index = 6;
	}else if(tianGan === "TG_DING" || tianGan === "TG_REN"){
		index = 8;
	}else if(tianGan === "TG_WU" || tianGan === "TG_GUI"){
		index = 0;
	}
	
	var tianGanArr = new Array();
	
	for(var i = 0 ; i < BizEnum.DIZHI.length; i ++){
		this._items[i].setTianGan(Util.getTianGanByIndex(index));
		
		index ++;
		
		index = index % 10;
		
		if(i == 1){
			index -= 2;
			
			index = (index + 10) % 10;
		}
	
	}
};

/**
 * 设置12宫
 */
MingPan.prototype.set12Gong = function(lunarMonth, lunarHour, isRunYue, lunarDay){
	var defaultShenGong =  BizEnum.GONGWEI.SHENGONG;

	var startIndex = Util.getIndexByDiZhi("DZ_YIN");
	var hourIndex = Util.getIndexByDiZhi(lunarHour);

	if(isRunYue)
	{
		var sysCfg = SystemConfig.getConfig();
		var runYueConfig = sysCfg.getRunYueConfig();
		
		if("ASNEXTMONTH" == runYueConfig)
		{
			lunarMonth ++;
		}
		else
		{
			if(lunarDay >= 16)
			{
				lunarMonth ++;
			}
		}
	}
	
	var mingGongIndex = startIndex + lunarMonth - 1 - hourIndex; 
	var shenGongIndex = startIndex + lunarMonth - 1 + hourIndex; 
	
	mingGongIndex = (mingGongIndex + 12) % 12;
	shenGongIndex = (shenGongIndex + 12) % 12;
	
	var startIndexOf12Gong = this._mingGongIndex = mingGongIndex;
	var indexOfShenGong = this._shenGongIndex = shenGongIndex;
	
	var index = 0;
	
	// 知道命宫后逆排12宫
	for(var i = 0 ; i < BizEnum.GONGWEI.length; i ++){
		this._items[startIndexOf12Gong].setGongWei(Util.getGongWeiByIndex(i));
		startIndexOf12Gong --;
		
		startIndexOf12Gong = (startIndexOf12Gong + 12) % 12;
	}
	
	// 设置身宫
	var gongWei = this._items[indexOfShenGong].getGongWei();
	
	gongWei += "(GONGWEI_SHENGONG)";
	
	this._items[indexOfShenGong].setGongWei(gongWei);
};

/**
 * 设置星星
 */
MingPan.prototype.setStars = function(personalInfo){
	var lunarMonth = personalInfo.getBirthday().getLunarMonth().index;
	var lunarHour = personalInfo.getBirthday().getHour();
	var lunarYear = personalInfo.getBirthday().getLunarYear();
	var lunarDay = personalInfo.getBirthday().getLunarDay().index;
	var lunarYearOfGZ = personalInfo.getBirthday().getYearOfGanZhi();
	var mingJu = personalInfo.getMingJu();
	var gender = personalInfo.getGender();
	var genderDescriptor = personalInfo.getGenderDescriptor();
	var isRunYue = personalInfo.getBirthday().isLunarRunYue(); 
	var sysCfg = SystemConfig.getConfig();
	var runYueConfig = sysCfg.getRunYueConfig();
	
	if(isRunYue){
		if("ASNEXTMONTH" == runYueConfig){
			lunarMonth ++;
		}else{
			if(lunarDay >= 16){
				lunarMonth ++;
			}
		}
	}
	
	/*
	 * 1. 安紫微星
	 * 2. 安天府星
	 * 3. 安十四主星
	 * 4. 安其他星曜
	 */ 
	 
	 this._setZiWeiStar(mingJu, lunarDay);
	 
	 // 5. 安文昌文曲星
	 this._setWenChangWenQuStar(lunarHour);
	  
	 // 6. 安左辅右弼星
	 this._setZuoFuYouBiStar(lunarMonth);
	 
	 // 7. 安天魁天钺星
	 this._setTianKuiTianYueStar(lunarYearOfGZ);
	 
	 // 8. 安天马星
	 this._setTianMaStar(lunarYearOfGZ, lunarMonth, sysCfg.getTianMaStarConfig());

	 // 11. 安禄存星
	 this._luCunIndex = this._setLuCunStar(lunarYearOfGZ);
	 
	 // 12. 安擎羊陀罗二星
	 this._setQingYangTuoLuoStar(this._luCunIndex);
	 
	 // 13. 安火铃二星
	 this._setHuoLingStar(lunarYearOfGZ, lunarHour);
	 
	// 14. 安地空地劫星
	 this._setDiKongDiJieStar(lunarHour);
	 
	 	 // 10. 安阴煞星
	 //this._setYinShaStar(lunarMonth);
	 
	 // 9. 安解神星
	 //this._setJieShenStar(lunarMonth);
	 
	 // 15. 安天刑天姚星
	 this._setTianXingTianYaoStar(lunarMonth);
	 
	 // 16. 安三台八座二星
	 //this._setSanTaiBaZuoStar(lunarDay);
	 
	 // 17. 安恩光天贵星
	// this._setEnGuangTianGuiStar(lunarDay);
	  
	 // 18. 安龙池凤阁星
	 //this._setLongChiFengGeStar(lunarYearOfGZ);
	 
	 // 19. 安台辅星
	// this._setTaiFuStar(lunarHour);
	 
	 // 20. 安封诰星
	//this._setFengGaoStar(lunarHour);
	 
	 // 21. 安天官天福星
	//this._setTianGuanTianFuStar(lunarYearOfGZ);
	 
	 // 22. 安十二长生诀
	this._set12ChangShengJue(gender, genderDescriptor, mingJu);
	 
	 // 23. 安红鸾天喜星
	this._setHongLuanTianXiStar(lunarYearOfGZ);
	
	 // 24. 安孤辰寡宿星
	//this._setGuChenGuaXiuStar(lunarYearOfGZ);
	
	 // 25. 安蜚廉星
	//this._setFeiLianStar(lunarYearOfGZ);
	
	 // 26. 安破碎星
	//this._setPoSuiStar(lunarYearOfGZ);
	
	// 27. 安天才天寿星
	//this._setTianCaiTianShouStar(lunarYearOfGZ);
	
	// 28. 安截空星
	//this._setJieKongStar(lunarYearOfGZ);
	
	// 29. 安天空星
	//this._setTianKongStar(lunarYearOfGZ);
	
	// 30. 安天德月德星
	//this._setTianDeYueDeStar(lunarYearOfGZ);
	
	// 31. 安天厨星
	//this._setTianChuStar(lunarYearOfGZ);
	
	// 32. 安天巫星
	//this._setTianWuStar(lunarMonth);
	
	// 33. 安天哭天虚星
	//this._setTianKuTianXuStar(lunarYearOfGZ);
	
	// 34. 安旬空星
	//this._setXunKongStar(lunarYearOfGZ);
	
	// 35. 安天月星
	//this._setTianYueStar(lunarMonth);
	 
	// 36. 安天殇天使星
	//this._setTianShangTianShiStar();
	
	// 37. 安年解星 
	//this._setNianJieStar(lunarYearOfGZ);
	
	// 38. 安华盖星
	//this._setHuaGaiStar(lunarYearOfGZ);
};

/**
 * 安紫微星
 */
MingPan.prototype._setZiWeiStar = function(mingJu, lunarDate){
	var base = mingJu.index;
	var ziWeiIndex = -1;
	var mod = lunarDate % base;
	
	if(mod === 0){
		ziWeiIndex = (lunarDate / base) + 2 -1;
	}else{
		var yu = base - mod;           // 馀数
		
		if(yu % 2 == 0){
			ziWeiIndex = (Math.floor(lunarDate / base) + 1 + 2 -1 + 12 + yu) % 12;
		}else{
			ziWeiIndex = (Math.floor(lunarDate / base) + 1 + 2 -1 + 12 - yu) % 12;
		}
	}
	
	this._set14MainStar(ziWeiIndex % 12);
};

/**
 * 安天府星
 *
 * 根据：
 * 安天府星诀〈以紫微而转移〉
 * 天府南斗令，常对紫微宫，
 * 丑卯相更迭，未酉互为根。
 */
MingPan.prototype._setTianFuStar = function(ziWeiIndex){
	var tianFuIndex = -1;           // 天府星所在宫位的index
	
	if(ziWeiIndex < 5){
		tianFuIndex = 4 - ziWeiIndex;
	}else{
		tianFuIndex = 16 - ziWeiIndex;
	}
	
	var tianFuStar = Star.newInstance("MAINSTAR_TIANFUXING", tianFuIndex);
	
	this._items[tianFuIndex].addStar(tianFuStar);
};

/**
 * 安14主星
 */
MingPan.prototype._set14MainStar = function(ziWeiIndex){
	var starSequence = this._get14MainStarSequence(ziWeiIndex);
	
	for(var i = 0 ; i < this._items.length; i ++){
		var item = this._items[i];
		var stars = starSequence[i];
		
		for(var j = 0 ; j < stars.length; j ++){
			var star = stars[j];
			
			var _star = Star.newInstance(star.name, i);
			
			_star.setDescriptor(star.descriptor);
			
			item.addStar(_star);
		}
	}
};

/**
 * 获取主星的排列位置
 */
MingPan.prototype._get14MainStarSequence = function(ziWeiIndex){
	var starSequence = new Array();

	switch(ziWeiIndex){
		case 0 : {
			starSequence.push([{name : "MAINSTAR_ZIWEIXING", descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_ZIWEIXING", 0)}]);
			starSequence.push([]);
			starSequence.push([{name : "MAINSTAR_POJUNXING", descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_POJUNXING", 2)}]);
			starSequence.push([]);
			starSequence.push([{
				name : "MAINSTAR_LIANZHENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_LIANZHENXING", 4)
			}, {
				name : "MAINSTAR_TIANFUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANFUXING", 4)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TAIYINXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYINXING", 5)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TANLANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TANLANGXING", 6)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANTONGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANTONGXING", 7)
			}, {
				name : "MAINSTAR_JUMENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_JUMENXING", 7)
			}]);
			starSequence.push([{
				name : "MAINSTAR_WUQUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_WUQUXING", 8)
			}, {
				name : "MAINSTAR_TIANXIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANXIANGXING", 8)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TAIYANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYANGXING", 9)
			}, {
				name : "MAINSTAR_TIANLIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANLIANGXING", 9)
			}]);
			starSequence.push([{
				name : "MAINSTAR_QISHAXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_QISHAXING", 10)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANJIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANJIXING", 11)
			}]);
			
			break;
		}
		case 1 : {
			starSequence.push([{
				name : "MAINSTAR_TIANJIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANJIXING", 0)
			}]);
			starSequence.push([{
				name : "MAINSTAR_ZIWEIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_ZIWEIXING", 1)
			}, {
				name : "MAINSTAR_POJUNXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_POJUNXING", 1)
			}]);
			starSequence.push([]);
			starSequence.push([{
				name : "MAINSTAR_TIANFUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANFUXING", 3)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TAIYINXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYINXING", 4)
			}]);
			starSequence.push([{
				name : "MAINSTAR_LIANZHENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_LIANZHENXING", 5)
			}, {
				name : "MAINSTAR_TANLANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TANLANGXING", 5)
			}]);
			starSequence.push([{
				name : "MAINSTAR_JUMENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_JUMENXING", 6)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANXIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANXIANGXING", 7)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANTONGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANTONGXING", 8)
			}, {
				name : "MAINSTAR_TIANLIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANLIANGXING", 8)
			}]);
			starSequence.push([{
				name : "MAINSTAR_WUQUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_WUQUXING", 9)
			}, {
				name : "MAINSTAR_QISHAXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_QISHAXING", 9)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TAIYANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYANGXING", 10)
			}]);
			starSequence.push([]);
							
			break;
		}
		case 2 : {
			starSequence.push([{
				name : "MAINSTAR_POJUNXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_POJUNXING", 0)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANJIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANJIXING", 1)
			}]);
			starSequence.push([{
				name : "MAINSTAR_ZIWEIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_ZIWEIXING", 2)
			},{
				name : "MAINSTAR_TIANFUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANFUXING", 2)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TAIYINXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYINXING", 3)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TANLANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TANLANGXING", 4)
			}]);
			starSequence.push([{
				name : "MAINSTAR_JUMENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_JUMENXING", 5)
			}]);
			starSequence.push([{
				name : "MAINSTAR_LIANZHENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_LIANZHENXING", 6)
			}, {
				name : "MAINSTAR_TIANXIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANXIANGXING", 6)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANLIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANLIANGXING", 7)
			}]);
			starSequence.push([{
				name : "MAINSTAR_QISHAXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_QISHAXING", 8)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANTONGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANTONGXING", 9)
			}]);
			starSequence.push([{
				name : "MAINSTAR_WUQUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_WUQUXING", 10)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TAIYANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYANGXING", 11)
			}]);
			
			break;
		}	
		case 3 : {
			starSequence.push([{
				name : "MAINSTAR_TAIYANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYANGXING", 0)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANFUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANFUXING", 1)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANJIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANJIXING", 2)
			}, {
				name : "MAINSTAR_TAIYINXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYINXING", 2)
			}]);
			starSequence.push([{
				name : "MAINSTAR_ZIWEIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_ZIWEIXING", 3)
			}, {
				name : "MAINSTAR_TANLANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TANLANGXING", 3)
			}]);
			starSequence.push([{
				name : "MAINSTAR_JUMENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_JUMENXING", 4)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANXIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANXIANGXING", 5)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANLIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANLIANGXING", 6)
			}]);
			starSequence.push([{
				name : "MAINSTAR_LIANZHENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_LIANZHENXING", 7)
			}, {
				name : "MAINSTAR_QISHAXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_QISHAXING", 7)
			}]);
			starSequence.push([]);
			starSequence.push([]);
			starSequence.push([{
				name : "MAINSTAR_TIANTONGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANTONGXING", 10)
			}]);
			starSequence.push([{
				name : "MAINSTAR_WUQUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_WUQUXING", 11)
			}, {
				name : "MAINSTAR_POJUNXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_POJUNXING", 11)
			}]);
			
			break;
		}
		case 4 : {
			starSequence.push([{
				name : "MAINSTAR_WUQUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_WUQUXING", 0)
			}, {
				name : "MAINSTAR_TIANFUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANFUXING", 0)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TAIYANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYANGXING", 1)
			}, {
				name : "MAINSTAR_TAIYINXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYINXING", 1)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TANLANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TANLANGXING", 2)
			}]);
			starSequence.push([{
				name : "MAINSTAR_JUMENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_JUMENXING", 3)
			}, {
				name : "MAINSTAR_TIANJIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANJIXING", 3)
			}]);
			starSequence.push([{
				name : "MAINSTAR_ZIWEIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_ZIWEIXING", 4)
			}, {
				name : "MAINSTAR_TIANXIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANXIANGXING", 4)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANLIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANLIANGXING", 5)
			}]);
			starSequence.push([{
				name : "MAINSTAR_QISHAXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_QISHAXING", 6)
			}]);
			starSequence.push([]);
			starSequence.push([{
				name : "MAINSTAR_LIANZHENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_LIANZHENXING", 8)
			}]);
			starSequence.push([]);
			starSequence.push([{
				name : "MAINSTAR_POJUNXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_POJUNXING", 10)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANTONGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANTONGXING", 11)
			}]);
			
			break;
		}
		case 5 : {
			starSequence.push([{
				name : "MAINSTAR_TIANTONGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANTONGXING", 0)
			}, {
				name : "MAINSTAR_TAIYINXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYINXING", 0)
			}]);
			starSequence.push([{
				name : "MAINSTAR_WUQUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_WUQUXING", 1)
			}, {
				name : "MAINSTAR_TANLANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TANLANGXING", 1)
			}]);
			starSequence.push([{
				name : "MAINSTAR_JUMENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_JUMENXING", 2)
			}, {
				name : "MAINSTAR_TAIYANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYANGXING", 2)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANXIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANXIANGXING", 3)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANJIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANJIXING", 4)
			}, {
				name : "MAINSTAR_TIANLIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANLIANGXING", 4)
			}]);
			starSequence.push([{
				name : "MAINSTAR_ZIWEIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_ZIWEIXING", 5)
			}, {
				name : "MAINSTAR_QISHAXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_QISHAXING", 5)
			}]);
			starSequence.push([]);
			starSequence.push([]);
			starSequence.push([]);
			starSequence.push([{
				name : "MAINSTAR_LIANZHENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_LIANZHENXING", 9)
			}, {
				name : "MAINSTAR_POJUNXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_POJUNXING", 9)
			}]);
			starSequence.push([]);
			starSequence.push([{
				name : "MAINSTAR_TIANFUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANFUXING", 11)
			}]);
			
			break;
		}
		case 6 : {
			starSequence.push([{
				name : "MAINSTAR_TANLANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TANLANGXING", 0)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANTONGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANTONGXING", 1)
			}, {
				name : "MAINSTAR_JUMENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_JUMENXING", 1)
			}]);
			starSequence.push([{
				name : "MAINSTAR_WUQUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_WUQUXING", 2)
			}, {
				name : "MAINSTAR_TIANXIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANXIANGXING", 2)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TAIYANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYANGXING", 3)
			}, {
				name : "MAINSTAR_TIANLIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANLIANGXING", 3)
			}]);
			starSequence.push([{
				name : "MAINSTAR_QISHAXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_QISHAXING", 4)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANJIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANJIXING", 5)
			}]);
			starSequence.push([{
				name : "MAINSTAR_ZIWEIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_ZIWEIXING", 6)
			}]);
			starSequence.push([]);
			starSequence.push([{
				name : "MAINSTAR_POJUNXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_POJUNXING", 8)
			}]);
			starSequence.push([]);
			starSequence.push([{
				name : "MAINSTAR_LIANZHENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_LIANZHENXING", 10)
			}, {
				name : "MAINSTAR_TIANFUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANFUXING", 10)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TAIYINXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYINXING", 11)
			}]);			
			
			break;
		}
		case 7 : {
			starSequence.push([{
				name : "MAINSTAR_JUMENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_JUMENXING", 0)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANXIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANXIANGXING", 1)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANTONGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANTONGXING", 2)
			}, {
				name : "MAINSTAR_TIANLIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANLIANGXING", 2)
			}]);
			starSequence.push([{
				name : "MAINSTAR_WUQUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_WUQUXING", 3)
			}, {
				name : "MAINSTAR_QISHAXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_QISHAXING", 3)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TAIYANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYANGXING", 4)
			}]);
			starSequence.push([]);
			starSequence.push([{
				name : "MAINSTAR_TIANJIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANJIXING", 6)
			}]);
			starSequence.push([{
				name : "MAINSTAR_ZIWEIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_ZIWEIXING", 7)
			}, {
				name : "MAINSTAR_POJUNXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_POJUNXING", 7)
			}]);
			starSequence.push([]);
			starSequence.push([{
				name : "MAINSTAR_TIANFUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANFUXING", 9)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TAIYINXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYINXING", 10)
			}]);
			starSequence.push([{
				name : "MAINSTAR_LIANZHENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_LIANZHENXING", 11)
			}, {
				name : "MAINSTAR_TANLANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TANLANGXING", 11)
			}]);
			
			break;
		}
		case 8 : {
			starSequence.push([{
				name : "MAINSTAR_LIANZHENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_LIANZHENXING", 0)
			}, {
				name : "MAINSTAR_TIANXIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANXIANGXING", 0)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANLIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANLIANGXING", 1)
			}]);
			starSequence.push([{
				name : "MAINSTAR_QISHAXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_QISHAXING", 2)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANTONGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANTONGXING", 3)
			}]);
			starSequence.push([{
				name : "MAINSTAR_WUQUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_WUQUXING", 4)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TAIYANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYANGXING", 5)
			}]);
			starSequence.push([{
				name : "MAINSTAR_POJUNXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_POJUNXING", 6)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANJIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANJIXING", 7)
			}]);
			starSequence.push([{
				name : "MAINSTAR_ZIWEIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_ZIWEIXING", 8)
			}, {
				name : "MAINSTAR_TIANFUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANFUXING", 8)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TAIYINXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYINXING", 9)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TANLANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TANLANGXING", 10)
			}]);
			starSequence.push([{
				name : "MAINSTAR_JUMENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_JUMENXING", 11)
			}]);
			
			break;
		}
		case 9 : {
			starSequence.push([{
				name : "MAINSTAR_TIANLIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANLIANGXING", 0)
			}]);
			starSequence.push([{
				name : "MAINSTAR_LIANZHENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_LIANZHENXING", 1)
			}, {
				name : "MAINSTAR_QISHAXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_QISHAXING", 1)
			}]);
			starSequence.push([]);
			starSequence.push([]);
			starSequence.push([{
				name : "MAINSTAR_TIANTONGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANTONGXING", 4)
			}]);
			starSequence.push([{
				name : "MAINSTAR_WUQUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_WUQUXING", 5)
			}, {
				name : "MAINSTAR_POJUNXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_POJUNXING", 5)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TAIYANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYANGXING", 6)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANFUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANFUXING", 7)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANJIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANJIXING", 8)
			}, {
				name : "MAINSTAR_TAIYINXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYINXING", 8)
			}]);
			starSequence.push([{
				name : "MAINSTAR_ZIWEIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_ZIWEIXING", 9)
			}, {
				name : "MAINSTAR_TANLANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TANLANGXING", 9)
			}]);
			starSequence.push([{
				name : "MAINSTAR_JUMENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_JUMENXING", 10)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANXIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANXIANGXING", 11)
			}]);
			
			break;
		}
		case 10 : {
			starSequence.push([{
				name : "MAINSTAR_QISHAXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_QISHAXING", 0)
			}]);
			starSequence.push([]);
			starSequence.push([{
				name : "MAINSTAR_LIANZHENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_LIANZHENXING", 2)
			}]);
			starSequence.push([]);
			starSequence.push([{
				name : "MAINSTAR_POJUNXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_POJUNXING", 4)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANTONGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANTONGXING", 5)
			}]);
			starSequence.push([{
				name : "MAINSTAR_WUQUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_WUQUXING", 6)
			}, {
				name : "MAINSTAR_TIANFUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANFUXING", 6)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TAIYANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYANGXING", 7)
			}, {
				name : "MAINSTAR_TAIYINXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYINXING", 7)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TANLANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TANLANGXING", 8)
			}]);
			starSequence.push([{
				name : "MAINSTAR_JUMENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_JUMENXING", 9)
			}, {
				name : "MAINSTAR_TIANJIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANJIXING", 9)
			}]);
			starSequence.push([{
				name : "MAINSTAR_ZIWEIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_ZIWEIXING", 10)
			}, {
				name : "MAINSTAR_TIANXIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANXIANGXING", 10)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANLIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANLIANGXING", 11)
			}]);
			
			break;
		}
		case 11 : {
			starSequence.push([]);
			starSequence.push([]);
			starSequence.push([]);
			starSequence.push([{
				name : "MAINSTAR_LIANZHENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_LIANZHENXING", 3)
			}, {
				name : "MAINSTAR_POJUNXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_POJUNXING", 3)
			}]);
			starSequence.push([]);
			starSequence.push([{
				name : "MAINSTAR_TIANFUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANFUXING", 5)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANTONGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANTONGXING", 6)
			}, {
				name : "MAINSTAR_TAIYINXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYINXING", 6)
			}]);
			starSequence.push([{
				name : "MAINSTAR_WUQUXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_WUQUXING", 7)
			}, {
				name : "MAINSTAR_TANLANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TANLANGXING", 7)
			}]);
			starSequence.push([{
				name : "MAINSTAR_JUMENXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_JUMENXING", 8)
			}, {
				name : "MAINSTAR_TAIYANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TAIYANGXING", 8)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANXIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANXIANGXING", 9)
			}]);
			starSequence.push([{
				name : "MAINSTAR_TIANJIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANJIXING", 10)
			}, {
				name : "MAINSTAR_TIANLIANGXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_TIANLIANGXING", 10)
			}]);
			starSequence.push([{
				name : "MAINSTAR_ZIWEIXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_ZIWEIXING", 11)
			}, {
				name : "MAINSTAR_QISHAXING",
				descriptor : Util.getMiaoWangByStarAndIndex("MAINSTAR_QISHAXING", 11)
			}]);
			
			break;
		}
	}
	
	return starSequence;
};

/**
 * 安文昌文曲星
 */
MingPan.prototype._setWenChangWenQuStar = function(lunarHour){
	var wenChangStartIndex = Util.getIndexByDiZhi("DZ_XU");
	var wenQuStartIndex = Util.getIndexByDiZhi("DZ_CHEN"); 

	var index = Util.getIndexByDiZhi(Util.getLunarHour(lunarHour));

	var wenChangIndex = (wenChangStartIndex - index + 12) % 12;
	var wenQuIndex = (wenQuStartIndex + index) % 12;
	
	var wenChangStar = Star.newInstance("GEMSTAR_WENCHANGXING", wenChangIndex);
	this._items[wenChangIndex].addStar(wenChangStar);
	
	var wenQuStar = Star.newInstance("GEMSTAR_WENQUXING", wenQuIndex);
	this._items[wenQuIndex].addStar(wenQuStar);
};

/**
 * 安左辅右弼星
 */
MingPan.prototype._setZuoFuYouBiStar = function(lunarMonth){
	var zuoFuIndex = (Util.getIndexByDiZhi("DZ_CHEN") + lunarMonth - 1) % 12;
	
	var youBiIndex = (Util.getIndexByDiZhi("DZ_XU") - lunarMonth + 1 + 12) % 12;
	
	var zuoFuStar = Star.newInstance("GEMSTAR_ZUOFUXING", zuoFuIndex);
	this._items[zuoFuIndex].addStar(zuoFuStar);
	
	var youBiStar = Star.newInstance("GEMSTAR_YOUBIXING", youBiIndex);
	this._items[youBiIndex].addStar(youBiStar);
};

/**
 * 安天魁天钺星
 */
MingPan.prototype._setTianKuiTianYueStar = function(lunarYear){
	var tianGan = lunarYear.split("$")[0];
	
	var tianKuiIndex = -1;
	var tianYueIndex = -1;
	
	// 甲戊庚年，天魁在丑，天钺在未
	if(tianGan === "TG_JIA" || tianGan === "TG_WU" || tianGan === "TG_GENG"){
		tianKuiIndex = 1;
		tianYueIndex = 7;
	}
	
	// 乙己年，天魁在子，天钺在申
	if(tianGan === "TG_YI" || tianGan === "TG_JI"){
		tianKuiIndex = 0;
		tianYueIndex = 8;
	}
	
	// 辛年，天魁在午，天钺在寅
	if(tianGan === "TG_XIN"){
		tianKuiIndex = 6;
		tianYueIndex = 2;
	}
	
	// 壬癸年，天魁在卯，天钺在巳
	if(tianGan === "TG_REN" || tianGan === "TG_GUI"){
		tianKuiIndex = 3;
		tianYueIndex = 5;
	}
	
	// 丙丁年，天魁在亥，天钺在酉
	if(tianGan === "TG_BING" || tianGan === "TG_DING"){
		tianKuiIndex = 11;
		tianYueIndex = 9;
	}
	
	var tianKuiStar = Star.newInstance("GEMSTAR_TIANKUIXING", tianKuiIndex);
	this._items[tianKuiIndex].addStar(tianKuiStar);
	
	var tianYueStar = Star.newInstance("GEMSTAR_TIANYUEXING", tianYueIndex);
	this._items[tianYueIndex].addStar(tianYueStar);
};

/**
 * 安天马星
 */
MingPan.prototype._setTianMaStar = function(lunarYear, lunarMonth, type){
	// 寅午戌人马居申，申子辰人马居寅，巳酉丑人马居亥，亥卯未人马居巳
	
	var dizhi = false;
	
	if("BIRTHMONTH_BASED" == type){
		var startIndex =  Util.getIndexByDiZhi("DZ_YIN");
		var index = startIndex + lunarMonth - 1;
		index = index % 12;
		dizhi = Util.getDiZhiByIndex(index);
	}else if("BIRTHYEAR_BASED" == type){
		dizhi = lunarYear.split("$")[1];
	}
	
	var tianMaIndex = -1;
	
	if(dizhi === "DZ_YIN" || dizhi === "DZ_WU" || dizhi === "DZ_XU"){
		tianMaIndex = Util.getIndexByDiZhi("DZ_SHEN");
	}
	
	if(dizhi=== "DZ_SHEN" || dizhi === "DZ_ZI" || dizhi === "DZ_CHEN"){
		tianMaIndex = Util.getIndexByDiZhi("DZ_YIN");
	}
	
	if(dizhi === "DZ_SI" || dizhi === "DZ_YOU" || dizhi === "DZ_CHOU"){
		tianMaIndex = Util.getIndexByDiZhi("DZ_HAI");
	}
	
	if(dizhi === "DZ_HAI" || dizhi === "DZ_MAO" || dizhi === "DZ_WEI"){
		tianMaIndex = Util.getIndexByDiZhi("DZ_SI");
	}
	
	var tianMaStar = Star.newInstance("GEMSTAR_TIANMAXING", tianMaIndex);
	this._items[tianMaIndex].addStar(tianMaStar);
};

/**
 * 安解神星
 */
MingPan.prototype._setJieShenStar = function(lunarMonth){
	var jieShenIndex = -1;
	
	// 正二解申三四戌，五六解子七八寅，九月十月解在辰，十一十二在午宫
	if(lunarMonth === 1 || lunarMonth === 2){
		jieShenIndex = 8;
	}
	
	if(lunarMonth === 3 || lunarMonth === 4){
		jieShenIndex = 10;
	}
	
	if(lunarMonth === 5 || lunarMonth === 6){
		jieShenIndex = 0;
	}
	
	if(lunarMonth === 7 || lunarMonth === 8){
		jieShenIndex = 2;
	}
	
	if(lunarMonth === 9 || lunarMonth === 10){
		jieShenIndex = 4;
	}
	
	if(lunarMonth === 11 || lunarMonth === 12){
		jieShenIndex = 6;
	}
	
	var jieShenStar = Star.newInstance("NORMALSTAR_JIESHENXING", jieShenIndex);
	this._items[jieShenIndex].addStar(jieShenStar);
};

/**
 * 安天巫星
 */
MingPan.prototype._setTianWuStar = function(lunarMonth){

	var startIndex =  Util.getIndexByDiZhi("DZ_YIN");
	var index = startIndex + lunarMonth - 1;
	index = index % 12;
	
	var dizhi = Util.getDiZhiByIndex(index);

	var tianWuIndex = -1;
	
	// 寅午戌月在巳宫，申子辰月在寅宫，亥卯未月在申宫，巳酉丑月在亥宫
	if(dizhi == "DZ_YIN" || dizhi == "DZ_WU" || dizhi == "DZ_XU"){
		tianWuIndex = Util.getIndexByDiZhi("DZ_SI");
	}
	
	if(dizhi == "DZ_SHEN" || dizhi == "DZ_ZI" || dizhi == "DZ_CHEN"){
		tianWuIndex = Util.getIndexByDiZhi("DZ_YIN");
	}
	
	if(dizhi == "DZ_HAI" || dizhi == "DZ_MAO" || dizhi == "DZ_WEI"){
		tianWuIndex = Util.getIndexByDiZhi("DZ_SHEN");
	}
	
	if(dizhi == "DZ_SI" || dizhi == "DZ_YOU" || dizhi == "DZ_CHOU"){
		tianWuIndex = Util.getIndexByDiZhi("DZ_HAI");
	}
	
	var tianWuStar = Star.newInstance("NORMALSTAR_TIANWUXING", tianWuIndex);
	this._items[tianWuIndex].addStar(tianWuStar);
};

/**
 * 安天月星
 */
MingPan.prototype._setTianYueStar = function(lunarMonth){
	// 正月在戌二月巳，三月辰兮四月寅，
	// 五月未来六月卯，七亥八未九在寅，
	// 十月在午十一戌，十二天月寅上寻
	var tianYueIndex = -1;

	switch(lunarMonth){
		case 1 : tianYueIndex = 10; break;
		case 2 : tianYueIndex = 5; break;
		case 3 : tianYueIndex = 4; break;
		case 4 : tianYueIndex = 2; break;
		case 5 : tianYueIndex = 7; break;
		case 6 : tianYueIndex = 3; break;
		case 7 : tianYueIndex = 11; break;
		case 8 : tianYueIndex = 7; break;
		case 9 : tianYueIndex = 2; break;
		case 10 : tianYueIndex = 6; break;
		case 11 : tianYueIndex = 10; break;
		case 12 : tianYueIndex = 2; break;
		default : break;
	}
	
	if(tianYueIndex < 0){
		return false;
	}
	
	var tianYueStar = Star.newInstance("NORMALSTAR_TIANYUEXING", tianYueIndex);
	this._items[tianYueIndex].addStar(tianYueStar);
};

/**
 * 安阴煞星
 */
MingPan.prototype._setYinShaStar = function(lunarMonth){
	// 正七月在寅，二八月在子，
	// 三九月在戌，四十月在申，
	// 五及十一午，六及十二辰
	var yinShaIndex = -1;

	switch(lunarMonth){
		case 1 :
		case 7 : yinShaIndex = 2; break;
		case 2 :
		case 8 : yinShaIndex = 0; break;
		case 3 :
		case 9 : yinShaIndex = 10; break;
		case 4 :
		case 10 : yinShaIndex = 8; break;
		case 5 :
		case 11 : yinShaIndex = 6; break;
		case 6 :
		case 12 : yinShaIndex = 4; break;
		default : break;
	}
	
	var yinShaStar = Star.newInstance("NORMALSTAR_YINSHAXING", yinShaIndex);
	this._items[yinShaIndex].addStar(yinShaStar);
};

/**
 * 安禄存星
 */
MingPan.prototype._setLuCunStar = function(lunarYear){
	var tiangan = lunarYear.split("$")[0];

	// 甲生禄存在寅宫，乙生在卯丙戊巳，丁己禄存停午方，庚禄居申辛禄酉，壬禄在亥癸禄子
	var luCunIndex = -1;
	
	switch(tiangan){
		case "TG_JIA" : luCunIndex = Util.getIndexByDiZhi("DZ_YIN"); break;
		case "TG_YI" : luCunIndex = Util.getIndexByDiZhi("DZ_MAO"); break;
		case "TG_BING" : 
		case "TG_WU" : luCunIndex = Util.getIndexByDiZhi("DZ_SI"); break;
		case "TG_DING" : 
		case "TG_JI" : luCunIndex = Util.getIndexByDiZhi("DZ_WU"); break;
		case "TG_GENG" : luCunIndex = Util.getIndexByDiZhi("DZ_SHEN"); break;
		case "TG_XIN" : luCunIndex = Util.getIndexByDiZhi("DZ_YOU"); break;
		case "TG_REN" : luCunIndex = Util.getIndexByDiZhi("DZ_HAI"); break;
		case "TG_GUI" : luCunIndex = Util.getIndexByDiZhi("DZ_ZI"); break;
		default: break;
	}
	
	var luCunStar = Star.newInstance("GEMSTAR_LUCUNXING", luCunIndex);
	this._items[luCunIndex].addStar(luCunStar);
	
	return luCunIndex;
};

/** 
 * 安擎羊陀罗二星
 */
MingPan.prototype._setQingYangTuoLuoStar = function(luCunIndex){
	// 禄前擎羊后陀罗，夹限逢凶祸患多，岁限逢之俱不利，人生遇此莫蹉跎
	
	var qingYangIndex = (luCunIndex + 12 + 1) % 12;
	var tuoLuoIndex = (luCunIndex + 12 - 1) % 12;
	
	var qingYangStar = Star.newInstance("FIENDSTAR_QINGYANGXING", qingYangIndex);
	this._items[qingYangIndex].addStar(qingYangStar);
	
	var tuoLuoStar = Star.newInstance("FIENDSTAR_TUOLUOXING", tuoLuoIndex);
	this._items[tuoLuoIndex].addStar(tuoLuoStar);
};

/**
 * 安火铃二星
 */
MingPan.prototype._setHuoLingStar = function(lunarYear, lunarHour){
	// 寅午戌人丑卯方，申子辰人寅戌扬，巳酉丑人卯戌位，亥卯未人酉戌房
	
	var defaultHuoBeginIndex = -1;
	var defaultLingBeginIndex = -1;
	
	var lunarHourIndex = Util.getIndexByDiZhi(Util.getLunarHour(lunarHour));
	
	var dizhi = lunarYear.split("$")[1];
	switch(dizhi){
		case "DZ_YIN" :
		case "DZ_WU" :
		case "DZ_XU" : {
			defaultHuoBeginIndex = Util.getIndexByDiZhi("DZ_CHOU");
			defaultLingBeginIndex = Util.getIndexByDiZhi("DZ_MAO");
			break;
		}
		case "DZ_SHEN" :
		case "DZ_ZI" :
		case "DZ_CHEN" : {
			defaultHuoBeginIndex = Util.getIndexByDiZhi("DZ_YIN");
			defaultLingBeginIndex = Util.getIndexByDiZhi("DZ_XU");
			break;
		}
		case "DZ_SI" :
		case "DZ_YOU" :
		case "DZ_CHOU" : {
			defaultHuoBeginIndex = Util.getIndexByDiZhi("DZ_MAO");
			defaultLingBeginIndex = Util.getIndexByDiZhi("DZ_XU");
			break;
		}
		case "DZ_HAI" :
		case "DZ_MAO" :
		case "DZ_WEI" : {
			defaultHuoBeginIndex = Util.getIndexByDiZhi("DZ_YOU");
			defaultLingBeginIndex = Util.getIndexByDiZhi("DZ_XU");
			break;
		}
		default : break;
	}
	
	var huoIndex = (defaultHuoBeginIndex + lunarHourIndex) % 12;
	var lingIndex = (defaultLingBeginIndex + lunarHourIndex) % 12;
	
	var huoStar = Star.newInstance("FIENDSTAR_HUOXING", huoIndex);
	this._items[huoIndex].addStar(huoStar);
	
	var lingStar = Star.newInstance("FIENDSTAR_LINGXING", lingIndex);
	this._items[lingIndex].addStar(lingStar);
};

/**
 * 安地空地劫星
 */
MingPan.prototype._setDiKongDiJieStar = function(lunarHour){
	var defaultStartIndex = Util.getIndexByDiZhi("DZ_HAI");
	var lunarIndex = Util.getIndexByDiZhi(Util.getLunarHour(lunarHour));
	
	var diKongIndex = (defaultStartIndex - lunarIndex + 12) % 12;
	var diJieIndex = (defaultStartIndex + lunarIndex + 12) % 12;
	
	var diJieStar = Star.newInstance("FIENDSTAR_DIJIEXING", diJieIndex);
	this._items[diJieIndex].addStar(diJieStar);
	
	var diKongStar = Star.newInstance("FIENDSTAR_DIKONGXING", diKongIndex);
	this._items[diKongIndex].addStar(diKongStar);
};

/**
 * 安天殇天使星
 */
MingPan.prototype._setTianShangTianShiStar = function(){
	for(var i = 0 ; i < this._items.length; i ++){
		var item = this._items[i];
		
		var gongWei = item.getGongWei();
		
		if(gongWei === "GONGWEI_JIAOYOUGONG"){
			var tianShangStar = Star.newInstance("NORMALSTAR_TIANSHANGXING", i);
			item.addStar(tianShangStar);
		}
		
		if(gongWei === "GONGWEI_JIEGONG"){
			var tianShiStar = Star.newInstance("NORMALSTAR_TIANSHIXING", i);
			item.addStar(tianShiStar);
		}
	}
};

/**
 * 安天刑天姚星
 */
MingPan.prototype._setTianXingTianYaoStar = function(lunarMonth){
	var monthIndex = lunarMonth - 1;
	var defaultTianXingIndex = Util.getIndexByDiZhi("DZ_YOU");
	var defaultTianYaoIndex = Util.getIndexByDiZhi("DZ_CHOU");
	
	var tianXingIndex = (defaultTianXingIndex + monthIndex) % 12;
	var tianYaoIndex = (defaultTianYaoIndex + monthIndex) % 12;
	
	var tianXingStar = Star.newInstance("NORMALSTAR_TIANXINGXING", tianXingIndex);
	this._items[tianXingIndex].addStar(tianXingStar);
	
	var tianYaoStar = Star.newInstance("NORMALSTAR_TIANYAOXING", tianYaoIndex);
	this._items[tianYaoIndex].addStar(tianYaoStar);
};

/**
 * 安三台八座二星
 *
 * @param lunarDay  农历哪天
 */
MingPan.prototype._setSanTaiBaZuoStar = function(lunarDay){
	var lunarDayIndex = lunarDay % 12;

	for(var i = 0 ; i < this._items.length; i ++){
		var item = this._items[i];
		
		var stars = item.getStars();
		
		stars = stars || [];
		
		for(var j = 0 ; j < stars.length; j ++){
			var star = stars[j];
			
			if("GEMSTAR_ZUOFUXING" === star.getName()){
				var sanTaiIndex = (lunarDayIndex + i - 1 + 12) % 12;
				
				var sanTaiStar = Star.newInstance("NORMALSTAR_SANTAIXING", sanTaiIndex);
				this._items[sanTaiIndex].addStar(sanTaiStar);
			}
			
			if("GEMSTAR_YOUBIXING" === star.getName()){
				var baZuoIndex = (i - lunarDayIndex + 1 + 12) % 12;
				
				var baZuoStar = Star.newInstance("NORMALSTAR_BAZUOXING", baZuoIndex);
				this._items[baZuoIndex].addStar(baZuoStar);
			}
		}
	}
};

/**
 * 安恩光天贵星
 */
MingPan.prototype._setEnGuangTianGuiStar = function(lunarDay){
	var lunarDayIndex = lunarDay % 12;

	for(var i = 0 ; i < this._items.length; i ++){
		var item = this._items[i];
		
		var stars = item.getStars();
		
		stars = stars || [];
		
		for(var j = 0 ; j < stars.length; j ++){
			var star = stars[j];
			
			if("GEMSTAR_WENCHANGXING" === star.getName()){
				var enGuangIndex = (lunarDayIndex + i - 2 + 12) % 12;
				
				var enGuangStar = Star.newInstance("NORMALSTAR_ENGUANGXING", enGuangIndex);
				this._items[enGuangIndex].addStar(enGuangStar);
			}
			
			if("GEMSTAR_WENQUXING" === star.getName()){
				var tianGuiIndex = (i + lunarDayIndex -2 + 12) % 12;
				
				var tianGuiStar = Star.newInstance("NORMALSTAR_TIANGUIXING", tianGuiIndex);
				this._items[tianGuiIndex].addStar(tianGuiStar);
			}
		}
	}
};

/**
 * 安天哭天虚星
 */
MingPan.prototype._setTianKuTianXuStar = function(lunarYear){
	// 天哭天虚起午宫。午宫起子两分踪。哭逆巳兮虚顺未。数到生年便居中
	
	var defaultStartIndex = Util.getIndexByDiZhi("DZ_WU");
	
	var dizhi = lunarYear.split("$")[1];
	var lunarYearIndex = Util.getIndexByDiZhi(dizhi);
	
	var tianKuIndex = (defaultStartIndex - lunarYearIndex + 12) % 12;
	var tianXuIndex = (defaultStartIndex + lunarYearIndex) % 12;
	
	var tianKuStar = Star.newInstance("NORMALSTAR_TIANKUXING", tianKuIndex);
	this._items[tianKuIndex].addStar(tianKuStar);
				
	var tianXuStar = Star.newInstance("NORMALSTAR_TIANXUXING", tianXuIndex);
	this._items[tianXuIndex].addStar(tianXuStar);
};

/**
 * 安龙池凤阁星
 */
MingPan.prototype._setLongChiFengGeStar = function(lunarYear){
	// 龙池子顺辰，凤阁子戌逆
	
	var defaultLongChiStartIndex = Util.getIndexByDiZhi("DZ_CHEN");
	var defaultFengGeStartIndex = Util.getIndexByDiZhi("DZ_XU");
	var lunarYearIndex = Util.getIndexByDiZhi(lunarYear.split("$")[1]);
	
	var longChiIndex = (defaultLongChiStartIndex + lunarYearIndex) % 12;
	var fengGeIndex = (defaultFengGeStartIndex - lunarYearIndex + 12) % 12;
	
	var longChiStar = Star.newInstance("NORMALSTAR_LONGCHIXING", longChiIndex);
	this._items[longChiIndex].addStar(longChiStar);
				
	var fengGeStar = Star.newInstance("NORMALSTAR_FENGGEXING", fengGeIndex);
	this._items[fengGeIndex].addStar(fengGeStar);
};

/**
 * 安台辅星
 */
MingPan.prototype._setTaiFuStar = function(lunarHour){
	// 由午宫起子顺数至本生时安之
	
	var defaultStartIndex = Util.getIndexByDiZhi("DZ_WU");
	var lunarHourIndex = Util.getIndexByDiZhi(Util.getLunarHour(lunarHour));
	
	var taiFuIndex = (defaultStartIndex + lunarHourIndex) % 12;
	
	var taiFuStar = Star.newInstance("NORMALSTAR_TAIFUXING", taiFuIndex);
	this._items[taiFuIndex].addStar(taiFuStar);
};

/**
 * 安封诰星
 */
MingPan.prototype._setFengGaoStar = function(lunarHour){
	var defaultStartIndex = Util.getIndexByDiZhi("DZ_YIN");
	var lunarHourIndex = Util.getIndexByDiZhi(Util.getLunarHour(lunarHour));
	
	var fengGaoIndex = (defaultStartIndex + lunarHourIndex) % 12;
	
	var fengGaoStar = Star.newInstance("NORMALSTAR_FENGGAOXING", fengGaoIndex);
	this._items[fengGaoIndex].addStar(fengGaoStar);
};

/**
 * 安天官天福星
 */
MingPan.prototype._setTianGuanTianFuStar = function(lunarYear){
	var tianGan = lunarYear.split("$")[0];
	var tianGuanIndex = -1;
	var tianFuIndex = -1;
	
	switch(tianGan){
		case "TG_JIA" : {
			tianGuanIndex = Util.getIndexByDiZhi("DZ_WEI");
			tianFuIndex = Util.getIndexByDiZhi("DZ_YOU");
			
			break;
		}
		case "TG_YI" : {
			tianGuanIndex = Util.getIndexByDiZhi("DZ_CHEN");
			tianFuIndex = Util.getIndexByDiZhi("DZ_SHEN");
			
			break;
		}
		case "TG_BING" : {
			tianGuanIndex = Util.getIndexByDiZhi("DZ_SI");
			tianFuIndex = Util.getIndexByDiZhi("DZ_ZI");
			
			break;
		}
		case "TG_DING" : {
			tianGuanIndex = Util.getIndexByDiZhi("DZ_YIN");
			tianFuIndex = Util.getIndexByDiZhi("DZ_HAI");
			
			break;
		}
		case "TG_WU" : {
			tianGuanIndex = Util.getIndexByDiZhi("DZ_MAO");
			tianFuIndex = Util.getIndexByDiZhi("DZ_MAO");
			
			break;
		}
		case "TG_JI" : {
			tianGuanIndex = Util.getIndexByDiZhi("DZ_YOU");
			tianFuIndex = Util.getIndexByDiZhi("DZ_YIN");
			
			break;
		}
		case "TG_GENG" : {
			tianGuanIndex = Util.getIndexByDiZhi("DZ_HAI");
			tianFuIndex = Util.getIndexByDiZhi("DZ_WU");
			
			break;
		}
		case "TG_XIN" : {
			tianGuanIndex = Util.getIndexByDiZhi("DZ_YOU");
			tianFuIndex = Util.getIndexByDiZhi("DZ_SI");
			
			break;
		}
		case "TG_REN" : {
			tianGuanIndex = Util.getIndexByDiZhi("DZ_XU");
			tianFuIndex = Util.getIndexByDiZhi("DZ_WU");
			
			break;
		}
		case "TG_GUI" : {
			tianGuanIndex = Util.getIndexByDiZhi("DZ_WU");
			tianFuIndex = Util.getIndexByDiZhi("DZ_SI");
			
			break;
		}
		default: break;
	}
	
	var tianGuanStar = Star.newInstance("NORMALSTAR_TIANGUANXING", tianGuanIndex);
	this._items[tianGuanIndex].addStar(tianGuanStar);
	
	var tianFuStar = Star.newInstance("NORMALSTAR_TIANFUXING", tianFuIndex);
	this._items[tianFuIndex].addStar(tianFuStar);
};

/**
 * 安十二长生诀
 */
MingPan.prototype._set12ChangShengJue = function(gender, genderDescriptor, mingJu){
	// 四吉：长生、冠带、临官、帝旺。 
    // 四平：沐浴、衰、病、养。 
    // 四凶：死、墓、绝、胎。

	var startIndex = -1;
	var that = this;
	
	switch(mingJu.name){
		case "MINGJU_SHUIERJU" : {
			startIndex = Util.getIndexByDiZhi("DZ_SHEN");
			break;
		}
		case "MINGJU_MUSANJU" : {
			startIndex = Util.getIndexByDiZhi("DZ_HAI");
			break;
		} 
		case "MINGJU_JINSIJU" : {
			startIndex = Util.getIndexByDiZhi("DZ_SI");
			break;
		}
		case "MINGJU_TUWUJU" : {
			startIndex = Util.getIndexByDiZhi("DZ_SHEN");
			break;
		}
		case "MINGJU_HUOLIUJU" : {
			startIndex = Util.getIndexByDiZhi("DZ_YIN");
			break;
		}
		default : break;
	}
	
	// 阳男阴女顺行，阴男阳女逆行
	if((gender === "GENDER_NAN" && genderDescriptor == "YY_YANG") || (gender === "GENDER_NV" && genderDescriptor == "YY_YIN")){
		for(var i = 0; i < BizEnum.CHANGSHENG.length; i ++){
			var item = that._items[startIndex];
			item.setChangSheng12Shen(Util.getChangShengByIndex(i));
			
			startIndex ++;
			
			startIndex = (startIndex + 12)% 12;
		}
	}
	
	if((gender === "GENDER_NAN" && genderDescriptor == "YY_YIN") || (gender === "GENDER_NV" && genderDescriptor == "YY_YANG")){
		for(var i = 0; i < BizEnum.CHANGSHENG.length; i ++){
			var item = that._items[startIndex];
			item.setChangSheng12Shen(Util.getChangShengByIndex(i));
			
			startIndex --;
			
			startIndex = (startIndex + 12) % 12;
		}
	}
};

/**
 * 安红鸾天喜星
 */
MingPan.prototype._setHongLuanTianXiStar = function(lunarYear){
	var dizhi = lunarYear.split("$")[1];
	var lunarYearIndex = Util.getIndexByDiZhi(dizhi);
	var defaultStartIndex = Util.getIndexByDiZhi("DZ_MAO");
	
	var hongLuanIndex = (defaultStartIndex - lunarYearIndex + 12) % 12;
	var tianXiIndex = (hongLuanIndex - 6 + 12) % 12;
	
	var hongLuanStar = Star.newInstance("NORMALSTAR_HONGLUANXING", hongLuanIndex);
	this._items[hongLuanIndex].addStar(hongLuanStar);
	
	var tianXiStar = Star.newInstance("NORMALSTAR_TIANXIXING", tianXiIndex);
	this._items[tianXiIndex].addStar(tianXiStar);
};

/**
 * 安孤辰寡宿星
 */
MingPan.prototype._setGuChenGuaXiuStar = function(lunarYear){
	var guChenIndex = -1;
	var guaXiuIndex = -1;
	
	var dizhi = lunarYear.split("$")[1];
	
	switch(dizhi){
		case "DZ_YIN" :
		case "DZ_MAO" :
		case "DZ_CHEN" : {
			guChenIndex = Util.getIndexByDiZhi("DZ_SI");
			guaXiuIndex = Util.getIndexByDiZhi("DZ_CHOU");
			
			break;
		}
		case "DZ_SI" :
		case "DZ_WU" :
		case "DZ_WEI" : {
			guChenIndex = Util.getIndexByDiZhi("DZ_SHEN");
			guaXiuIndex = Util.getIndexByDiZhi("DZ_CHEN");
			
			break;
		}
		case "DZ_SHEN" :
		case "DZ_YOU" :
		case "DZ_XU" : {
			guChenIndex = Util.getIndexByDiZhi("DZ_HAI");
			guaXiuIndex = Util.getIndexByDiZhi("DZ_WEI");
			
			break;
		}
		case "DZ_HAI" :
		case "DZ_ZI" :
		case "DZ_CHOU" : {
			guChenIndex = Util.getIndexByDiZhi("DZ_YIN");
			guaXiuIndex = Util.getIndexByDiZhi("DZ_XU");
			
			break;
		}
	}
	
	var guChenStar = Star.newInstance("NORMALSTAR_GUCHENXING", guChenIndex);
	this._items[guChenIndex].addStar(guChenStar);
	
	var guaXiuStar = Star.newInstance("NORMALSTAR_GUASUXING", guaXiuIndex);
	this._items[guaXiuIndex].addStar(guaXiuStar);
};

/**
 * 安蜚廉星
 */
MingPan.prototype._setFeiLianStar = function(lunarYear){
	var feiLianIndex = -1;
	
	var dizhi = lunarYear.split("$")[1];
	
	switch(dizhi){
		case "DZ_ZI" : {
			feiLianIndex = Util.getIndexByDiZhi("DZ_SHEN");
			break;
		}
		case "DZ_CHOU" : {
			feiLianIndex = Util.getIndexByDiZhi("DZ_YOU");
			break;
		}
		case "DZ_YIN" : {
			feiLianIndex = Util.getIndexByDiZhi("DZ_XU");
			break;
		}
		case "DZ_MAO" : {
			feiLianIndex = Util.getIndexByDiZhi("DZ_SI");
			break;
		}
		case "DZ_CHEN" : {
			feiLianIndex = Util.getIndexByDiZhi("DZ_WU");
			break;
		}
		case "DZ_SI" : {
			feiLianIndex = Util.getIndexByDiZhi("DZ_WEI");
			break;
		}
		case "DZ_WU" : {
			feiLianIndex = Util.getIndexByDiZhi("DZ_YIN");
			break;
		}
		case "DZ_WEI" : {
			feiLianIndex = Util.getIndexByDiZhi("DZ_MAO");
			break;
		}
		case "DZ_SHEN" : {
			feiLianIndex = Util.getIndexByDiZhi("DZ_CHEN");
			break;
		}
		case "DZ_YOU" : {
			feiLianIndex = Util.getIndexByDiZhi("DZ_HAI");
			break;
		}
		case "DZ_XU" : {
			feiLianIndex = Util.getIndexByDiZhi("DZ_ZI");
			break;
		}
		case "DZ_HAI" : {
			feiLianIndex = Util.getIndexByDiZhi("DZ_CHOU");
			break;
		}
		default : break;
	}
	
	var feiLianStar = Star.newInstance("NORMALSTAR_FEILIANXING", feiLianIndex);
	this._items[feiLianIndex].addStar(feiLianStar);
};

/**
 * 安破碎星
 */
MingPan.prototype._setPoSuiStar = function(lunarYear){
	var poSuiIndex = -1;
	
	var dizhi = lunarYear.split("$")[1];
	
	switch(dizhi){
		case "DZ_ZI" :
		case "DZ_WU" :
		case "DZ_MAO" :
		case "DZ_YOU" : {
			poSuiIndex = Util.getIndexByDiZhi("DZ_SI");
			
			break;
		}
		case "DZ_YIN" :
		case "DZ_SHEN" :
		case "DZ_SI" :
		case "DZ_HAI" : {
			poSuiIndex = Util.getIndexByDiZhi("DZ_YOU");
			
			break;
		}
		case "DZ_CHEN" :
		case "DZ_XU" :
		case "DZ_CHOU" :
		case "DZ_WEI" : {
			poSuiIndex = Util.getIndexByDiZhi("DZ_CHOU");
			
			break;
		}
	}
	
	var poSuiStar = Star.newInstance("NORMALSTAR_POSUIXING", poSuiIndex);
	this._items[poSuiIndex].addStar(poSuiStar);
};

/**
 * 安天才天寿星
 */
MingPan.prototype._setTianCaiTianShouStar = function(lunarYear){
	var mingGongIndex = this._mingGongIndex;
	var shenGongIndex = this._shenGongIndex;
	
	var dizhi = lunarYear.split("$")[1];
	var lunarYearIndex = Util.getIndexByDiZhi(dizhi);
	
	var tianCaiIndex = (mingGongIndex + lunarYearIndex) % 12;
	var tianShouIndex = (shenGongIndex + lunarYearIndex) % 12;
	
	var tianCaiStar = Star.newInstance("NORMALSTAR_TIANCAIXING", tianCaiIndex);
	this._items[tianCaiIndex].addStar(tianCaiStar);
	
	var tianShouStar = Star.newInstance("NORMALSTAR_TIANSHOUXING", tianShouIndex);
	this._items[tianShouIndex].addStar(tianShouStar);
};

/**
 * 安截空星
 */
MingPan.prototype._setJieKongStar = function(lunarYear){
	var jieKongIndex = -1;
	
	var tiangan = lunarYear.split("$")[0];
	
	switch(tiangan){
		case "TG_JIA" : {
			jieKongIndex = Util.getIndexByDiZhi("DZ_SHEN");
			
			break;
		}
		case "TG_YI" : {
			jieKongIndex = Util.getIndexByDiZhi("DZ_WU");
			
			break;
		}
		case "TG_BING" : {
			jieKongIndex = Util.getIndexByDiZhi("DZ_CHEN");
			
			break;
		}
		case "TG_DING" : {
			jieKongIndex = Util.getIndexByDiZhi("DZ_YIN");
			
			break;
		}
		case "TG_WU" : {
			jieKongIndex = Util.getIndexByDiZhi("DZ_ZI");
			
			break;
		}
		case "TG_JI" : {
			jieKongIndex = Util.getIndexByDiZhi("DZ_YOU");
			
			break;
		}
		case "TG_GENG" : {
			jieKongIndex = Util.getIndexByDiZhi("DZ_WEI");
			
			break;
		}
		case "TG_XIN" : {
			jieKongIndex = Util.getIndexByDiZhi("DZ_SI");
			
			break;
		}
		case "TG_REN" : {
			jieKongIndex = Util.getIndexByDiZhi("DZ_MAO");
			
			break;
		}
		case "TG_GUI" : {
			jieKongIndex = Util.getIndexByDiZhi("DZ_CHOU");
			
			break;
		}
		default : break;
	}
	
	var jieKongStar = Star.newInstance("NORMALSTAR_JIEKONGXING", jieKongIndex);
	this._items[jieKongIndex].addStar(jieKongStar);
};

/**
 * 安旬空星
 */
MingPan.prototype._setXunKongStar = function(lunarYear){
	var tiangan = lunarYear.split("$")[0];
	var dizhi = lunarYear.split("$")[1];
	
	lunarYear = "JIAZI_" + tiangan.split("_")[1] + dizhi.split("_")[1]
	
	var index1 = -1;
	var index2 = -1;
	
	switch(lunarYear){
		case "JIAZI_JIAZI" :
		case "JIAZI_YICHOU" :
		case "JIAZI_BINGYIN" :
		case "JIAZI_DINGMAO" :
		case "JIAZI_WUCHEN" :
		case "JIAZI_JISI" :
		case "JIAZI_GENGWU" :
		case "JIAZI_XINWEI" :
		case "JIAZI_RENSHEN" :
		case "JIAZI_GUIYOU" : {
			index1 = Util.getIndexByDiZhi("DZ_XU");
			index2 = Util.getIndexByDiZhi("DZ_HAI");
			
			break;
		}
		case "JIAZI_JIAXU" :
		case "JIAZI_YIHAI" :
		case "JIAZI_BINGZI" :
		case "JIAZI_DINGCHOU" :
		case "JIAZI_WUYIN" :
		case "JIAZI_JIMAO" :
		case "JIAZI_GENGCHEN" :
		case "JIAZI_XINSI" :
		case "JIAZI_RENWU" :
		case "JIAZI_GUIWEI" : {
			index1 = Util.getIndexByDiZhi("DZ_SHEN");
			index2 = Util.getIndexByDiZhi("DZ_YOU");
			
			break;
		}
		case "JIAZI_JIASHEN" :
		case "JIAZI_YIYOU" :
		case "JIAZI_BINGXU" :
		case "JIAZI_DINGHAI" :
		case "JIAZI_WUZI" :
		case "JIAZI_JICHOU" :
		case "JIAZI_GENGYIN" :
		case "JIAZI_XINMAO" :
		case "JIAZI_RENCHEN" :
		case "JIAZI_GUISI" : {
			index1 = Util.getIndexByDiZhi("DZ_WU");
			index2 = Util.getIndexByDiZhi("DZ_WEI");
			
			break;
		}
		case "JIAZI_JIAWU" :
		case "JIAZI_YIWEI" :
		case "JIAZI_BINGSHEN" :
		case "JIAZI_DINGYOU" :
		case "JIAZI_WUXU" :
		case "JIAZI_JIHAI" :
		case "JIAZI_GENGZI" :
		case "JIAZI_XINCHOU" :
		case "JIAZI_RENYIN" :
		case "JIAZI_GUIMAO" : {
			index1 = Util.getIndexByDiZhi("DZ_CHEN");
			index2 = Util.getIndexByDiZhi("DZ_SI");
			
			break;
		}
		case "JIAZI_JIACHEN" :
		case "JIAZI_YISI" :
		case "JIAZI_BINGWU" :
		case "JIAZI_DINGWEI" :
		case "JIAZI_WUSHEN" :
		case "JIAZI_JIYOU" :
		case "JIAZI_GENGXU" :
		case "JIAZI_XINHAI" :
		case "JIAZI_RENZI" :
		case "JIAZI_GUICHOU" : {
			index1 = Util.getIndexByDiZhi("DZ_YIN");
			index2 = Util.getIndexByDiZhi("DZ_MAO");
			
			break;
		}
		case "JIAZI_JIAYIN" :
		case "JIAZI_YIMAO" :
		case "JIAZI_BINGCHEN" :
		case "JIAZI_DINGSI" :
		case "JIAZI_WUWU" :
		case "JIAZI_JIWEI" :
		case "JIAZI_GENGSHEN" :
		case "JIAZI_XINYOU" :
		case "JIAZI_RENXU" :
		case "JIAZI_GUIHAI" : {
			index1 = Util.getIndexByDiZhi("DZ_ZI");
			index2 = Util.getIndexByDiZhi("DZ_CHOU");
			
			break;
		}
		default : break;
	}
	
	var xunKongStar = Star.newInstance("NORMALSTAR_XUNKONGXING", index1);
	this._items[index1].addStar(xunKongStar);
	
	xunKongStar.setDescriptor(Util.getMiaoWangByStarAndIndex("NORMALSTAR_XUNKONGXING", index2));
	this._items[index2].addStar(xunKongStar);
};

/**
 * 安天空星
 */
MingPan.prototype._setTianKongStar = function(lunarYear){
	var dizhi = lunarYear.split("$")[1];

	var index = Util.getIndexByDiZhi(dizhi);
	index = (index + 1) % 12;
	
	var tianKongStar = Star.newInstance("NORMALSTAR_TIANKONGXING", index);
	this._items[index].addStar(tianKongStar);
};

/**
 * 安天德月德星
 */
MingPan.prototype._setTianDeYueDeStar = function(lunarYear){
	var defaultTianDeStartIndex = Util.getIndexByDiZhi("DZ_YOU");
	
	var dizhi = lunarYear.split("$")[1];
	var tianDeIndex = defaultTianDeStartIndex + Util.getIndexByDiZhi(dizhi);
	
	tianDeIndex = tianDeIndex % 12;
	
	var tianDeStar = Star.newInstance("NORMALSTAR_TIANDEXING", tianDeIndex);
	this._items[tianDeIndex].addStar(tianDeStar);
	
	var defaultYueDeStartIndex = Util.getIndexByDiZhi("DZ_SI");
	
	var yueDeIndex = defaultYueDeStartIndex + Util.getIndexByDiZhi(dizhi);
	
	yueDeIndex = yueDeIndex % 12;
	
	var yueDeStar = Star.newInstance("NORMALSTAR_YUEDEXING", yueDeIndex);
	this._items[yueDeIndex].addStar(yueDeStar);
};

/**
 * 安天厨星
 */
MingPan.prototype._setTianChuStar = function(lunarYear){
	/*
	天厨的安星诀：甲丁蛇位号天厨，丙鼠壬鸡癸伴猪，乙戊辛干皆向马，己猴庚虎福神殊，都是以生年天干安排，举例说明，比如甲年生人，禄存在寅宫，复禄于
巳，所以天厨星被安在巳宫。
	*/
	var tianChuIndex = -1;
	
	var tiangan = lunarYear.split("$")[0];
	
	switch(tiangan){
		case "TG_JIA" :
		case "TG_DING" :	{
			tianChuIndex = 5;
			
			break;
		}
		case "TG_BING" : {
			tianChuIndex = 0;
			
			break;
		}
		case "TG_REN" :	{
			tianChuIndex = 9;
			
			break;
		}
		case "TG_GUI" : {
			tianChuIndex = 11;
			
			break;
		}
		case "TG_YI" :
		case "TG_WU" :
		case "TG_XIN" :	{
			tianChuIndex = 6;
			
			break;
		}
		case "TG_JI" :	{
			tianChuIndex = 8;
			
			break;
		}
		case "TG_GENG" :	{
			tianChuIndex = 2;
			
			break;
		}
		default : break;
	}
	
	var dizhi = lunarYear.split("$")[1];
	var index = Util.getIndexByDiZhi(dizhi);
	
	var tianChuStar = Star.newInstance("NORMALSTAR_TIANCHUXING", tianChuIndex);
	this._items[tianChuIndex].addStar(tianChuStar);
};

/**
 * 安年解星
 */
MingPan.prototype._setNianJieStar = function(lunarYear){
	var dizhi = lunarYear.split("$")[1];

	var index = Util.getIndexByDiZhi(dizhi);
	var nianJieIndex = (Util.getIndexByDiZhi("DZ_XU") - index + 12) % 12;
	
	var nianJieStar = Star.newInstance("NORMALSTAR_NIANJIEXING", nianJieIndex);
	this._items[nianJieIndex].addStar(nianJieStar);
};

/**
 * 安华盖星
 */
MingPan.prototype._setHuaGaiStar = function(lunarYear){
	var dizhi = lunarYear.split("$")[1];
	
	switch(dizhi){
		case "DZ_SHEN" :
		case "DZ_ZI" :
		case "DZ_CHEN" : {
			var index = Util.getIndexByDiZhi("DZ_CHEN");
			
			var huaGaiStar = Star.newInstance("NORMALSTAR_HUAGAIXING", index);
			this._items[index].addStar(huaGaiStar);
			
			return ;
		}
		case "DZ_HAI" :
		case "DZ_MAO" :
		case "DZ_WEI" : {
			var index = Util.getIndexByDiZhi("DZ_WEI");
			
			var huaGaiStar = Star.newInstance("NORMALSTAR_HUAGAIXING", index);
			this._items[index].addStar(huaGaiStar);
			
			return ;
		}
		case "DZ_YIN" :
		case "DZ_WU" :
		case "DZ_XU" : {
			var index = Util.getIndexByDiZhi("DZ_XU");
			
			var huaGaiStar = Star.newInstance("NORMALSTAR_HUAGAIXING", index);
			this._items[index].addStar(huaGaiStar);
			
			return ;
		}
		case "DZ_SI" :
		case "DZ_YOU" :
		case "DZ_CHOU" : {
			var index = Util.getIndexByDiZhi("DZ_CHOU");
			
			var huaGaiStar = Star.newInstance("NORMALSTAR_HUAGAIXING", index);
			this._items[index].addStar(huaGaiStar);
			
			return ;
		}
		default : return;
	}
};

/**
 * 安十二宫太岁杀禄
 */
MingPan.prototype.setTaiSuiShaLuStar = function(luCunIndex, gender, genderDescriptor){
	var that = this;
	
	// 阳男阴女顺行，阴男阳女逆行
	var shunXing = false;
	if((gender === "GENDER_NAN" && genderDescriptor === "YY_YANG") || (gender === "GENDER_NV" && genderDescriptor === "YY_YIN")){
		shunXing = true;	
	}
	
	for(var i = 0 ; i < BizEnum.TAISUISHALU.length; i ++){
		that._items[luCunIndex] .setTaiSuiShaLu(Util.getTaiSuiShaLuByIndex(i));
	
		if(shunXing){
			luCunIndex ++;
			
			luCunIndex = luCunIndex % 12;
		}else{
			luCunIndex --;
			
			luCunIndex = (luCunIndex + 12) % 12;
		}
	}
};

/** 
 * 安流年岁前诸星
 */
MingPan.prototype.setLiuNianSuiQianStar = function(lunarStr){
	var dizhi = lunarStr.split("$")[1];
	
	var startIndex = Util.getIndexByDiZhi(dizhi);
	for(var i = 0 ; i < this._items.length; i ++){
		var item = this._items[startIndex];
		
		item.setLiuNianSuiQian(Util.getLiuNianSuiQianByIndex(i));
		
		startIndex ++ ;
		
		startIndex = startIndex % 12;
	}
}

/**
 * 安流年将前诸星
 */
MingPan.prototype.setLiuNianJiangQianStar = function(lunarStr){
	var dizhi = lunarStr.split("$")[1];

	var startIndex = -1;
	switch(dizhi){
		case "DZ_YIN" :
		case "DZ_WU" :
		case "DZ_XU" : {
			startIndex = Util.getIndexByDiZhi("DZ_WU");
			break;
		}
		case "DZ_SHEN" :
		case "DZ_ZI" :
		case "DZ_CHEN" : {
			startIndex = Util.getIndexByDiZhi("DZ_ZI");
			break;
		}
		case "DZ_SI" :
		case "DZ_YOU" :
		case "DZ_CHOU" : {
			startIndex = Util.getIndexByDiZhi("DZ_YOU");
			break;
		}
		case "DZ_HAI" :
		case "DZ_MAO" :
		case "DZ_WEI" : {
			startIndex = Util.getIndexByDiZhi("DZ_MAO");
			break;
		}
		default : break;
	}
	
	for(var i = 0 ; i < BizEnum.LIUNIANJIANGQIAN.length; i++){
		this._items[startIndex].setLiuNianJiangQian(Util.getLiuNianJiangQianByIndex(i));
		
		startIndex ++;
		
		startIndex = startIndex % 12;
	}
};

MingPan.prototype.setLuCunIndex = function(luCunIndex){
	this._luCunIndex = luCunIndex;
	
	return this;
};

MingPan.prototype.getLuCunIndex = function(){
	return this._luCunIndex;
};

MingPan.prototype.setSiHuaStar = function(ganZhi, category){
	var luStar, quanStar, keStar, jiStar;
	var sysCfg = SystemConfig.getConfig();
	
	var tiangan = ganZhi.split("$")[0];
	var diZhi = ganZhi.split("$")[1];
	switch(tiangan){
		case "TG_JIA" : {             // 甲廉破武阳为伴
			luStar = "MAINSTAR_LIANZHENXING";
			quanStar = "MAINSTAR_POJUNXING";
			keStar = "MAINSTAR_WUQUXING";
			jiStar = "MAINSTAR_TAIYANGXING";
			
			break;
		}
		case "TG_YI" : {             // 乙机梁紫月交侵
			luStar = "MAINSTAR_TIANJIXING";
			quanStar = "MAINSTAR_TIANLIANGXING";
			keStar = "MAINSTAR_ZIWEIXING";
			jiStar = "MAINSTAR_TAIYINXING";
			
			break;
		}
		case "TG_BING" : {             // 丙同机昌廉贞位
			luStar = "MAINSTAR_TIANTONGXING";
			quanStar = "MAINSTAR_TIANJIXING";
			keStar = "GEMSTAR_WENCHANGXING";
			jiStar = "MAINSTAR_LIANZHENXING";
			
			break;
		}
		case "TG_DING" : {               // 丁月同机巨门寻
			luStar = "MAINSTAR_TAIYINXING";
			quanStar = "MAINSTAR_TIANTONGXING";
			keStar = "MAINSTAR_TIANJIXING";
			jiStar = "MAINSTAR_JUMENXING";
			
			break;
		}
		case "TG_WU" : {              // 戊贪阴弼机为主
			var wuGanSiHua = sysCfg.getSiHuaOfWu();
		
			luStar = wuGanSiHua.lu;
			quanStar = wuGanSiHua.quan;
			keStar = wuGanSiHua.ke;
			jiStar = wuGanSiHua.ji;
			
			break;
		}
		case "TG_JI" : {             // 己武贪梁曲最平
			luStar = "MAINSTAR_WUQUXING";
			quanStar = "MAINSTAR_TANLANGXING";
			keStar = "MAINSTAR_TIANLIANGXING";
			jiStar = "GEMSTAR_WENQUXING";
			
			break;
		}
		case "TG_GENG" : {            // 
			var gengGanSiHua = sysCfg.getSiHuaOfGeng();
		
			luStar = gengGanSiHua.lu;
			quanStar = gengGanSiHua.quan;
			keStar = gengGanSiHua.ke;
			jiStar = gengGanSiHua.ji;
			
			break;
		}
		case "TG_XIN" : {               // 辛巨阳曲昌至临
			luStar = "MAINSTAR_JUMENXING";
			quanStar = "MAINSTAR_TAIYANGXING";
			keStar = "GEMSTAR_WENQUXING";
			jiStar = "GEMSTAR_WENCHANGXING";
			
			break;
		}
		case "TG_REN" : {              // TG_REN梁紫左武宿是
			var renGanSiHua = sysCfg.getSiHuaOfRen();
		
			luStar = renGanSiHua.lu;
			quanStar = renGanSiHua.quan;
			keStar = renGanSiHua.ke;
			jiStar = renGanSiHua.ji;
			
			break;
		}
		case "TG_GUI" : {             // 癸破巨阴贪狼停
			luStar = "MAINSTAR_POJUNXING";
			quanStar = "MAINSTAR_JUMENXING";
			keStar = "MAINSTAR_TAIYINXING";
			jiStar = "MAINSTAR_TANLANGXING";
			
			break;
		}
		default : break;
	}
	
	var method = "";
	switch(category){
		case "XianTianMingPan" : method = "setSiXiang"; break; 
		case "LiuNianMingPan" : method = "setSiHuaOfLiuNian"; break; 
		case "DaYunMingPan" : method = "setSiHuaOfDaYun"; break; 
		case "LiuYueMingPan" : method = "setSiHuaOfLiuYue"; break; 
		case "LiuRiMingPan" : method = "setSiHuaOfLiuRi"; break; 
		case "LiuShiMingPan" : method = "setSiHuaOfLiuShi"; break; 
		case "LiuFenMingPan" : method = "setSiHuaOfLiuFen"; break; 
		default : break;
	}
	
	for(var i = 0 ; i < this._items.length; i ++){
		var item = this._items[i];
		
		if(item.getTianGan() && item.getTianGan() == tiangan){
			item.setLaiYin("LAIYIN");
		}
		
		if(item.getDiZhi() && item.getDiZhi() == diZhi){
			item.setTaisui("TAISUI");
		}
		
		var stars = item.getStars();
		
		for(var j = 0 ; j < stars.length; j ++){
			var star = stars[j];
			
			if(star.getName() == luStar){
				eval("star." + method + "('SIHUA_LU')");
			}
			
			if(star.getName() == quanStar){
				eval("star." + method + "('SIHUA_QUAN')");
			}
			
			if(star.getName() == keStar){
				eval("star." + method + "('SIHUA_KE')");
			}
			
			if(star.getName() == jiStar){
				eval("star." + method + "('SIHUA_JI')");
			}
		}
	}
};


MingPan.prototype.setSiHuaStar2 = function(ganZhi, category,index){
	var luStar, quanStar, keStar, jiStar;
	var sysCfg = SystemConfig.getConfig();
	
	var tiangan = ganZhi.split("$")[0];
	switch(tiangan){
		case "TG_JIA" : {             // 甲廉破武阳为伴
			luStar = "MAINSTAR_LIANZHENXING";
			quanStar = "MAINSTAR_POJUNXING";
			keStar = "MAINSTAR_WUQUXING";
			jiStar = "MAINSTAR_TAIYANGXING";
			
			break;
		}
		case "TG_YI" : {             // 乙机梁紫月交侵
			luStar = "MAINSTAR_TIANJIXING";
			quanStar = "MAINSTAR_TIANLIANGXING";
			keStar = "MAINSTAR_ZIWEIXING";
			jiStar = "MAINSTAR_TAIYINXING";
			
			break;
		}
		case "TG_BING" : {             // 丙同机昌廉贞位
			luStar = "MAINSTAR_TIANTONGXING";
			quanStar = "MAINSTAR_TIANJIXING";
			keStar = "GEMSTAR_WENCHANGXING";
			jiStar = "MAINSTAR_LIANZHENXING";
			
			break;
		}
		case "TG_DING" : {               // 丁月同机巨门寻
			luStar = "MAINSTAR_TAIYINXING";
			quanStar = "MAINSTAR_TIANTONGXING";
			keStar = "MAINSTAR_TIANJIXING";
			jiStar = "MAINSTAR_JUMENXING";
			
			break;
		}
		case "TG_WU" : {              // 戊贪阴弼机为主
			var wuGanSiHua = sysCfg.getSiHuaOfWu();
		
			luStar = wuGanSiHua.lu;
			quanStar = wuGanSiHua.quan;
			keStar = wuGanSiHua.ke;
			jiStar = wuGanSiHua.ji;
			
			break;
		}
		case "TG_JI" : {             // 己武贪梁曲最平
			luStar = "MAINSTAR_WUQUXING";
			quanStar = "MAINSTAR_TANLANGXING";
			keStar = "MAINSTAR_TIANLIANGXING";
			jiStar = "GEMSTAR_WENQUXING";
			
			break;
		}
		case "TG_GENG" : {            // 
			var gengGanSiHua = sysCfg.getSiHuaOfGeng();
		
			luStar = gengGanSiHua.lu;
			quanStar = gengGanSiHua.quan;
			keStar = gengGanSiHua.ke;
			jiStar = gengGanSiHua.ji;
			
			break;
		}
		case "TG_XIN" : {               // 辛巨阳曲昌至临
			luStar = "MAINSTAR_JUMENXING";
			quanStar = "MAINSTAR_TAIYANGXING";
			keStar = "GEMSTAR_WENQUXING";
			jiStar = "GEMSTAR_WENCHANGXING";
			
			break;
		}
		case "TG_REN" : {              // TG_REN梁紫左武宿是
			var renGanSiHua = sysCfg.getSiHuaOfRen();
		
			luStar = renGanSiHua.lu;
			quanStar = renGanSiHua.quan;
			keStar = renGanSiHua.ke;
			jiStar = renGanSiHua.ji;
			
			break;
		}
		case "TG_GUI" : {             // 癸破巨阴贪狼停
			luStar = "MAINSTAR_POJUNXING";
			quanStar = "MAINSTAR_JUMENXING";
			keStar = "MAINSTAR_TAIYINXING";
			jiStar = "MAINSTAR_TANLANGXING";
			
			break;
		}
		default : break;
	}
	
	var method = "";
	switch(category){
		case "XianTianMingPan" : method = "setSiXiang"; break; 
		case "LiuNianMingPan" : method = "setSiHuaOfLiuNian"; break; 
		case "DaYunMingPan" : method = "setSiHuaOfDaYun"; break; 
		case "LiuYueMingPan" : method = "setSiHuaOfLiuYue"; break; 
		case "LiuRiMingPan" : method = "setSiHuaOfLiuRi"; break; 
		case "LiuShiMingPan" : method = "setSiHuaOfLiuShi"; break; 
		case "LiuFenMingPan" : method = "setSiHuaOfLiuFen"; break; 
		case "SiHuaMingPan" : method = 'setSiHuaMingPan'; break;
		default : break;
	}
	
	var item = this._items[index];
	var stars = item.getStars();
		
	for(var j = 0 ; j < stars.length; j ++){
		var star = stars[j];
				
		if(star.getName() == luStar){
			eval("star." + method + "('SIHUA_LU_PAN')");
			eval("star." + "setIfSiHuaOfSelf" + "(true)");
		}
				
		if(star.getName() == quanStar){
			eval("star." + method + "('SIHUA_QUAN_PAN')");
			eval("star." + "setIfSiHuaOfSelf" + "(true)");
		}
				
		if(star.getName() == keStar){
			eval("star." + method + "('SIHUA_KE_PAN')");
			eval("star." + "setIfSiHuaOfSelf" + "(true)");
		}
				
		if(star.getName() == jiStar){
			eval("star." + method + "('SIHUA_JI_PAN')");
			eval("star." + "setIfSiHuaOfSelf" + "(true)");
		}
	}
		
	if(category == "SiHuaMingPan"){
			
		var duiIndex = 0;
		if(index < 6){
			duiIndex = index + 6;
		}else {
			duiIndex = index - 6;
	}
			
		var duiItem = this._items[duiIndex];
		stars = duiItem.getStars();
			
			
			var duiGongSiHua = "";
			for(var j = 0 ; j < stars.length; j ++){
				var star = stars[j];
				
				if(star.getName() == luStar){
					duiGongSiHua = duiGongSiHua + 'SIHUA_LU_PAN' + "-";
					eval("item." + "setSiHuaOfDui" + "(true)");
				}
				
				if(star.getName() == quanStar){
					duiGongSiHua = duiGongSiHua + 'SIHUA_QUAN_PAN' + "-";
					eval("item." + "setSiHuaOfDui" + "(true)");
				}
				
				if(star.getName() == keStar){
					duiGongSiHua = duiGongSiHua + 'SIHUA_KE_PAN' + "-";
					eval("item." + "setSiHuaOfDui" + "(true)");
				}
				
				if(star.getName() == jiStar){
					duiGongSiHua = duiGongSiHua + 'SIHUA_JI_PAN' + "-";
					eval("item." + "setSiHuaOfDui" + "(true)");
				}
			}
			
			eval("item." + "setSiHuaOfDaYunDui" + "(duiGongSiHua)");
		}
}

MingPan.prototype.setSiHuaPanStar = function(category){
	for(var i = 0 ; i < this._items.length; i ++){
		var item = this._items[i];
		this.setSiHuaStar2(item.getTianGan(),category,i);
	}
};
