/**
 * PerpetualCalendarDay.js
 * 万年历天， 指代万年历中的某一天
 *
 * @date 2013-12-31
 * @version 0.1
 *
 * @date 2014-01-04
 * @version 0.2
 * @description  修改原先万年历项所指代的概念(以前指代一个农历年),将其改为指代
 *                一个公历天,因变动大,所以必须进行全面代码重构,并将文件名改为
 *                perpetualcalendarday.js,将类名改为PerpetualCalendarDay
 *
 * @date 2014-01-08
 * @version 0.3
 * @description 增加命名空间,增加小时
 */
 
 namespace("com.taxen.framework.ziwei.calendar");
 
 /**
  * 万年历天
  */
 function PerpetualCalendarDay(){
	this._year = false;                          // 公历年(eg. 2014)
	this._month = false;                         // 公历月(eg. 1)
	this._day = false;                           // 公历日(eg. 4) 
	this._hour = false;                          // 公历时(eg. 14)
	this._lunarYear = false;                     // 农历年(eg. 2013)
	this._lunarMonth = false;                    // 农历月(eg. 腊月)
	this._isLunarRunYue = false;                 // 是否是农历闰月(eg. false)
	this._lunarDay = false;                      // 农历日(eg. 初四)
	this._lunarHour = false;                     // 农历时(eg. 申时)
	this._yearOfGanZhi = false;                  // 农历干支年(eg. 癸巳年)
	this._monthOfGanZhi = false;                 // 农历干支月(eg. 甲子月)
	this._dayOfGanZhi = false;                   // 农历干支日(eg. 乙亥日)
	this._hourOfGanZhi = false;                  // 农历干支时(eg. 癸未时)
	this._zodiac = false;                        // 农历年生肖(eg. 蛇年) 
	this._weekday = false;                       // 星期数(eg. 星期六)
	this._festival = false;                      // 今天的节日(eg. 无)           // 暂未实现
	this._suitableThings = false;                // 宜(eg. 入宅...)              // 暂未实现
	this._inappropriateThings = false;           // 忌(eg. 嫁娶...)              // 暂未实现
	this._feast = false;                         // 今日的节气
 }
 
 PerpetualCalendarDay.newInstance = function(year, month, day, hour){
	hour = hour || 0;
 
	var theDay = new PerpetualCalendarDay();
	
	theDay._setDateInfo(year, month, day, hour)._setLunarDateInfo()._setZodiac()._setWeekday()._setFeast();

	return theDay;
 };
 
 PerpetualCalendarDay.prototype._setDateInfo = function(year, month, day, hour){
	this._setYear(year)._setMonth(month)._setDay(day)._setHour(hour);
	
	return this;
 };
 
 PerpetualCalendarDay.prototype._setLunarDateInfo = function(){
	var lunarDate = PerpetualCalendar.convertGregorianDate2LunarDate(this._year, this._month, this._day);
	
	this._setLunarYear(lunarDate.getYear())._setLunarMonth(lunarDate.getMonth(), lunarDate.isRunYue())._setLunarDay(lunarDate.getDay());
	
	return this;
 };
 
 PerpetualCalendarDay.prototype._setFeast = function(){
	this._feast = SimpleFeastCalculator.getFeastByDate(this._year, this._month, this._day);
	
	return this;
 };
 
 PerpetualCalendarDay.prototype._setWeekday = function(){
	var defaultWeekday = ["日", "一", "二", "三", "四", "五", "六"];
	
	var index = new Date(this._year, this._month - 1, this._day).getDay();
	
	this._weekday = defaultWeekday[index];
	
	return this;
 };
 
 PerpetualCalendarDay.prototype._setZodiac = function(){
	var index = ZiWei.getIndexOfDIZHI(this._yearOfGanZhi.charAt(1));
	
	this._zodiac = ZiWei.consts.ZODIAC[index];
	
	return this;
 };
 
 PerpetualCalendarDay.prototype._setLunarYear = function(lunarYear){
	this._lunarYear = lunarYear;
	
	this._yearOfGanZhi = PerpetualCalendar.getLunarYearGanZhiStr(this._lunarYear);
	
	return this;
 };
 
 PerpetualCalendarDay.prototype._setLunarMonth = function(lunarMonth, isRunYue){
	var defaultMonthName = ["正", "二", "三", "四", "五", "六", "七", "八", "九", "十", "十一", "腊"];
 
	this._lunarMonth = (isRunYue ? "闰" : "") + defaultMonthName[lunarMonth-1];
	
	this._setMonthOfGanZhi(lunarMonth, isRunYue);
	
	return this;
 };
 
 PerpetualCalendarDay.prototype._setLunarDay = function(lunarDay){
	var defaultDayName = ["一", "二", "三", "四", "五", "六", "七", "八", "九", "初", "十", "廿", "卅"];
	
	var lunarDayName = "";
	
	if(lunarDay < 10){
		lunarDayName = defaultDayName[9] + defaultDayName[lunarDay - 1];
	}else if(lunarDay == 10){
		lunarDayName = defaultDayName[9] + defaultDayName[10];
	}else if(lunarDay < 20){
		lunarDayName = defaultDayName[10] + defaultDayName[lunarDay % 10 -1];
	}else if(lunarDay == 20){
		lunarDayName = defaultDayName[1] + defaultDayName[10];
	}else if(lunarDay < 30){
		lunarDayName = defaultDayName[11] + defaultDayName[lunarDay % 20 - 1];
	}else if(lunarDay == 30){
		lunarDayName = defaultDayName[2] + defaultDayName[10];
	}
	
	this._lunarDay = lunarDayName;
	
	this._setDayOfGanZhi();
	
	return this;
 };
 
 PerpetualCalendarDay.prototype._setLunarHour = function(lunarHour){
	this._lunarHour = lunarHour;
	
	
 };
 
 PerpetualCalendarDay.prototype._setMonthOfGanZhi = function(lunarMonthIndex, isRunYue){
	var tianGanStartIndex = -1;
	
	if(isRunYue){
		lunarMonthIndex = (lunarMonthIndex + 1) % 12;
	}
 
	switch(this._yearOfGanZhi.charAt(0)){
		case "甲" :
		case "己" : {
			tianGanStartIndex = ZiWei.getIndexOfTIANGAN("丙");
			break;
		}
		case "乙" :
		case "庚" : {
			tianGanStartIndex = ZiWei.getIndexOfTIANGAN("戊");
			break;
		}
		case "丙" :
		case "辛" : {
			tianGanStartIndex = ZiWei.getIndexOfTIANGAN("庚");
			break;
		}
		case "丁" :
		case "壬" : {
			tianGanStartIndex = ZiWei.getIndexOfTIANGAN("壬");
			break;
		}
		case "戊" :
		case "癸" : {
			tianGanStartIndex = ZiWei.getIndexOfTIANGAN("甲");
			break;
		}
	}

	var diZhiStartIndex = ZiWei.getIndexOfDIZHI("寅");
	
	var tianGanIndex = (tianGanStartIndex + lunarMonthIndex - 1) % 10;
	var diZhiIndex = (diZhiStartIndex + lunarMonthIndex - 1) % 12;
	
	this._monthOfGanZhi = ZiWei.consts.TIANGAN[tianGanIndex] + ZiWei.consts.DIZHI[diZhiIndex];
	
	return this;
 };
 
 PerpetualCalendarDay.prototype._setDayOfGanZhi = function(){	
	var that = this;
 
	var baseTable = ["己卯","壬申","甲子","丁巳","己酉","壬寅","甲午","丁亥"];
	
	var baseYear = -1;
	
	var mod_year = that._year % 10;
	
	if(mod_year < 4){
		baseYear = (Math.floor(that._year / 10)) * 10 + 4 - 10;
	}else{
		baseYear = (Math.floor(that._year / 10)) * 10 + 4;
	}
	
	var index = ((baseYear - 1924) / 10) % 8;
	
	var points = (that._year - baseYear) * 5;
	
	for(var i = baseYear; i <= that._year; i ++){
		if(ZiWei.isLeapYear(i)){
			points ++;
		}
	}
	
	points += (PerpetualCalendar.getIntervalDays(new Date(that._year, 0, 1), new Date(that._year, that._month -1, that._day)) % 60);
	
	points = points % 60;
	
	var startIndex = ZiWei.getIndexOfJIAZI(baseTable[index]);
	
	var index = startIndex + points
	
	index = (index - 1 + 60) % 60;
	
	that._dayOfGanZhi = ZiWei.consts["JIAZI"][index];
	
	return this;
 };
 
 PerpetualCalendarDay.prototype._setHourOfGanZhi = function(){
 
 };

 PerpetualCalendarDay.prototype.getYear = function(){
	return this._year;
 };
 
 PerpetualCalendarDay.prototype.getMonth = function(){
	return this._month;
 };
 
 PerpetualCalendarDay.prototype.getDay = function(){
	return this._day;
 };
 
 PerpetualCalendarDay.prototype.getHour = function(){
	return this._hour;
 };
 
 PerpetualCalendarDay.prototype.getLunarYear = function(){
	return this._lunarYear;
 };
 
 PerpetualCalendarDay.prototype.getLunarMonth = function(){
	return this._lunarMonth;
 };
 
 PerpetualCalendarDay.prototype.getLunarDay = function(){
	return this._lunarDay;
 };
 
 PerpetualCalendarDay.prototype.getLunarHour = function(){
	return this._lunarHour;
 };
 
 PerpetualCalendarDay.prototype.getYearOfGanZhi = function(){
	return this._yearOfGanZhi;
 };
 
 PerpetualCalendarDay.prototype.getMonthOfGanZhi = function(){
	return this._monthOfGanZhi;
 };
 
 PerpetualCalendarDay.prototype.getDayOfGanZhi = function(){
	return this._dayOfGanZhi;
 };
 
 PerpetualCalendarDay.prototype.getZodiac = function(){
	return this._zodiac;
 };
 
 PerpetualCalendarDay.prototype.getWeekDay = function(){
	return this._weekday;
 };
 
 PerpetualCalendarDay.prototype.getFestival = function(){
	return this._festival;
};

PerpetualCalendarDay.prototype.getFeast = function(){
	return this._feast;
};

PerpetualCalendarDay.prototype.getSuitableThings = function(){
	return this._suitableThings;
};

PerpetualCalendarDay.prototype.getInappropriateThings = function(){
	return this._inappropriateThings;
};

/**
 * 根据小时数获取此时的四柱数
 */
PerpetualCalendarDay.prototype.getSiZhuByHour = function(hour){
	if(hour >= 24 || hour < 0){
		return false;
	}
	
	var tianGanStartIndex = -1;
	var diZhiStartIndex = ZiWei.getIndexOfDIZHI("子");
	var hourIndex = ZiWei.getIndexOfDIZHI(ZiWei.convertHour2DIZHI(hour, 0));
 
	switch(this._dayOfGanZhi.charAt(0)){
		case "甲" :
		case "己" : {
			tianGanStartIndex = ZiWei.getIndexOfTIANGAN("甲");
			break;
		}
		case "乙" :
		case "庚" : {
			tianGanStartIndex = ZiWei.getIndexOfTIANGAN("丙");
			break;
		}
		case "丙" :
		case "辛" : {
			tianGanStartIndex = ZiWei.getIndexOfTIANGAN("戊");
			break;
		}
		case "丁" :
		case "壬" : {
			tianGanStartIndex = ZiWei.getIndexOfTIANGAN("庚");
			break;
		}
		case "戊" :
		case "癸" : {
			tianGanStartIndex = ZiWei.getIndexOfTIANGAN("壬");
			break;
		}
		default : break;
	}
 
	var tianGanIndex = (tianGanStartIndex + hourIndex) % 10;
	var diZhiIndex = hourIndex;
	
    var shiZhu = ZiWei.consts.TIANGAN[tianGanIndex] + ZiWei.consts.DIZHI[diZhiIndex];
	
	return {
		"NianZhu" : this._yearOfGanZhi,
		"YueZhu" : this._monthOfGanZhi,
		"RiZhu" : this._dayOfGanZhi,
		"ShiZhu" : shiZhu
	};
};

 PerpetualCalendarDay.prototype._setYear = function(year){
	this._year = year;
	
	return this;
 };
 
 PerpetualCalendarDay.prototype._setMonth = function(month){
	this._month = month;
	
	return this;
 };
 
 PerpetualCalendarDay.prototype._setDay = function(day){
	this._day = day;
	
	return this;
 };
 
 PerpetualCalendarDay.prototype._setHour = function(hour){
	this._hour = hour;
	
	return this;
 };